mode(-1);
function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction


function IMJPlotMultiRes(wavecoef,L,scal,QMF_Filter)
//  Mallat-Style MRA plot -- IJ version with changed axis labelling
//
if scal==0, 
    scal = 1. / max(abs(wavecoef)); 
end
[n,J] = dyadlength(wavecoef); 
LockAxes([0 1 (L-2) J]);
t = (.5:(n-.5))/n;
//
	for j=(J-1):-1:L
	   w = zeros(1,n);
	   w(dyad(j)) = wavecoef(dyad(j));
	   x = IWT_PO(w,j,QMF_Filter);
	   plot(t, j + scal.*x);
	end
	w = zeros(1,n);
	w(1:2^(L)) = wavecoef(1:2^(L));
	x = IWT_PO(w,L,QMF_Filter);
	plot(t,(L-1) + scal.*x);
//xlabel('Spatial Var.'); ylabel('Dyadic Resolution Level');
//title('Multi-Resolution Decomposition');
UnlockAxes;


// Revision History
//  10/1/05          AM            Name of the variable QMF is changed to
//                                 QMF_Filter


//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
endfunction

function IMJPlotWaveCoeff(wavecoef,L,scal)
// IMJPlotWaveCoeff -- Wavelet Coeffts Plot: IMJ version with changed axis labelling
[n,J] = dyadlength(wavecoef); 
if scal==0, 
   seg = (1+ 2^(L)):(n);
   scal = .75 ./ max(abs(wavecoef(seg))); 
end
LockAxes([0 1  (L-1) J]); 
for j=(J-1):(-1):L
  tj = (.5:(2^(j)-.5))./2^(j) ;
  PlotSpikes(j,tj,(wavecoef(dyad(j)).*scal));
end
//xlabel('k, spatial position'); ylabel('j, resolution scale');
//title('Wavelet Decomposition');
UnlockAxes;
    

//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
endfunction


function r = rms(y)
// rms -- Return Root Mean Square of Signal
//  Usage
//    r = rms(y)
//  Inputs
//    y    signal
//  Outputs
//    r    sqrt( mean ( y .^2 ))
//
r = sqrt( mtlb_mean ( y .^2 ));
    
endfunction   


       N   = 2048; 
       rho = 7;
       qmf = MakeONFilter('Symmlet',8);
       L   = 6;

   t = (0:(N-1))./N;
//
   HeaviSine = MakeSignal('HeaviSine',N);
   Bumps     = MakeSignal('Bumps',N);
   Blocks    = MakeSignal('Blocks',N);
   Doppler   = MakeSignal('Doppler',N);
//
   rand('seed',0);
   [xblocks,yblocks]   = NoiseMaker(Blocks,rho);
   [xbumps,ybumps]     = NoiseMaker(Bumps,rho);
   [xheavi,yheavi]     = NoiseMaker(HeaviSine,rho);
   [xDoppler,yDoppler] = NoiseMaker(Doppler,rho);

clc;mode(1);lines(0);
// adfig01 -- Adapt Figure 01: Four Spatially Inhomogenoeus Signals
//
// These four signals are caricatures of signals arising
// in scientific signal processing.
//
// Blocks is a piecewise constant signal, a caricature of a scan line
// through a 2-d image depicting an object with several edges.
//
// Bumps is a very peaky signal, a caricature of an NMR Spectrum.
// 
// HeaviSine is a sinusoid with two clicks.
//
// Doppler is an attenuating sinusoid with time-varying frequency.
//
// These objects are interesting to us because they portray significant
// spatial inhomogeneity.
//
mode(-1);
scf(1);clf(1);
//
   //clf;
   versaplot(221,t,xblocks, [],' 1 (a) Blocks '   ,[],[])
   versaplot(222,t,xbumps,  [],' 1 (b) Bumps '    ,[],[])
   versaplot(223,t,xheavi,  [],' 1 (c) HeaviSine ',[],[])
   versaplot(224,t,xDoppler,[],' 1 (d) Doppler '  ,[],[])

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig02 -- Adapt Figure 02: Noisy Versions of Four Signals
//
// The four objects of Figure 1 with white noise superposed.
// The noise is normally distributed with variance 1.
//
// 
mode(-1);
scf(1);clf(1);

//
//clf;
versaplot(221,t,yblocks, [],' 2 (a) Noisy Blocks '   ,[],[])
versaplot(222,t,ybumps,  [],' 2 (b) Noisy Bumps '    ,[],[])
versaplot(223,t,yheavi,  [],' 2 (c) Noisy HeaviSine ',[],[])
versaplot(224,t,yDoppler,[],' 2 (d) Noisy Doppler '  ,[],[])

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig03 -- Adapt Figure 03: Wavelet Shrinkage of the Four Noisy Signals
//
// Here we aapply a specific thresholding rule to the
// four noisy signals depicted in Figure 2.
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a soft thresholding nonlinearity, with threshold selected
//           by the Stein's Unbiased Risk Estimate (SURE) in the interval
//           [0,sqrt{2 log(n)}]
//       3.  Transform back to the signal domain.
// 
// The reconstructions suppress the noise, while preserving the sharp structure
// in the neighborhood of the highly-variable spatial components.
//
mode(-1);
scf(1);clf(1);
//

   [xhat,xw] = WaveShrink(yblocks,'Hybrid',L,qmf);
   versaplot(221,t,xhat,[],' 3 (a) SUREShrink[Blocks]',[],[])
//
   [xhat,xw] = WaveShrink(ybumps,'Hybrid',L,qmf);
   versaplot(222,t,xhat,[],' 3 (b) SUREShrink[Bumps]',[],[])
//
   [xhat,xw] = WaveShrink(yheavi,'Hybrid',L,qmf);
   versaplot(223,t,xhat,[],' 3 (c) SUREShrink[HeaviSine]',[],[])
//
   [xhat,xw] = WaveShrink(yDoppler,'Hybrid',L,qmf);
   versaplot(224,t,xhat,[],' 3 (d) SUREShrink[Doppler]',[],[])

halt("press a key to proceed!");
clc;mode(1);lines(0);    
// adfig04 -- Adapt Figure 04: LPJS reconstruction
//
// The James-Stein Estimate is applied to Dyadic Fourier
// Coronae. This shrinker can be described as follows:
// segment the Fourier Domain into blocks of size 2^j, 
// estimate the signal strength in each block, and apply that
// scalar shrinkage to each block which is appropriate for
// the estimated signal strength. The first block begins at 
// L = 5.
//
// Despite the promising connection with classical multivariate
// shrinkage, the estimator has a disappointing visual appearance.
//
mode(-1);
scf(1);clf(1);
//
//clf;
//
[xhat,xw] = CoronaJS(yblocks,L);
versaplot(221,t,xhat,[],' 4 (a) LPJS[Blocks]',[],[])
[xhat,xw] = CoronaJS(ybumps,L);
versaplot(222,t,xhat,[],' 4 (b) LPJS[Bumps]',[],[])
[xhat,xw] = CoronaJS(yheavi,L);
versaplot(223,t,xhat,[],' 4 (c) LPJS[HeaviSine]',[],[])
[xhat,xw] = CoronaJS(yDoppler,L);
versaplot(224,t,xhat,[],' 4 (d) LPJS[Doppler]',[],[])

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig05 -- Adapt Figure 05: A Display of all four wavelets, j=6, k=32;
//
// The display shows four mother wavelets from the Haar,
// original Daubechies, Coiflet, and Nearly Symmetric Families.
//
mode(-1);
scf(1);clf(1);

	xw = zeros(1,2048);
	xw(dyad2ix(6,32)) = 1;
	HaarQMF = MakeONFilter('Haar');
	HaarWave = IWT_PO(xw,5,HaarQMF);
	//HaarWave = MakeWavelet(6,32,'Haar',1,'Mother',2048);
	D4QMF   = MakeONFilter('Daubechies',4);
	DaubWave = IWT_PO(xw,5,D4QMF);
	//DaubWave = MakeWavelet(6,32,'Daubechies',4,'Mother',2048);
	C3QMF   = MakeONFilter('Coiflet',3);
	CoifWave = IWT_PO(xw,5,C3QMF);
	//CoifWave = MakeWavelet(6,32,'Coiflet',3,'Mother',2048);
	S8QMF   = MakeONFilter('Symmlet',8);
	SymmWave = IWT_PO(xw,5,S8QMF);
	//SymmWave = MakeWavelet(6,32,'Symmlet',8,'Mother',2048);
//
//  2 * 2 array of plots
//
	//clf;
	tt = (.5:2047.5)/2048;
	versaplot(221,tt,HaarWave,[],'5 (a) Haar Wavelet',         [.4 .6 -.3 +.3],[])
	versaplot(222,tt,DaubWave,[],'5 (b) Daubechies D4 Wavelet',[.4 .6 -.3 +.3],[])
	versaplot(223,tt,CoifWave,[],'5 (c) Daubechies C3 Coiflet',[.4 .6 -.3 +.3],[])
	versaplot(224,tt,SymmWave,[],'5 (d) Daubechies S8 Symmlet',[.4 .6 -.3 +.3],[])

halt("press a key to proceed!");
clc;mode(1);lines(0);    
// adfig06 -- Adapt Figure 06: MultiResolution Analysis of the Four Functions
// 
// Mallat's MRA groups together all the terms in the wavelet 
// decomposition which occupy the same scale (with perhaps
// different locations).
//
// Here we display the MRA of the four functions from Figure 1,
// using the Daubechies Nearly Symmetric S8 Wavelet.
//
mode(-1);
scf(1);clf(1);

S8QMF = MakeONFilter('Symmlet',8);
L = 6; //clf;
// 
   subplot(221);
   xw = FWT_PO(Blocks,L,S8QMF);
   IMJPlotMultiRes(xw,L,.2,S8QMF);
   title(' 6 (a) Blocks ')
//
   subplot(222);
   xw = FWT_PO(Bumps,L,S8QMF);
   IMJPlotMultiRes(xw,L,.2,S8QMF);
   title(' 6 (b) Bumps ')
//
   subplot(223)
   xw = FWT_PO(HeaviSine,L,S8QMF);
   IMJPlotMultiRes(xw,L,.2,S8QMF);
   title(' 6 (c) HeaviSine ')
//
   subplot(224)
   xw = FWT_PO(Doppler,L,S8QMF);
   IMJPlotMultiRes(xw,L,.2,S8QMF);
   title(' 6 (d) Doppler ')
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig07 -- Adapt Figure 07: MultiResolution Analysis of Blocks and HeaviSine
//                Using Haar & Db4
//
// Mallat's MRA groups together all the terms in the wavelet 
// decomposition which occupy the same scale (with perhaps
// different locations).
//
// Here we display the MRA of the four functions from Figure 1,
// using the Daubechies Nearly Symmetric S8 Wavelet. Each curve
// represents the contributions arising from a single scale.
//
mode(-1);
scf(1);clf(1);

//
HaarQMF = MakeONFilter('Haar');
//
   //clf; 
   subplot(221);
   xw = FWT_PO(Blocks,L,HaarQMF);
   IMJPlotMultiRes(xw,L,.2,HaarQMF);
   title(' 7 (a) Haar[Blocks] ')
//
   subplot(222);
   xw = FWT_PO(HeaviSine,L,HaarQMF);
   IMJPlotMultiRes(xw,L,.2,HaarQMF);
   title(' 7 (b) Haar[HeaviSine] ')
//
Db4QMF  = MakeONFilter('Daubechies',4);
//
   subplot(223)
   xw = FWT_PO(Blocks,L,Db4QMF);
   IMJPlotMultiRes(xw,L,.2,Db4QMF);
   title(' 7 (c) Db4[Blocks] ')
//
   subplot(224)
   xw = FWT_PO(HeaviSine,L,Db4QMF);
   IMJPlotMultiRes(xw,L,.2,Db4QMF);
   title(' 7 (d) Db4[HeaviSine] ')


halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig08 -- Adapt Figure 08: S8 Wavelet Coefficients of the Four Functions
//
// Here we display the wavelet coefficients of the four functions,
// stratified by scale and location.  The significant coefficients
// occur in locations of significant spatial variability.  For
// locally smooth functions, the coefficients tend to be small
// at fine scales.
//
mode(-1);
scf(1);clf(1);
//
S8QMF = MakeONFilter('Symmlet',8);
//clf;
//
   subplot(221)
   wx = FWT_PO(Blocks,L,S8QMF);
   IMJPlotWaveCoeff(wx,L,0.);
   title(' 8 (a) Blocks ')
//
   subplot(222)
   wx = FWT_PO(Bumps,L,S8QMF);
   IMJPlotWaveCoeff(wx,L,0.);
   title(' 8 (b) Bumps ')
//
   subplot(223)
   wx = FWT_PO(HeaviSine,L,S8QMF);
   IMJPlotWaveCoeff(wx,L,0.);
   title(' 8 (c) HeaviSine ')
//
   subplot(224)
   wx = FWT_PO(Doppler,L,S8QMF);
   IMJPlotWaveCoeff(wx,L,0.);
   title(' 8 (d) Doppler ')
//axis
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig09 -- Adapt Figure 09: Haar Coefficients of the Four Functions
//
// Here we display the wavelet coefficients of the four functions,
// stratified by scale and location.  The significant coefficients
// occur in locations of significant spatial variability.  For
// locally smooth functions, the coefficients tend to be small
// at fine scales.  The coefficients do not decay with scale as 
// rapidly as the coefficients in an S8 wavelet expansion. This
// is particularly evident by comparing (Panel d) of this figure
// with (Panel d) of the previous figure.
//
mode(-1);
scf(1);clf(1);

HaarQMF = MakeONFilter('Haar');
HL = 3;
//clf;
// 
   subplot(221)
   xw = FWT_PO(Blocks,HL,HaarQMF);
   IMJPlotWaveCoeff(xw,HL,0.);
   title(' 9 (a) Haar[Blocks] ')
//
   subplot(222)
   xw = FWT_PO(Bumps,HL,HaarQMF);
   IMJPlotWaveCoeff(xw,L,0.);
   title(' 9 (b) Haar[Bumps] ')
//
   subplot(223)
   xw = FWT_PO(HeaviSine,HL,HaarQMF);
   IMJPlotWaveCoeff(xw,HL,0.);
   title(' 9 (c) Haar[HeaviSine] ')
//
   subplot(224)
   xw = FWT_PO(Doppler,HL,HaarQMF);
   IMJPlotWaveCoeff(xw,HL,0.);
   title(' 9 (d) Haar[Doppler] ')
//


halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig10 -- Adapt Figure 10: Wavelet Shrinkage of object yBlocks in Haar Basis
//
// (Panel a) depicts the noisy object yBlocks, its Haar transform (Panel c),
// wavelet shrinkage reconstruction using the Haar wavelet (Panel b), and 
// the Haar Transform of the reconstruction (Panel d).
//
// The viewer is supposed to notice that in the Haar domain, the
// noise is spread out among all coefficients, while the signal is
// concentrated in only a few coefficients. Hence thresholding mostly
// affects the noise without disturbing the signal.
//
mode(-1);
scf(1);clf(1);
//
HQMF = MakeONFilter('Haar');
HL = 3; 
[xhat,xw] = WaveShrink(yblocks,'Hybrid',HL,HQMF);
yw        = FWT_PO(yblocks,HL,HQMF);
//clf;
ax = [ 0 1 (-10) 30];
//
   versaplot(221,t,yblocks,[],' 10 (a) Noisy Data y'             ,ax,[]);
   versaplot(222,t,xhat   ,[],' 10 (b) HaarShrink Reconstruction',ax,[]);
   subplot(223); IMJPlotWaveCoeff(yw,HL,.025); title(' 10 (c) Haar[y]')
   subplot(224); IMJPlotWaveCoeff(xw,HL,.025); title(' 10 (d) Haar[Reconstruction]')
    

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig11 -- Adapt Figure 11: Simulate the SURE threshold estimation procedure
//
// (Panel a) A 128-long vector, where only the first 16 
// entries are nonzero, contaminated with Normal(0,1) noise.
// (Panel b) Reconstruction with soft thresholding chosen
// by minimizing the SURE criterion.  
// (Panel c) The SURE criterion for soft thresholding, as a
// function of the threshold. (Panel d) The actual loss of the 
// thresholding rule, as a function of thethreshold.
mode(-1);
scf(1);clf(1);
//
//   1. Create a normal vector with sparse means
//
	theta = zeros(1,128);
	theta(1:16) = 4 .* ones(1,16);
	rand('seed',0);
	x = theta + WhiteNoise(theta);
	//clf;
	n = 128;
//
//   2. Calculate the SURE curve
//
	a = mtlb_sort(abs(x)).^2 ;
	b = cumsum(a);
	n = length(x);
	c = linspace(n-1,0,n);
	s = b+c.*a;
	risk = (n - ( 2 .* (1:n ))  + s)/n;
	[guess,ibest] = min(risk);
	lambda = sqrt( a(ibest) );
	res = (abs(x) - lambda);
	res = (res + abs(res))/2;
	xhat = sign(x).*res;
//
//   3. Calculate the Loss curve
//
	loss = zeros(size(x));
	lam = sqrt(a);
	for i=1:128
		loss(i) = sum( (SoftThresh(x,lam(i)) - theta).^2 ) ./ 128;
	end
//
//   4. Display
//
	versaplot(221,1:n, x   ,[],'11(a) raw data',[0 128 -4 6],[])
	versaplot(222,1:n, xhat,[],'11(b) estimate',[0 128 -4 6],[])
	ax = [ 0 max(sqrt(a)) 0 max(risk) ];
	versaplot(223,lam, risk,[],'11(c) estimated risk versus lambda',ax,[])
	versaplot(224,sqrt(a), loss,[],'11(d) loss versus lambda',ax,[])

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig12 -- Adapt Figure 12: Simulating the behavior of various threshold rules
//
// Here we compare the behavior of several schemes for threshold
// choice, when the noise is Normal(0,1). Several Different degrees
// of sparsity are studied.
//
// (Panel a) Choice by minimizing pure SURE criterion.
// (Panel b) Choice by fixed sqrt{2 log(n)} criterion.
// (Panel c) Choice by Hybrid of (a) and (b).
// (Panel d) Choice by Hybrid on random half-samples.
//
mode(-1);
scf(1);clf(1);

NProb=1024; M=25;
rand('seed',0);
//


// EvalSure -- Performance of SURE shrinkage for varying sparsity 
// parameters C and eps
if ~exists('NProb'),
   NProb = input('Size of Problem');
end
if ~exists('M'),
   M = input('Number of Repetitions');
end
disp('in EvalSURE...')
disp(sprintf('doing %g Monte Carlo repetitions at N=%g',M,N))
disp('this could take a while ...')
SureRecords = zeros(M*13*3,3);
MedSure = zeros(13*3,3);
v = zeros(1,M); rcount=1; scount=1;
for C = [3 5 7],
   for eps = [.005 .01 .02 .04 .06 .08 .10 .12 .14 .16 .18 .20 .25],
      x = zeros(1,NProb);
      k = floor(eps*NProb);
      x(1:k) = zeros(1,k)+C;
      for m=1:M,
         y = x + WhiteNoise(x);
         xhat = SUREThresh(y);
         loss = rms(xhat-x); // root mean square!
         v(m) = loss;
         SureRecords(rcount,:) = [C eps loss]; rcount = rcount+1;
		 if modulo(rcount,10)==0, printf('.'), end 
       end
       MedSure(scount,:) = [C eps rms(v)]; scount = scount+1;
    end
end
plot(SureRecords(:,2),SureRecords(:,3).^2,'+')
title('(a) SURE Threshold')
xlabel('Epsilon')
ylabel('MSE')
     

// EvalFix -- Performance of minimax shrinkage for varying sparsity
// parameters C and eps
if ~exists('NProb'),
   NProb = input('Size of Problem');
end
if ~exists('M'),
   M = input('Number of Repetitions');
end
disp('in EvalFix ...')
disp(sprintf('doing %g Monte Carlo repetitions at N=%g',M,N))
disp('this could take a while ...')
FixRecords =  zeros( M*13*3 , 3);
MedFix =  zeros( 13*3, 3);
v = zeros(1,M); rcount = 1; scount = 1;
for C = [3 5 7],
   for eps = [.005 .01 .02 .04 .06 .08 .10 .12 .14 .16 .18 .20 .25],
      x = zeros(1,NProb);
      k = floor(eps*NProb);
      x(1:k) = zeros(1,k)+C;
      for m=1:M,
         y = x + WhiteNoise(x);
         xhat = MinMaxThresh(y);
         loss = rms(xhat-x);  // root mean square!
         v(m) = loss;
         FixRecords(rcount,:) = [C eps loss];  rcount = rcount +1;
		 if modulo(rcount,10)==0, printf('.'), end 
       end
       MedFix(scount,:) = [C eps rms(v)]; scount = scount +1;
    end
end
plot(FixRecords(:,2),FixRecords(:,3).^2,'.')
title(' (b) Fixed Threshold')
xlabel('Epsilon')
ylabel('MSE')
    
    


// EvalHybrid -- Performance of Hybrid(*) shrinkage for varying sparsity 
// parameters C and eps
if ~exists('NProb'),
   NProb = input('Size of Problem');
end
if ~exists('M'),
   M = input('Number of Repetitions');
end
disp('in EvalHybrid')
disp(sprintf('doing %g Monte Carlo repetitions at N=%g',M,N))
disp('this could take a while ...')
HybridRecords = zeros( M*13*3 , 3);
MedHybr = zeros( 13*3, 3);
v = zeros(1,M); rcount = 1; scount = 1;
for C = [3 5 7],
    for eps = [.005 .01 .02 .04 .06 .08 .10 .12 .14 .16 .18 .20 .25],
      x = zeros(1,NProb);
      k = floor(eps*NProb);
      x(1:k) = zeros(1,k)+C;
      for m=1:M,
         y = x + WhiteNoise(x);
         xhat = HybridThresh(y);
         loss = rms(xhat-x); // root mean square!
         v(m) = loss;
         HybridRecords(rcount,:) =  [C eps loss]; rcount = rcount +1;
		 if modulo(rcount,10)==0, printf('.'), end 
       end
       MedHybr(scount,:) =  [C eps rms(v)]; scount = scount +1;
    end
end
plot(HybridRecords(:,2),HybridRecords(:,3).^2,'*')

title('(c) Hybrid Thresholds')
xlabel('Epsilon')
ylabel('MSE')

//prtsc
     

// EvalRigor -- Performance of Hybrid(+) shrinkage for varying sparsity 
// parameters C and eps
if ~exists('NProb'),
   NProb = input('Size of Problem');
end
if ~exists('M'),
   M = input('Number of Repetitions');
end
disp('in EvalRigor ...')
disp(sprintf('doing %g Monte Carlo repetitions at N=%g',M,N))
disp('this could take a while ...')
PlusRecords = zeros( M*13*3 , 3);
MedPlus = zeros( 13*3, 3);
v = zeros(1,M); rcount = 1; scount = 1;
for C = [3 5 7],
    for eps = [.005 .01 .02 .04 .06 .08 .10 .12 .14 .16 .18 .20 .25],
      x = zeros(1,NProb);
      k = floor(eps*NProb);
      x(1:k) = zeros(1,k)+C;
      for m=1:M,
         y = x + WhiteNoise(x);
         xhat = RigorThresh(y);
         loss = rms(xhat-x); // root mean square!
         v(m) = loss;
         PlusRecords(rcount,:) =  [C eps loss]; rcount = rcount +1;
		 if modulo(rcount,10)==0, printf('.'), end 
       end
       MedPlus(scount,:) =  [C eps rms(v)]; scount = scount +1;
    end
end
plot(PlusRecords(:,2),PlusRecords(:,3).^2,'*')

title('(c) Hybrid(+) Thresholds')
xlabel('Epsilon')
ylabel('MSE')
//hold off
//prtsc




ax = [0 .3 0 1];
//clf;
versaplot(221,SureRecords(:,2),SureRecords(:,3).^2,'o',...
    '12 (a) SURE Threshold',ax,[]);
xlabel('Epsilon')
ylabel('root MSE')
versaplot(222,FixRecords(:,2),FixRecords(:,3).^2,'.',...
    '12 (b) Fixed Threshold',ax,[]);
xlabel('Epsilon')
ylabel('root MSE')
versaplot(223,HybridRecords(:,2),HybridRecords(:,3).^2,'*',...
    '12 (c) Hybrid(*) Threshold',ax,[]);
xlabel('Epsilon')
ylabel('root MSE')
versaplot(224,PlusRecords(:,2),PlusRecords(:,3).^2,'+',...
    '12 (d) Hybrid(+) Threshold',ax,[]);
xlabel('Epsilon')
ylabel('root MSE')
    

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig13 -- Adapt Figure 13: WaveJS Reconstructions from Noisy Data; S8 Wavelet
//
// A classical James-Stein shrinker applied in the wavelet domain
// to different resolution levels independently of one another.
//
// The results are noisier-looking than the results of the 
// nonlinear soft thresholding of wavelet coefficients.
//
mode(-1);
scf(1);clf(1);
//
	//clf;
	[xhat,xw] = WaveJS(yblocks,L,qmf);
	versaplot(221,t,xhat,[],' 13 (a) WaveJS[Blocks]',[],[])
//
	[xhat,xw] = WaveJS(ybumps,L,qmf);
	versaplot(222,t,xhat,[],' 13 (b) WaveJS[Bumps]',[],[])
//
	[xhat,xw] = WaveJS(yheavi,L,qmf);
	versaplot(223,t,xhat,[],' 13 (c) WaveJS[HeaviSine]',[],[])
//
	[xhat,xw] = WaveJS(yDoppler,L,qmf);
	versaplot(224,t,xhat,[],' 13 (d) WaveJS[Doppler]',[],[])
    

halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig14 -- Adapt Figure 14: AutoTrunc: Fourier Truncated
//            Reconstructions from Noisy Data;
//
// Here we depict a reconstruction using truncated Fourier expansions,
// in which only the low-order fourier components of the noisy signal
// are retained in reconstruction. The cut-off point for reconstruction
// in the frequency domain is automatically chosen; it is the empirical 
// minimizer of the Stein Unbiased Estimate of Risk among truncation rules.
//
mode(-1);
scf(1);clf(1);
//
	//clf;
	xhat = AutoTrunc(yblocks,1.);
	versaplot(221,t,xhat,[],' 14 (a) AutoTrunc[Blocks]',[],[])
//
	xhat = AutoTrunc(ybumps,1.);
	versaplot(222,t,xhat,[],' 14 (b) AutoTrunc[Bumps]',[],[])
//
	xhat = AutoTrunc(yheavi,1.);
	versaplot(223,t,xhat,[],' 14 (c) AutoTrunc[HeaviSine]',[],[])
//
	xhat = AutoTrunc(yDoppler,1.);
	versaplot(224,t,xhat,[],' 14 (d) AutoTrunc[Doppler]',[],[])
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// adfig15 -- Adapt Figure 15: AutoSpline: Periodic Thin-Plate spline Reconstructions
//    with automatic choice of penalty parameter;
//
//
// Here we depict a reconstruction using penalized smoothing splines,
// in which periodic thin-plate splines are used to smooth the data,
// with roughness penalty proportional to the energy stored in the
// second derivative.  The constant of proportionality (or Lagrangian
// tuning parameter) is the empirical minimizer of the Stein Unbiased
// Estimate of Risk.
//
mode(-1);
scf(1);clf(1);

//clf;
[xhat, c] = SplineUChoose(yblocks,2.);
versaplot(221,t,xhat,[],' 15 (a) AutoSpline[Blocks]',[],[])
[xhat,c] = SplineUChoose(ybumps,2.);
versaplot(222,t,xhat,[],' 15 (b) AutoSpline[Bumps]',[],[])
[xhat,c] = SplineUChoose(yheavi,2.);
versaplot(223,t,xhat,[],' 15 (c) AutoSpline[HeaviSine]',[],[])
[xhat,c] = SplineUChoose(yDoppler,2.);
versaplot(224,t,xhat,[],' 15 (d) AutoSpline[Doppler]',[],[])
    
                
    
    
      
    
     
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 

   
    
    