mode(-1);
     N = 2048;
     rho = 7;
     qmf = MakeONFilter('Symmlet',8);
     L   = 6;
 

  t = (0:(N-1))/N;
//
  HeaviSine = MakeSignal('HeaviSine',N);
  Bumps     = MakeSignal('Bumps',N);
  Blocks    = MakeSignal('Blocks',N);
  Doppler   = MakeSignal('Doppler',N);
//
  rand('seed',0);
  [xblocks,yblocks] = NoiseMaker(Blocks,rho);
  [xbumps,ybumps] = NoiseMaker(Bumps,rho);
  [xheavi,yheavi] = NoiseMaker(HeaviSine,rho);
  [xDoppler,yDoppler] = NoiseMaker(Doppler,rho);
//
  disp('Initializing Parameters:')
  disp(sprintf('N = %g',N))
  disp(sprintf('rho = %g',rho))
  disp(sprintf('L = %g',L))

function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction
function IMJPlotWaveCoeff(wavecoef,L,scal)
// IMJPlotWaveCoeff -- Wavelet Coeffts Plot: IMJ version with changed axis labelling
[n,J] = dyadlength(wavecoef); 
if scal==0, 
   seg = (1+ 2^(L)):(n);
   scal = .75 ./ max(abs(wavecoef(seg))); 
end
LockAxes([0 1  (L-1) J]); 
for j=(J-1):(-1):L
  tj = (.5:(2^(j)-.5))./2^(j) ;
  PlotSpikes(j,tj,(wavecoef(dyad(j)).*scal));
end
//xlabel('k, spatial position'); ylabel('j, resolution scale');
//title('Wavelet Decomposition');
UnlockAxes;
    

//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
endfunction


clc;mode(1);lines(0);
// asfig01 -- Asymptopia Figure 01: De-Noising of NMR Signal
//
// Here a noisy NMR signal is denoised by a simple three-step
// recipe:
//         1.  Transform to Wavelet Domain.
//         2.  Apply thresholding to set coeficients
//             ``at the noise level'' to zero
//         3.  Return to the original domain.
//
// Evidently, the noise is suppressed without brooadening the peaks.
// More traditional smoothing methods either suppress the noise and
// broaden peaks or don't suppress the noise and leave peaks narrow.
//
// These data were kindly supplied by Chris Raphael, an NSF postdoctoral
// fellow in the Statistics Department at Stanford. The original
// data came from the laboratory of Adrian Maudsley at UCSF.
//

mode(-1);  
scf(1);clf(1);
	nmrsignal  = ReadSignal('RaphaelNMR')';
	QMF6       = MakeONFilter('Symmlet',6);
	L          = 4;
//
	scalednmr  = NormNoise(nmrsignal,QMF6);
	n          = length(nmrsignal);
	tnmr       =  (1:n) ./n;
//
	y          = scalednmr ;
	rawwcoef   = FWT_PO(y,L,QMF6);
	wcoef      = rawwcoef;
//
	thr        = sqrt(2*log(length(y))) ;
	wcoef((2^(L)+1):n)      = HardThresh(rawwcoef((2^(L)+1):n),thr);
	xh         = IWT_PO(wcoef,L,QMF6);       
//
	//clf;
	versaplot(221,tnmr,y, [],' 1 (a) NMR Spectrum',[],[])
	versaplot(222,tnmr,xh,[],' 1 (b) Wavelet Shrinkage De-Noising',[],[])
	subplot(223); IMJPlotWaveCoeff(rawwcoef,L,.025); title(' 1 (c) Near Symm 6 Wavelet Coeffs')
	subplot(224); IMJPlotWaveCoeff(wcoef,L,.025); title(' 1 (d) Hard Threshold, Estimated Scale')

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig02 -- Asymptopia Figure 02: Four Spatially Inhomogenoeus Signals
//
// Here we depict four signals chosen as caricatures of signals arising
// in scientific signal processing.
//
// Blocks is a piecewise constant signal, a caricature of a scan line
// through a 2-d image depicting an object with several edges.
//
// Bumps is a very peaky signal, a caricature of an NMR Spectrum.
// 
// HeaviSine is a sinusoid with two clicks.
//
// Doppler is an attenuating sinusoid with time-varying frequency.
//
// These objects are interesting to us because they portray significant
// spatial inhomogeneity.
//
mode(-1);  
scf(1);clf(1);
//
	//clf;
	versaplot(221,t,xblocks, [],' 2 (a) Blocks '   ,[],[])
	versaplot(222,t,xbumps,  [],' 2 (b) Bumps '    ,[],[])
	versaplot(223,t,xheavi,  [],' 2 (c) HeaviSine ',[],[])
	versaplot(224,t,xDoppler,[],' 2 (d) Doppler '  ,[],[])

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig03 -- Asymptopia Figure 03: Noisy Versions of Four Signals
//
// The four objects of Figure 2 with white noise superposed.
// The noise is normally distributed with variance 1.
//
// 
mode(-1);  
scf(1);clf(1);

//
	//clf;
	versaplot(221,t,yblocks, [],' 3 (a) Noisy Blocks '   ,[],[])
	versaplot(222,t,ybumps,  [],' 3 (b) Noisy Bumps '    ,[],[])
	versaplot(223,t,yheavi,  [],' 3 (c) Noisy HeaviSine ',[],[])
	versaplot(224,t,yDoppler,[],' 3 (d) Noisy Doppler '  ,[],[])
 

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig04 -- Asymptopia Figure 04: Wavelet Shrinkage Damping of Noisy Data
//
// Here we apply the minimax thresholding rule to the
// four noisy signals depicted in Figure 3.
//
// The procedure:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a soft thresholding nonlinearity, with threshold set to
//           the magic number \lambda_n
//       3.  Transform back to the signal domain.
// 
// The reconstructions suppress the noise, while preserving the sharp structure
// in the neighborhood of the highly-variable spatial components.
//
//
mode(-1);  
scf(1);clf(1);
//
	[sbumps,shbumps]     = WaveShrink(ybumps ,'Visu',L,qmf);
	[sblocks,shblocks]   = WaveShrink(yblocks,'Visu',L,qmf);
	[sheavi,shheavi]     = WaveShrink(yheavi ,'Visu',L,qmf);
	[sDoppler,shDoppler] = WaveShrink(yDoppler,'Visu',L,qmf);
//
	//clf; 
    
	versaplot(221,t,sblocks, [],' 4 (a) Wavelet Shrinkage[Noisy Blocks] '   ,[],[])
	versaplot(222,t,sbumps,  [],' 4 (b) Wavelet Shrinkage[Noisy Bumps] '    ,[],[])
	versaplot(223,t,sheavi,  [],' 4 (c) Wavelet Shrinkage[Noisy HeaviSine] ',[],[])
	versaplot(224,t,sDoppler,[],' 4 (d) Wavelet Shrinkage[Noisy Doppler] '  ,[],[])
 
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig05 -- Asymptopia Figure 05: AutoSpline Reconstructions from Noisy Data
//
// Here we depict a reconstruction using penalized thin-plate splines,
// in which periodic thin-plate splines are used to smooth the data,
// with roughness penalty proportional to the energy stored in the
// second derivative.  The constant of proportionality (or Lagrangian
// tuning parameter) is the empirical minimizer of the Stein Unbiased
// Estimate of Risk.
//
mode(-1);  
scf(1);clf(1);
// 
//clf;
// SplineInit
//
	[xhat, c] = SplineUChoose(yblocks,2.);
	versaplot(221,t,xhat,[],' 5 (a) AutoSpline[Blocks]',[],[])
//
	[xhat,c] = SplineUChoose(ybumps,2.);
	versaplot(222,t,xhat,[],' 5 (b) AutoSpline[Bumps]',[],[])
//
	[xhat,c] = SplineUChoose(yheavi,2.);
	versaplot(223,t,xhat,[],' 5 (c) AutoSpline[HeaviSine]',[],[])
//
	[xhat,c] = SplineUChoose(yDoppler,2.);
	versaplot(224,t,xhat,[],' 5 (d) AutoSpline[Doppler]',[],[])

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig06 -- Asymptopia Figure 06: AutoTrunc Truncated Fourier Reconstructions
//
// Here we depict a reconstruction using truncated Fourier expansions,
// in which only the low-order fourier components of the noisy signal
// are retained in reconstruction. The cut-off point for reconstruction
// in the frequency domain is the empirical minimizer of the Stein Unbiased
// Estimate of Risk.
mode(-1);  
scf(1);clf(1);
//
	//clf;
	xhat = AutoTrunc(yblocks,1.);
	versaplot(221,t,xhat,[],' 6 (a) AutoTrunc[yBlocks]',[],[])
//
	xhat = AutoTrunc(ybumps,1.);
	versaplot(222,t,xhat,[],' 6 (b) AutoTrunc[yBumps]',[],[])
//
	xhat = AutoTrunc(yheavi,1.);
	versaplot(223,t,xhat,[],' 6 (c) AutoTrunc[yHeaviSine]',[],[])
//
	xhat = AutoTrunc(yDoppler,1.);
	versaplot(224,t,xhat,[],' 6 (d) AutoTrunc[yDoppler]',[],[])

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig07 -- Asymptopia Figure 07: Unconditional Bases and Mutilation of Coefficients
//
// Here we show the effect of ``multilating'' the empirical coefficients
// of object blocks in each of several orthogonal bases.
//
// By multilation, we mean that for all coefficients beyond
// number 32, we replace the real and imaginary parts of
// of the coefficients by their positive parts
//
// While this is an operation that ``shrinks'' the coefficients
// in size, it can result, in the Fourier Case, with a substantially
// ``wilder'' looking object.  In contrast, ``shrinkage'' of wavelet
// coefficients does not make the result ``wilder''than the original.
//
mode(-1);  
scf(1);clf(1);

//
	//clf; 
	subplot(221);
	a=gca();a.data_bounds=([0 1 -10 20]);
	L = 6; qmfHaar = MakeONFilter('Haar');
	hblocks = FWT_PO(xblocks,L,qmfHaar);
	plot(t, xblocks); 
	title( '7(a) Blocks');
//
	fblocks = Wavelab_fft(xblocks);
	seg = 2^(L);
	Int = (seg + 1) : (2048 - seg);
	tempr = ( real(fblocks(Int)) + abs(real(fblocks(Int))) )./ 2;
	tempi = ( imag(fblocks(Int)) + abs(imag(fblocks(Int))) )./ 2;
	ffblocks = fblocks;
	ffblocks(Int) = tempr + %i* tempi;
	xfblocks = Wavelab_ifft(ffblocks);
	subplot(222)
	plot(t, real(xfblocks));
	title( '7(b) Fourier mutilation');
//
	details = ((2^L) + 1):2048;
	hhblocks = hblocks;
	hhblocks(details) = ( abs(hblocks(details)) + hblocks(details) ) ./ 2;
	xhblocks = IWT_PO(hhblocks,L,qmfHaar);
	subplot(223)
	plot(t, xhblocks);
	title( '7(c) Haar wavelet mutilation');
//
	qmfS8 = MakeONFilter('Symmlet',8);
	xw = FWT_PO(xblocks,L,qmfS8);
	details = ((2^L) + 1):2048;
	xxw = xw;
	xxw(details) = ( abs(xw(details)) + xw(details) ) ./ 2;
	sblocks = IWT_PO(xxw, L, qmfS8);
	subplot(224)
	plot(t, sblocks);
	title( '7(d) NearSymm8 Wavelet mutilation');

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig08 -- Asymptopia Figure 08: Smoothing Good-Gaskins data
//  
// Here we illustrate the application of wavelet thresholding to Poisson
// Counts data. The Good-Gaskins 1980 scattering data are transformed by the Anscombe 
// variance-stabilizing transformation for poisson data, which are
// then processed exactly as if the data obeyed the white noise model.
//
// Note that for these data, the wavelet result is very closely comparable
// to the result that Good and Gaskins obtained by 
//
mode(-1);  
scf(1);clf(1);

	//load scatter
demopath = get_absolute_file_path("AsympDemo.sce");
loadmatfile(demopath+"/scatter.mat");

	y = 2.*sqrt(scatter + .375);
	t =(-135):10:(-135+255*10); 
	QMF_Filter = MakeONFilter('Coiflet',3);
	[xh,wcoef] = WaveShrink(y,'Visu',5,QMF_Filter);
//
	//clf;  
   // load goodfit;
demopath = get_absolute_file_path("AsympDemo.sce");
loadmatfile(demopath+"/goodfit.mat");
	rootgood = 2*sqrt(goodfit+.375);
//	versaplot(311,t,y,[],'(a) Root-o-Gram of Good-Gaskins Scattering Counts',[],[])
//	versaplot(312,t,xh,[],'(b) Wavelet Shrinkage'           ,[],[])
//	versaplot(313,t,2*sqrt(goodfit + .375),[],'(b) Good-Gaskins Estimate'           ,[],[])
	versaplot(311,t,y,   [],'8 (a) Roots of Good-Gaskins Scattering Counts',[],[])
	versaplot(312,t,xh,  [],'8 (b) Wavelet Shrinkage of Rooted Counts'     ,[],[])
	versaplot(313,t,y-xh,[],'8 (c) Rootogram of Residuals'                 ,[],[])

   halt("press a key to proceed!");
clc;mode(1);lines(0);
//	
// asfig09 -- Asymptopia Figure 09: Comparison to Good-Gaskins Smoother
//  
// Here we illustrate the application of wavelet thresholding to Poisson
// Counts data. The Good-Gaskins 1980 scattering data are transformed by the Anscombe 
// variance-stabilizing transformation for poisson data, which are
// then processed exactly as if the data obeyed the white noise model.
//
// Note that for these data, the wavelet result is very closely comparable
// to the result that Good and Gaskins obtained by using computationally
// much more challenging methods.
//
//
	mode(-1);  
scf(1);clf(1);
    
    	//load scatter
	y = 2.*sqrt(scatter + .375);
	t =(-135):10:(-135+255*10); 
	QMF_Filter = MakeONFilter('Coiflet',3);
	[xh,wcoef] = WaveShrink(y,'Visu',5,QMF_Filter);
//
	//clf;  
    //load goodfit;
	rootgood = 2*sqrt(goodfit+.375);

	versaplot(311,t,xh,[],'9 (a) Wavelet Shrinkage (-);  Good&Gaskins (..)',[],1)
	versaplot(311,t,rootgood,'-.',[],[],0)
	versaplot(312,t,xh-rootgood,[],'9 (b) Wavelet-Good&Gaskins'  ,[],[])
	versaplot(325,t,xh,[],'9 (c) Closeup ',[500 900 20 60],1);
	versaplot(325,t,rootgood,'-.',[],[],1);
	versaplot(325,t,y,'.',[],[],0);
	versaplot(326,t,xh,[],'9 (d) Closeup ',[1000 1400 20 40],1);
	versaplot(326,t,rootgood,'-.',[],[],1);
	versaplot(326,t,y,'.',[],[],0);
	

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// asfig10 -- Asymptopia Figure 10: Compare various thresholds; ESCA data
//
// Here we illustrate the application of wavelet thresholding to Poisson
// Counts data.  An ESCA spectrum with millions of counts is used as
// a ``true'' object, and an empirical spectrum with maximum 4000 counts/bin
// is simulated from it. This simulated spectrum is transformed by the Anscombe
// variance-stabilizing transformation for poisson data, which are
// then processed as in the white noise model.
//
// The point here is to compare several different thresholding rules
// to give an idea how soft, hard, minimax and adaptive thresholding
// might differ.
//
mode(-1);  
scf(1);clf(1);

function n = fishrand(intens,overpar)
// fishrand -- generate Poisson random vector, with given intensity
//  Usage
//    n = fishrand(intens,overpar)
//  Inputs
//    intens    vector of poisson intensities
//    overpar   real number
//  Outputs
//    n         vector of pseudo-Poisson random #'s
//  Description
//    An sequence of approximately Poisson random counts is generated;
//    the output vector n(i) counts successes in N trials at probability p(i),
//    where N = (overpar*max(max(intens))) and p = intens ./ N.  By the
//    the theorem of Posson approximation to the Binomial, these counts
//    have nearly a Poisson distribution if overpar is large.
//
//    Prepared as part of the paper ``Wavelet Shrinkage: Asymptopia'', by
//    Donoho, Johnstone, Kerkyacharian, and Picard.
//  See Also
//    asfig10

	if argn(2) < 2,
	  overpar = 50;
	end
//
	maxintens = max(max(intens));
	u = zeros(1,overpar*maxintens);
	p = intens ./ (overpar*maxintens);
	n = zeros(intens);
	for i=1:max(size(n)),
		if modulo(i,10) == 1, 
			i, 
		end
	   u = (rand(u) < p(i));
	   n(i) = sum(u);
	end
endfunction

    esca = ReadSignal('ESCA');
    intens = 4000 .* esca ./ max(max(esca));
// 	if exist('ESCAsim.mat'),
// 		disp('File ESCAsim.mat exists -- loading')
// 		load ESCAsim   // faster than simulating
// 	else
// 		disp('File ESCAsim.mat ~exist -- calculating')
// 		disp('This could take a while')
		counts = fishrand(intens,10);  // poisson variate generator
// 	end

    y = 2.*sqrt(counts + .375);
    t = 1:length(counts);
//
	[nn,J] = dyadlength(y) ; L =4;
	rwc = FWT_CDJV(y,L,3) ; swc = rwc; hwc = rwc; suwc = rwc;
//
	suwc = MultiSURE(suwc',L);
	swc((2^(L)+1):nn) = SoftThresh(swc((2^(L)+1):nn),sqrt(2*log(nn))) ;
	hwc((2^(L)+1):nn) = HardThresh(hwc((2^(L)+1):nn),sqrt(2*log(nn))) ;

//
	surerecon    = IWT_CDJV(suwc,L,3);
	softrecon    = IWT_CDJV( swc,L,3);
	hardrecon    = IWT_CDJV (hwc,L,3);

//
	//clf;
    ax  = [400 900 50 140];
	versaplot(512,t,y,[],        '10 (b) Rooted Count',ax,[])
	versaplot(513,t,surerecon,[],'10 (c) SURE Shrink' ,ax,[])
	versaplot(515,t,softrecon,[],'10 (d) Soft Thresh' ,ax,[])
	versaplot(514,t,hardrecon,[],'10 (e) Hard Thresh' ,ax,[])
	versaplot(511,t,2*sqrt(intens),[],'10 (a) Root Intensity',ax,[])
//  