mode(-1);
// MakeAllFilters -- Create AI Filters and Edge Filters
Fil2 = MakeAIFilter(2); Fil4 = MakeAIFilter(4);
Fil6 = MakeAIFilter(6); Fil8 = MakeAIFilter(8);
// MakeBdryFilters

EdgeFil2 = MakeAIBdryFilter(2); 
EdgeFil4 = MakeAIBdryFilter(4);
EdgeFil6 = MakeAIBdryFilter(6); 
EdgeFil8 = MakeAIBdryFilter(8);

function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction


clc;mode(1);lines(0);
// aifig1 -- Average-Interpolating Refinement of a sequence of averages.
//
// The figure shows (as a step function) the block averages 
// of the function sin(t), and (as dashed and dotted curves)
// several average-interpolating refinements to a resolution
// 5 scales finer.
//
// At the resolution of the plotting device, all of the refinements 
// are equal to the true underlying function, and are much closer to 
// that function than the piecewise constant function. 
//
mode(-1);  
scf(1);clf(1);
//
t = (0:63) ./16 - 2;
ave = 16  .*(cos(t) - cos(t +1/16.));
Blocks = ave;
MaxOrd=8;
dt = t(2)-t(1);
vb = [ Blocks ; Blocks ]; vb = vb(:);
tb = [t ; (t+dt) ]; tb = tb(:);
//clf;

subplot(1,1,1)
plot(tb,vb)
title('1. Interpolating Averages of sin(t)')
//axis([0 1 0 1]); 
xlabel('t')
//
a = Blocks;
for j=1:5, 
  a = AIRefine(a,2,Fil2,EdgeFil2); 
end;
t = 4 * (0:(length(a)-1)) ./ length(a) - 2;
plot(t,a,'--')
//
a = Blocks;
for j=1:5, 
  a = AIRefine(a,4,Fil4,EdgeFil4); 
end;
plot(t,a,'-.')
//
if(MaxOrd > 6),
a = Blocks;
for j=1:5, 
  a = AIRefine(a,8,Fil8,EdgeFil8); 
end;
plot(t,a,':')
end;
UnlockAxes


   halt("press a key to proceed!");
clc;mode(1);lines(0);
// aifig2 -- Fundamental Solutions of Average-Interpolation
//
// Results of average-interpolating the Kronecker
// sequence. (Panel a) Average-Interpolation of Degree D=2.
// (Panel b) D=4. (Panel c) D=6. (Panel d) D=8.
//
//
mode(-1);  
scf(1);clf(1);
//
nref = 5;
kronecker = zeros(1,16);
kronecker(9) = 1;
//
//  D=2
//
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,2,Fil2,EdgeFil2); 
   end;
   t = 16*(0:(length(a)-1)) ./ length(a) -8;  
   versaplot(221,t,a,[],'2(a) AI Fundamental Soln., D=2',[],[])
   a2 =a;
//
//  D=4
//
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,4,Fil4,EdgeFil4); 
   end;
   versaplot(222,t,a,[],'2(b) AI Fundamental Soln., D=4',[],[])
   a4=a;
//
//  D=6
//
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,6,Fil6,EdgeFil6); 
   end;
   versaplot(223,t,a,[],'2(c) AI Fundamental Soln., D=6',[],[])
   a6=a;
//
//  D=8
//
   kronecker = zeros(1,32);
   kronecker(17) = 1;
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,8,Fil8,EdgeFil8); 
   end;
   t = (0 : (length(a)-1)) .* 32 ./ (length(a)) - 16;
   inx = (t >= -8) & (t < 8); a8=a;
   versaplot(224,t(inx),a(inx),[],'2(d) AI Fundamental Soln., D=8',[],[])
   a8=a;
//
UnlockAxes;
    
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// aifig3 -- AI Wavelets
//
// The result of average-interpolating a sequence which
// consists of (-1,1) in a sea of zeros.
//
// 
mode(-1);  
scf(1);clf(1);
//
nref = 4;
kronecker = zeros(1,32);
kronecker(17) = -1; kronecker(18) = 1;
//
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,2,Fil2,EdgeFil2); 
   end;
   t = 16*(0:(length(a)-1)) ./ length(a) -8;  
   versaplot(221,t,a,[],'3(a) AI Wavelet, D=2',[],[]) ; 
   a2 =a;
//
//  D=4
//
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,4,Fil4,EdgeFil4); 
   end;
   versaplot(222,t,a,[],'3(b) AI Wavelet, D=4',[],[]); 
   a4=a;
//
//  D=6
//
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,6,Fil6,EdgeFil6); 
   end;
   versaplot(223,t,a,[],'3(c) AI Wavelet, D=6',[],[]) ; 
   a6=a;
//
//  D=8
//
   kronecker = zeros(1,64);
   kronecker(33) = -1; kronecker(34) = 1;
   a = kronecker;
   for j=1:nref, 
     a = AIRefine(a,8,Fil8,EdgeFil8); 
   end;
   t = (0 : (length(a)-1)) .* 32 ./ (length(a)) - 16;
   inx = (t >= -8) & (t < 8); a8=a;
   versaplot(224,t(inx),a(inx),[],'3(d) AI Wavelet, D=8',[],[])

     halt("press a key to proceed!");
clc;mode(1);lines(0);  
// aifig4 -- The Dual Functions
//
// These functions are dual to the wavelets of the previous
// figure, in that integration of a function f against these
// functions gives the coefficients in the wavelet expansion
// using the corresponding AI wavelets.
//
mode(-1);  
scf(1);clf(1);
//
 nref = 5;
v = zeros(4,32);
kronecker = zeros(1,32);
kronecker(18) = 1;
// Order D=2
D = 2;
a = 2.* kronecker;
for k=(-D/2):(D/2),
  a(17+2*k) = a(17+2*k) - Fil2(1 + D + 2*k);
  a(18+2*k) = a(18+2*k) - Fil2(1 + D + 2*k);
end
// D, a 
v(1,:) = a;  
for j=1:nref, 
  a = [a ; a]; 
  a = matrix(a,1,prod(size(a)));
end;
t = 16*(0:(length(a)-1)) ./ length(a) -8;  
inx = (t >= -5) & (t < 5);
subplot(221);
plot(t(inx),a(inx)) ; 
title('4(a) Dual AI Wavelet D=2')

D = 4;
a = 2 .* kronecker;
for k=(-D/2):(D/2),
  a(17+2*k) = a(17+2*k) - Fil4(1 + D + 2*k);
  a(18+2*k) = a(18+2*k) - Fil4(1 + D + 2*k);
end
// D, a 
v(2,:) = a;       
for j=1:nref, 
  a = [a ; a]; 
  a = matrix(a,1,prod(size(a)));
end;
subplot(222);
plot(t(inx),a(inx)) ; 
title('4(b) Dual, D=4')

D = 6;
a = 2 .* kronecker;
for k=(-D/2):(D/2),
  a(17+2*k) = a(17+2*k) - Fil6(1 + D + 2*k);
  a(18+2*k) = a(18+2*k) - Fil6(1 + D + 2*k);
end
// D, a
v(3,:) = a;        
for j=1:nref, 
  a = [a ; a]; 
  a = matrix(a,1,prod(size(a)));
end;
subplot(223);
plot(t(inx),a(inx)) ; 
title('4(c) Dual, D=6')

D = 8;
a = 2.* kronecker;
for k=(-D/2):(D/2),
  a(17+2*k) = a(17+2*k) - Fil8(1 + D + 2*k);
  a(18+2*k) = a(18+2*k) - Fil8(1 + D + 2*k);
end
//D, a
v(4,:) = a;       
for j=1:nref, 
  a = [a ; a]; 
  a = matrix(a,1,prod(size(a)));
end;
t = 16*(0:(length(a)-1)) ./ length(a) -8;
subplot(224);
plot(t(inx),a(inx)) ; 
title('4(d) Dual, D=8')


       halt("press a key to proceed!");
clc;mode(1);lines(0);
// aifig5 -- Show Boundary Wavelets
//
// This figure displays some boundary wavelets and
// corresponding wavelets at the interior of the 
// interval.  The wavelets at the ``heart'' of the 
// interval are the same as the non-boundary adjusted 
// wavelets.  The wavelets at the ``ends'' are modified
// to maintain polynomial exactness and related 
// properties.
//
mode(-1);  
scf(1);clf(1);
//
//  D=2 Boundary Wavelets
//
    
   subplot(221); 
   LockAxes([0 1 -20 20]);
   for j= [1 2  5 7 8],
    a = zeros(1,8); 
    a(j) = 1; 
    for k=1:5, 
      a = AIRefine(a,2,Fil2,EdgeFil2); 
    end;
    t = (0:255) ./256; 
    if j==1, pch = '-.'; end
    if j==2, pch = '--'; end
    if j==5, pch = '-'; end
    if j==7, pch ='--'; end
    if j==8, pch = '-.'; end
    plot(t,8 .*a, pch); 
   end
   title('5(a) Interval Wavelets phi_{3,k}, D=2'); 
   UnlockAxes;
//
//  D=4
//
subplot(222); 
LockAxes([0 1 -20 20]);
for j= [1 2  9 15 16],
a = zeros(1,16); 
a(j) = 1; 
for k=1:5, 
  a = AIRefine(a,4,Fil4,EdgeFil4); 
end;
t4 = (0:(length(a)-1)) ./length(a); 
if j==1, pch = '-.'; end
if j==2, pch = '--'; end
if j==9, pch = '-'; end
if j==15, pch ='--'; end
if j==16, pch = '-.'; end
plot(t4,8 .*a, pch); 
end
title('5 (b) Interval Wavelets phi_{4,k}, D=4');
UnlockAxes;
//
//  D=6
//
subplot(223); 
LockAxes([0 1 -20 20]); 
for j= [1 2  5 7 8],
a = zeros(1,16); 
a(2*j) = 1; a(2*j-1) = -1; 
for k=1:4, 
  a = AIRefine(a,2,Fil2,EdgeFil2); 
end;
t = (0:255) ./256; 
if j==1, pch = '-.'; end
if j==2, pch = '--'; end
if j==5, pch = '-'; end
if j==7, pch ='--'; end
if j==8, pch = '-.'; end
plot(t,8 .*a, pch); 
end
title('5 (c) Interval Wavelets psi_{3,k}, D=2');
UnlockAxes;
//
//  D=8
//
subplot(224); 
LockAxes([0 1 -20 20]); 
for j= [1 2  9 15 16],
a = zeros(1,32); 
a(2*j) = 1; a(2*j-1) = -1; 
for k=1:4, 
  a = AIRefine(a,4,Fil4,EdgeFil4); 
end;
if j==1, pch = '-.'; end
if j==2, pch = '--'; end
if j==9, pch = '-'; end
if j==15, pch ='--'; end
if j==16, pch = '-.'; end
plot(t4,8 .*a, pch); 
end
title('5 (d) Interval Wavelets psi_{4,k}, D=4');
UnlockAxes
    
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// aifig6 -- Depict 2-d Average-Interpolation
//
// (Panel a) A set of 2-d block averages at a fine scale,
// (Panel b) a set of 2-d block averages two scales coarser,
// (Panel c) Refinement of the coarse-scale averages (D=2)
// (Panel c) Refinement of the coarse-scale averages (D=4)
//
// Refinement of the coarse-scale information nearly reproduces
// the original fine-scale data.
//
mode(-1);  
scf(1);clf(1);
//
n = 64; lev=2;
[x,y] = ...
meshgrid((-.501+1/(2*n)):(1/n):(.501-1/(2*n)),(-.5+1/(2*n)):(1/n):(.5-1/(2*n)));
y = flipud(y);
r = sqrt(x .^2 + y .^2);
subplot(221)
sr = (sin(5 .*(r)) ./ (5 .*(r))).^2; clear r x y;
mesh(sr); title('6(a) Averages of (sin(5r)/(5r))^2,  Fine scale, j=6')
csr = HCoarsen2d(sr,lev);
clear sr;
Hsr = HRefine2d(csr,lev);
subplot(222);
mesh(Hsr); title('6(b) Averages at Coarse scale, j=4')
clear Hsr; 
Rsr2 = AIRefine2d(csr,lev,2,Fil2,EdgeFil2);
subplot(223);
mesh(Rsr2); title('6(c) D=2 Interpolation from Coarse to Fine') 
clear Rsr2;
Rsr4 = AIRefine2d(csr,lev,4,Fil4,EdgeFil4);
subplot(224);
mesh(Rsr4); title('6(d) D=4 Interpolation from Coarse to Fine');
    
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// aifig7 -- Noisy Differentiation
//
// Here we illustrate the use of wavelets for noisy differentiation.
// (Panel a) displays object Bumps, (panel b) its noisy cumulative, 
// and (Panel c) a naive inversion based on differencing. 
//
// The naive inversion is very noisy and displays only a hint of the 
// structure of the underlying function.
//
// We also display a wavelet-shrinkage reconstruction, in which noise is
// suppressed while the structure remains. 
//
// The wavelet-shrinkage reconstruction goes as follows
//
//       1.  Transform the naive reconstruction into the wavelet domain.
//       2.  Apply level-dependent thresholds which scale inversely with 
//           resolution.
//       3.  Return to the wavelet domain.
//
//  Coiflets with 3 vanishing moments are used.
//
mode(-1);  
scf(1);clf(1);
	n = 2048;
	t = (.5:(n-.5)) ./ n;
	Bumps = MakeSignal('Bumps',n);
//
// Build Noisy Primitive
//
	zBumps = cumsum(Bumps);
	x      = zBumps + rand(zBumps);
//
//  Naive Reconstruction
//
	z = diff([0 x]);
//
// Wavelet Shrinkage
//
	QSymm6 = MakeONFilter('Symmlet',6);
	w      = FWT_PO(z, 5, QSymm6);
	ws     = InvShrink(w,5,4,1);
	zrec   = IWT_PO(ws,5,QSymm6);
//
// Display Results

	subplot(221); plot(t,Bumps); title('7 (a) Object Bumps')
	subplot(222); plot(t,x);     title('7 (b) Noisy Primitive')
	subplot(223); plot(t,z);     title('7 (c) Naive Reconstruction via Differences')
	subplot(224); plot(t,zrec);  title('7 (d) Wavelet De-Noising Reconstruction')
    
    
    