mode(-1);


function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction

	     N = 2048;

	     rho = 7;

	t = (0:(N-1))/N;
//
	disp('Initializing Parameters:')
	disp(sprintf('N = %g',N))
	disp(sprintf('rho = %g',rho))
//
	HeaviSine = MakeSignal('HeaviSine',N);
	Bumps     = MakeSignal('Bumps',N);
	Blocks    = MakeSignal('Blocks',N);
	Doppler   = MakeSignal('Doppler',N);
//
	[xblocks,yblocks] = NoiseMaker(Blocks,rho);
	[xbumps,ybumps]   = NoiseMaker(Bumps,rho);
	[xheavi,yheavi]   = NoiseMaker(HeaviSine,rho);
	[xDoppler,yDoppler] = NoiseMaker(Doppler,rho);
//
	n = N;
	QuadChirp = MakeSignal('QuadChirp',n);
	MishMash  = MakeSignal('MishMash',n);
//
	[xQuad,yQuad]       = NoiseMaker(QuadChirp,rho);
	[xMish,yMish]       = NoiseMaker(MishMash,rho);

clc;mode(1);lines(0);
// cspinf01 -- Four Spatially Inhomogeneous Signals
//
// These four signals are caricatures of signals arising
// in scientific signal processing.
//
// Blocks is a piecewise constant signal, a caricature of a scan line
// through a 2-d image depicting an object with several edges.
//
// Bumps is a very peaky signal, a caricature of an NMR Spectrum.
// 
// HeaviSine is a sinusoid with two clicks.
//
// Doppler is an attenuating sinusoid with time-varying frequency.
//
// These objects are interesting to us because they portray significant
// spatial inhomogeneity.
//
mode(-1);  
scf(1);clf(1);
//
// clf;
versaplot(221,t,xblocks, [],' 1 (a) Blocks '   ,[],[])
versaplot(222,t,xbumps,  [],' 1 (b) Bumps '    ,[],[])
versaplot(223,t,xheavi,  [],' 1 (c) HeaviSine ',[],[])
versaplot(224,t,xDoppler,[],' 1 (d) Doppler '  ,[],[])

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf02 -- Noisy Versions of Four Signals
//
// The four objects of Figure 1 with white noise superposed.
// The noise is normally distributed with variance 1.
//
// 
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	versaplot(221,t,yblocks, [],' 2 (a) Noisy Blocks '   ,[],[])
	versaplot(222,t,ybumps,  [],' 2 (b) Noisy Bumps '    ,[],[])
	versaplot(223,t,yheavi,  [],' 2 (c) Noisy HeaviSine ',[],[])
	versaplot(224,t,yDoppler,[],' 2 (d) Noisy Doppler '  ,[],[])
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf03 -- Ordinary S8 Wavelet Shrinkage
//             Symmlet 8 Shrinkage of the Four Noisy Signals
//
// Ordinary SOFT Threshold Wavelet Shrinkage of the Four Noisy Signals
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a SOFT thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
//  
//
//  Remark: run SpinCycleInit and cspinf0[12] before this.
//
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
	nxblocks  = 0;
	nxbumps   = 0;
	nxheavi   = 0;
	nxDoppler = 0;
	FirstOnly = 1;
//
	nspin =1;  // ONLY LOOK AT SHIFT 0
	for i=0:(nspin-1),		
		[chblocks]  = cyclespin(yblocks,  i);
		[chbumps]   = cyclespin(ybumps,   i);
		[chheavi]   = cyclespin(yheavi,   i);
		[chDoppler] = cyclespin(yDoppler, i);
//
		[dhblocks]  = WaveShrink(chblocks,  'Visu',L,QMF_Filter);
		[dhbumps]   = WaveShrink(chbumps,   'Visu',L,QMF_Filter);
		[dhheavi]   = WaveShrink(chheavi,   'Visu',L,QMF_Filter);
		[dhDoppler] = WaveShrink(chDoppler, 'Visu',L,QMF_Filter);
//
		[dhblocks]  = cyclespin(dhblocks,  -i);
		[dhbumps]   = cyclespin(dhbumps,   -i);
		[dhheavi]   = cyclespin(dhheavi,   -i);
		[dhDoppler] = cyclespin(dhDoppler, -i);
//
		[xhblocks]  = xhblocks  + dhblocks;
		[xhbumps]   = xhbumps   + dhbumps;
		[xhheavi]   = xhheavi   + dhheavi;
		[xhDoppler] = xhDoppler + dhDoppler;
//
		if i==0,
			[zblocks]  = dhblocks;
			[zbumps]   = dhbumps;
			[zheavi]   = dhheavi;
			[zDoppler] = dhDoppler;
		end
//
		if i==0 | (i > 0 & ~FirstOnly),
			nxblocks = nxblocks  + norm(dhblocks-xblocks).^2;
			nxbumps  = nxbumps   + norm(dhbumps-xbumps).^2;
			nxheavi  = nxheavi   + norm(dhheavi-xheavi).^2;
			nxDoppler= nxDoppler + norm(dhDoppler-xDoppler).^2;
		end
//
	end
//
	[xhblocks]  = xhblocks/nspin;
	[xhbumps]   = xhbumps/nspin;
	[xhheavi]   = xhheavi/nspin;
	[xhDoppler] = xhDoppler/nspin;
//
	if FirstOnly, denom=1; else, denom=nspin; end
	nxblocks = sqrt(nxblocks/denom);
	nxbumps  = sqrt(nxbumps/denom);
	nxheavi  = sqrt(nxheavi/denom);
	nxDoppler= sqrt(nxDoppler/denom);
//
	if FirstOnly, 
		labelstr = 'RMS(Soft,S8,Orig)'; 
	else, 
		labelstr = 'Root(Ave(MSE(Soft,Shifted)))';
	end
//
	printf('Blocks:     %s = %g \n',labelstr,nxblocks)
	printf('Bumps :     %s = %g \n',labelstr,nxbumps)
	printf('HeaviSine:  %s = %g \n',labelstr,nxheavi)
	printf('Doppler:    %s = %g \n',labelstr,nxDoppler)
//
//
// 	figure;
	versaplot(221,t,zblocks, [],'  3 (a) S8,VisuShrink[yBlocks] '   ,[],[])
	versaplot(222,t,zbumps,  [],'  3 (b) S8,VisuShrink[yBumps] '    ,[],[])
	versaplot(223,t,zheavi,  [],'  3 (c) S8,VisuShrink[yHeaviSine] ',[],[])
	versaplot(224,t,zDoppler,[],'  3 (d) S8,VisuShrink[yDoppler] '  ,[],[])
//
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf04 -- Cycle Spinning S8 Wavelet Shrinkage
//
// Here we test an idea of R.R. Coifman, which he calls
// cycle-spinning.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// We apply a specific thresholding rule to the
// four noisy signals depicted in Figure 2.
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a SOFT thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  We do this at each of 16 circulant shifts of a signal and
//  then average the results.
//  
//  Errors are compared with applying this algorithm at one single shift.
//
//  Remark: run SpinCycleInit and cspinf0[12] before this.
//
//  Agenda:  Compare Hard Thresholding
//           Compare ordinary VisuShrink
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
	nxblocks  = 0;
	nxbumps   = 0;
	nxheavi   = 0;
	nxDoppler = 0;
	FirstOnly = 1;
//
	nspin =16;
	for i=0:(nspin-1),		
		[chblocks]  = cyclespin(yblocks,  i);
		[chbumps]   = cyclespin(ybumps,   i);
		[chheavi]   = cyclespin(yheavi,   i);
		[chDoppler] = cyclespin(yDoppler, i);
//
		[dhblocks]  = WaveShrink(chblocks,  'Visu',L,QMF_Filter);
		[dhbumps]   = WaveShrink(chbumps,   'Visu',L,QMF_Filter);
		[dhheavi]   = WaveShrink(chheavi,   'Visu',L,QMF_Filter);
		[dhDoppler] = WaveShrink(chDoppler, 'Visu',L,QMF_Filter);
//
		[dhblocks]  = cyclespin(dhblocks,  -i);
		[dhbumps]   = cyclespin(dhbumps,   -i);
		[dhheavi]   = cyclespin(dhheavi,   -i);
		[dhDoppler] = cyclespin(dhDoppler, -i);
//
		[xhblocks]  = xhblocks  + dhblocks;
		[xhbumps]   = xhbumps   + dhbumps;
		[xhheavi]   = xhheavi   + dhheavi;
		[xhDoppler] = xhDoppler + dhDoppler;
//
		if i==0,
			[zblocks]  = dhblocks;
			[zbumps]   = dhbumps;
			[zheavi]   = dhheavi;
			[zDoppler] = dhDoppler;
		end
//
		if i==0 | (i > 0 & ~FirstOnly),
			nxblocks = nxblocks  + norm(dhblocks-xblocks).^2;
			nxbumps  = nxbumps   + norm(dhbumps-xbumps).^2;
			nxheavi  = nxheavi   + norm(dhheavi-xheavi).^2;
			nxDoppler= nxDoppler + norm(dhDoppler-xDoppler).^2;
		end
//
	end
//
	[xhblocks]  = xhblocks/nspin;
	[xhbumps]   = xhbumps/nspin;
	[xhheavi]   = xhheavi/nspin;
	[xhDoppler] = xhDoppler/nspin;
//
	if FirstOnly, denom=1; else, denom=nspin; end
	nxblocks = sqrt(nxblocks/denom);
	nxbumps  = sqrt(nxbumps/denom);
	nxheavi  = sqrt(nxheavi/denom);
	nxDoppler= sqrt(nxDoppler/denom);
//
	if FirstOnly, 
		labelstr = 'RMS(Soft,Orig)'; 
	else, 
		labelstr = 'Root(Ave(MSE(Soft,Shifted)))';
	end
//
	printf('Blocks:    RMS(Soft,CSpin) =%g %s = %g \n',norm(xhblocks-xblocks),labelstr,nxblocks)
	printf('Bumps :    RMS(Soft,CSpin) =%g %s = %g \n',norm(xhbumps-xbumps),labelstr,nxbumps)
	printf('HeaviSine: RMS(Soft,CSpin) =%g %s = %g \n',norm(xhheavi-xheavi),labelstr,nxheavi)
	printf('Doppler:   RMS(Soft,CSpin) =%g %s = %g \n',norm(xhDoppler-xDoppler),labelstr,nxDoppler)
//
// 	figure;
	versaplot(221,t,xhblocks, [],'  4 (a) Soft,SpinCycle[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],'  4 (b) Soft,SpinCycle[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],'  4 (c) Soft,SpinCycle[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],'  4 (d) Soft,SpinCycle[yDoppler] '  ,[],[])

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf05 -- Fully Translation-Invariant S8 Wavelet Shrinkage
//             Wavelet Shrinkage of the Four Noisy Signals
//
// Here we test fully translation-invariant denoising, using
// the Stationary Wavelet Transform.  This is a method of removing artifacts
// from wavelet thresholding associated with discontinuities and singularities.
// We apply a specific thresholding rule to the four noisy signals depicted in Figure 2.
//
// The procedure for DeNoising:
//       1.  Translation-Invariant Transform to Wavelet Domain, 
//			Using Nearly-Symmetric Wavelet with 8 vanishing moments.
//       2.  Apply a Hard thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  Remark: run SpinCycleInit and cspinf0[12] before this.
//
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;  thr = sqrt(2* log(n));
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
		[tiwtblocks]  = FWT_TI(yblocks,  L,QMF_Filter);
		[tiwtbumps]   = FWT_TI(ybumps,   L,QMF_Filter);
		[tiwtheavi]   = FWT_TI(yheavi,   L,QMF_Filter);
		[tiwtDoppler] = FWT_TI(yDoppler, L,QMF_Filter);
//
		[nrow,ncol]  = size(tiwtblocks);
		thrwtblocks  = tiwtblocks;
		thrwtblocks(:,2:ncol) = SoftThresh(thrwtblocks(:,2:ncol),thr);
		thrwtbumps  = tiwtbumps;
		thrwtbumps(:,2:ncol) =  SoftThresh(thrwtbumps(:,2:ncol),thr);
		thrwtheavi  = tiwtheavi;
		thrwtheavi(:,2:ncol) = SoftThresh(thrwtheavi(:,2:ncol),thr);
		thrwtDoppler  = tiwtDoppler;
		thrwtDoppler(:,2:ncol) = SoftThresh(thrwtDoppler(:,2:ncol),thr);
//
		[xhblocks]  = IWT_TI(thrwtblocks,QMF_Filter);
		[xhbumps]   = IWT_TI(thrwtbumps,QMF_Filter);
		[xhheavi]   = IWT_TI(thrwtheavi,QMF_Filter);
		[xhDoppler] = IWT_TI(thrwtDoppler, QMF_Filter);
		
//
	printf('Blocks:    RMS(Soft,TI) =%g  \n',norm(xhblocks-xblocks))
	printf('Bumps :    RMS(Soft,TI) =%g  \n',norm(xhbumps-xbumps))
	printf('HeaviSine: RMS(Soft,TI) =%g  \n',norm(xhheavi-xheavi))
	printf('Doppler:   RMS(Soft,TI) =%g  \n',norm(xhDoppler-xDoppler))
//
// 	figure;
	versaplot(221,t,xhblocks, [],' 5 (a) Soft,TI[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],' 5 (b) Soft,TI[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],' 5 (c) Soft,TI[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],' 5 (d) Soft,TI[yDoppler] '  ,[],[])

//	Revision History
//		09/29/99	MRD	   declare xblocks etc. global
//       10/1/05     AM     the name of the variable QMF is changed to
//                          QMF_Filter
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf06 -- Ordinary Haar Wavelet Shrinkage
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a SOFT thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
//  
//
//  Remark: run SpinCycleInit and cspinf0[12] before this.
//
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Haar');
	L = 5;
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
	nxblocks  = 0;
	nxbumps   = 0;
	nxheavi   = 0;
	nxDoppler = 0;
	FirstOnly = 1;
//
	nspin =1;  // ONLY LOOK AT SHIFT 0
	for i=0:(nspin-1),		
		[chblocks]  = cyclespin(yblocks,  i);
		[chbumps]   = cyclespin(ybumps,   i);
		[chheavi]   = cyclespin(yheavi,   i);
		[chDoppler] = cyclespin(yDoppler, i);
//
		[dhblocks]  = WaveShrink(chblocks,  'Visu',L,QMF_Filter);
		[dhbumps]   = WaveShrink(chbumps,   'Visu',L,QMF_Filter);
		[dhheavi]   = WaveShrink(chheavi,   'Visu',L,QMF_Filter);
		[dhDoppler] = WaveShrink(chDoppler, 'Visu',L,QMF_Filter);
//
		[dhblocks]  = cyclespin(dhblocks,  -i);
		[dhbumps]   = cyclespin(dhbumps,   -i);
		[dhheavi]   = cyclespin(dhheavi,   -i);
		[dhDoppler] = cyclespin(dhDoppler, -i);
//
		[xhblocks]  = xhblocks  + dhblocks;
		[xhbumps]   = xhbumps   + dhbumps;
		[xhheavi]   = xhheavi   + dhheavi;
		[xhDoppler] = xhDoppler + dhDoppler;
//
		if i==0,
			[zblocks]  = dhblocks;
			[zbumps]   = dhbumps;
			[zheavi]   = dhheavi;
			[zDoppler] = dhDoppler;
		end
//
		if i==0 | (i > 0 & ~FirstOnly),
			nxblocks = nxblocks  + norm(dhblocks-xblocks).^2;
			nxbumps  = nxbumps   + norm(dhbumps-xbumps).^2;
			nxheavi  = nxheavi   + norm(dhheavi-xheavi).^2;
			nxDoppler= nxDoppler + norm(dhDoppler-xDoppler).^2;
		end
//
	end
//
	[xhblocks]  = xhblocks/nspin;
	[xhbumps]   = xhbumps/nspin;
	[xhheavi]   = xhheavi/nspin;
	[xhDoppler] = xhDoppler/nspin;
//
	if FirstOnly, denom=1; else, denom=nspin; end
	nxblocks = sqrt(nxblocks/denom);
	nxbumps  = sqrt(nxbumps/denom);
	nxheavi  = sqrt(nxheavi/denom);
	nxDoppler= sqrt(nxDoppler/denom);
//
	if FirstOnly, 
		labelstr = 'RMS(Soft,Haar,Orig)'; 
	else, 
		labelstr = 'Root(Ave(MSE(Soft,Shifted)))';
	end
//
	printf('Blocks:     %s = %g \n',labelstr,nxblocks)
	printf('Bumps :     %s = %g \n',labelstr,nxbumps)
	printf('HeaviSine:  %s = %g \n',labelstr,nxheavi)
	printf('Doppler:    %s = %g \n',labelstr,nxDoppler)
//
//
// 	figure;
	versaplot(221,t,zblocks, [],'  6 (a) Haar,VisuShrink[yBlocks] '   ,[],[])
	versaplot(222,t,zbumps,  [],'  6 (b) Haar,VisuShrink[yBumps] '    ,[],[])
	versaplot(223,t,zheavi,  [],'  6 (c) Haar,VisuShrink[yHeaviSine] ',[],[])
	versaplot(224,t,zDoppler,[],'  6 (d) Haar,VisuShrink[yDoppler] '  ,[],[])
//

//	Revision History
//		09/29/99	MRD		Declared xblocks etc. global
//       10/1/05     AM      Changing the name of the variable QMF to
//                           QMF_Filter

       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf07 -- Fully TI Haar Wavelet Shrinkage
//             Haar Shrinkage of the Four Noisy Signals
//
// Here we test fully translation-invariant denoising, using
// the Stationary Wavelet Transform.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// Using this in a clever way, we can average 
// the results of de-noising on *all* circulant shifts of a signal.
//
// The procedure for DeNoising:
//       1.  Translation-Invariant Transform to Wavelet Domain, 
//			Using Haar Wavelet.
//       2.  Apply a Soft thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  We do this on *all* circulant shifts of a signal and
//  then average the results.
//  
//
//  Remark: run CycleSpinInit and cspinf0[12] before this.
//
//
mode(-1);  
scf(1);clf(1);
//

	HaarQMF = MakeONFilter('Haar');
	L = 5;  thr = sqrt(2* log(n));
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
		[tiwtblocks]  = FWT_TI(yblocks,  L,HaarQMF);
		[tiwtbumps]   = FWT_TI(ybumps,   L,HaarQMF);
		[tiwtheavi]   = FWT_TI(yheavi,   L,HaarQMF);
		[tiwtDoppler] = FWT_TI(yDoppler, L,HaarQMF);
//
		[nrow,ncol]  = size(tiwtblocks);
		thrwtblocks  = tiwtblocks;
		thrwtblocks(:,2:ncol) = SoftThresh(thrwtblocks(:,2:ncol),thr);
		thrwtbumps  = tiwtbumps;
		thrwtbumps(:,2:ncol)  = SoftThresh(thrwtbumps(:,2:ncol),thr);
		thrwtheavi  = tiwtheavi;
		thrwtheavi(:,2:ncol)  = SoftThresh(thrwtheavi(:,2:ncol),thr);
		thrwtDoppler  = tiwtDoppler;
		thrwtDoppler(:,2:ncol) = SoftThresh(thrwtDoppler(:,2:ncol),thr);
//
		[xhblocks]  = IWT_TI(thrwtblocks ,HaarQMF);
		[xhbumps]   = IWT_TI(thrwtbumps  ,HaarQMF);
		[xhheavi]   = IWT_TI(thrwtheavi  ,HaarQMF);
		[xhDoppler] = IWT_TI(thrwtDoppler,HaarQMF);
		
//
	printf('Blocks:    RMS(Soft,HaarTI) =%g  \n',norm(xhblocks-xblocks))
	printf('Bumps :    RMS(Soft,HaarTI) =%g  \n',norm(xhbumps-xbumps))
	printf('HeaviSine: RMS(Soft,HaarTI) =%g  \n',norm(xhheavi-xheavi))
	printf('Doppler:   RMS(Soft,HaarTI) =%g  \n',norm(xhDoppler-xDoppler))
//
// 	figure;
	versaplot(221,t,xhblocks, [],' 7 (a) Soft,Haar,TI[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],' 7 (b) Soft,Haar,TI[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],' 7 (c) Soft,Haar,TI[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],' 7 (d) Soft,Haar,TI[yDoppler] '  ,[],[])
//
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf08 -- Closeups of Fully TI Haar Wavelet Shrinkage
//
// Here we test fully translation-invariant denoising, using
// the Stationary Wavelet Transform.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// Using this in a clever way, we can average 
// the results of de-noising on
// *all* circulant shifts of a signal.
//
// The procedure for DeNoising:
//       1.  Translation-Invariant Transform to Wavelet Domain, 
//			Using Haar Wavelet.
//       2.  Apply a Soft thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  We do this on *all* circulant shifts of a signal and
//  then average the results.
//  
//
//  Remark: run CycleSpinInit and cspinf0[12] before this.
//  Remark: run cspinf07 before this
//  Agenda:  //
mode(-1);  
scf(1);clf(1);
//


// 	figure;
	ax = [.0 .35 -15 25];
	subplot(2,2,1); plot(t,xhblocks,'-'); aa=gca();aa.data_bounds=(ax); 
        plot(t,xblocks,'.')
	title(' 8a TI Haar DeNoising & Blocks')
//
	subplot(2,2,2);
	plot(t,zblocks);  aa=gca();aa.data_bounds=(ax);
	title(' 8b Ordinary Haar DeNoising');
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf09 -- Fully TI, S8, Hard-Thresholding Shrinkage
//
// Here we test fully translation-invariant denoising, using
// the Stationary Wavelet Transform.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// We apply a specific thresholding rule to the
// four noisy signals depicted in Figure 2.
//
// The procedure for DeNoising:
//       1.  Translation-Invariant Transform to Wavelet Domain, 
//			Using Nearly-Symmetric Wavelet with 8 vanishing moments.
//       2.  Apply a Hard thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  We do this on *all* circulant shifts of a signal and
//  then average the results.
//  
//
//  Remark: run SpinCycleInit and cspinf0[12] before this.
//
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;  thr = sqrt(2* log(n));
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
		[tiwtblocks]  = FWT_TI(yblocks,   L,QMF_Filter);
		[tiwtbumps]   = FWT_TI(ybumps,    L,QMF_Filter);
		[tiwtheavi]   = FWT_TI(yheavi,    L,QMF_Filter);
		[tiwtDoppler] = FWT_TI(yDoppler,  L,QMF_Filter);
//
		[nrow,ncol]  = size(tiwtblocks);
		thrwtblocks  = tiwtblocks;
		thrwtblocks(:,2:ncol) = HardThresh(thrwtblocks(:,2:ncol),thr);
		thrwtbumps  = tiwtbumps;
		thrwtbumps(:,2:ncol)  = HardThresh(thrwtbumps(:,2:ncol),thr);
		thrwtheavi  = tiwtheavi;
		thrwtheavi(:,2:ncol)  = HardThresh(thrwtheavi(:,2:ncol),thr);
		thrwtDoppler  = tiwtDoppler;
		thrwtDoppler(:,2:ncol) = HardThresh(thrwtDoppler(:,2:ncol),thr);
//
		[xhblocks]  = IWT_TI(thrwtblocks,QMF_Filter);
		[xhbumps]   = IWT_TI(thrwtbumps,QMF_Filter);
		[xhheavi]   = IWT_TI(thrwtheavi,QMF_Filter);
		[xhDoppler] = IWT_TI(thrwtDoppler, QMF_Filter);
		
//
	printf('Blocks:    RMS(Hard,TI) =%g  \n',norm(xhblocks-xblocks))
	printf('Bumps :    RMS(Hard,TI) =%g  \n',norm(xhbumps-xbumps))
	printf('HeaviSine: RMS(Hard,TI) =%g  \n',norm(xhheavi-xheavi))
	printf('Doppler:   RMS(Hard,TI) =%g  \n',norm(xhDoppler-xDoppler))
//
// 	figure;
	versaplot(221,t,xhblocks, [],' 9 (a) Hard,S8,TI[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],' 9 (b) Hard,S8,TI[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],' 9 (c) Hard,S8,TI[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],' 9 (d) Hard,S8,TI[yDoppler] '  ,[],[])
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf10 -- TI, Hard, Haar Shrinkage, Small Sample Size
//
// Here we test fully translation-invariant denoising, using
// the Stationary Wavelet Transform.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// Using this in a clever way, we can average 
// the results of de-noising on
// *all* circulant shifts of a signal.
//
// The procedure for DeNoising:
//       1.  Translation-Invariant Transform to Wavelet Domain, 
//			Using Haar Wavelet.
//       2.  Apply a Hard thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  We do this on *all* circulant shifts of a signal and
//  then average the results.
//  
//
//  Remark: DON't run CycleSpinInit and cspinf0[12] before this.
//          DO run  ``global N; N=2048; CycleSpinInit'' and cspinf0[12] after this
//
//  Agenda:  //
mode(-1);  
scf(1);clf(1);
//
	N = 256;
	HaarQMF = MakeONFilter('Haar');
	L = 5;  thr = sqrt(2* log(N));
//
	//SpinCycleInit; // NOTE after you run this all earlier scripts will
				   // BOMB unless you first ``global N; N=2048; SpinCycleInit;''
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
		[tiwtblocks]  = FWT_TI(yblocks,  L,HaarQMF);
		[tiwtbumps]   = FWT_TI(ybumps,   L,HaarQMF);
		[tiwtheavi]   = FWT_TI(yheavi,   L,HaarQMF);
		[tiwtDoppler] = FWT_TI(yDoppler, L,HaarQMF);
//
		[nrow,ncol]  = size(tiwtblocks);
		thrwtblocks  = tiwtblocks;
		thrwtblocks(:,2:ncol) = HardThresh(thrwtblocks(:,2:ncol),thr);
		thrwtbumps  = tiwtbumps;
		thrwtbumps(:,2:ncol) =  HardThresh(thrwtbumps(:,2:ncol),thr);
		thrwtheavi  = tiwtheavi;
		thrwtheavi(:,2:ncol) = HardThresh(thrwtheavi(:,2:ncol),thr);
		thrwtDoppler  = tiwtDoppler;
		thrwtDoppler(:,2:ncol) = HardThresh(thrwtDoppler(:,2:ncol),thr);
//
		[xhblocks]  = IWT_TI(thrwtblocks ,HaarQMF);
		[xhbumps]   = IWT_TI(thrwtbumps  ,HaarQMF);
		[xhheavi]   = IWT_TI(thrwtheavi  ,HaarQMF);
		[xhDoppler] = IWT_TI(thrwtDoppler,HaarQMF);
		
//
	printf('Blocks:    RMS(Hard,HaarTI) =%g  \n',norm(xhblocks-xblocks))
	printf('Bumps :    RMS(Hard,HaarTI) =%g  \n',norm(xhbumps-xbumps))
	printf('HeaviSine: RMS(Hard,HaarTI) =%g  \n',norm(xhheavi-xheavi))
	printf('Doppler:   RMS(Hard,HaarTI) =%g  \n',norm(xhDoppler-xDoppler))
//
// 	figure; 
    ax1 =[0 1 -10 20]; ax2 = [0 1 -15 10];
	versaplot(221,t,xhblocks, [],' 10 (a) Hard,Haar,TI[yBlocks] '   ,ax1,[])
	versaplot(223,t,xhheavi,  [],' 10 (c) Hard,Haar,TI[yHeaviSine] ',ax2,[])
//
	HaarQMF = MakeONFilter('Haar');
	L = 5;
//
	FirstOnly = 1;
//
	nspin =1;  // ONLY LOOK AT SHIFT 0
	for i=0:(nspin-1),		
		[chblocks]  = cyclespin(yblocks,  i);
		[chbumps]   = cyclespin(ybumps,   i);
		[chheavi]   = cyclespin(yheavi,   i);
		[chDoppler] = cyclespin(yDoppler, i);
//
		[dhblocks]  = WaveShrink(chblocks,  'Visu',L,HaarQMF);
		[dhbumps]   = WaveShrink(chbumps,   'Visu',L,HaarQMF);
		[dhheavi]   = WaveShrink(chheavi,   'Visu',L,HaarQMF);
		[dhDoppler] = WaveShrink(chDoppler, 'Visu',L,HaarQMF);
//
		[dhblocks]  = cyclespin(dhblocks,  -i);
		[dhbumps]   = cyclespin(dhbumps,   -i);
		[dhheavi]   = cyclespin(dhheavi,   -i);
		[dhDoppler] = cyclespin(dhDoppler, -i);
//
		[xhblocks]  = xhblocks  + dhblocks;
		[xhbumps]   = xhbumps   + dhbumps;
		[xhheavi]   = xhheavi   + dhheavi;
		[xhDoppler] = xhDoppler + dhDoppler;
//
		if i==0,
			[zblocks]  = dhblocks;
			[zbumps]   = dhbumps;
			[zheavi]   = dhheavi;
			[zDoppler] = dhDoppler;
		end
//
//
	end
//
	versaplot(222,t,zblocks, [],'  10 (b) Haar,VisuShrink[yBlocks] '   ,ax1,[])
	versaplot(224,t,zheavi,  [],'  10 (d) Haar,VisuShrink[yHeaviSine] ',ax2,[])
//
    
    
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf11 -- Cycle Spinning SURE Threshold Wavelet Shrinkage
//
// Here we test an idea of R.R. Coifman, which he calls
// cycle-spinning.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// We apply a specific thresholding rule to the
// four noisy signals depicted in Figure 2.
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a SURE thresholding nonlinearity, with threshold set to
//           result computed by SURE
//       3.  Transform back to the signal domain.
// 
//  We do this at each of 16 circulant shifts of a signal and
//  then average the results.
//  
//  Errors are compared with applying this algorithm at one single shift.
//
//  Remark: run SpinCycleInit and cspinf0[12] before this.
//
//
mode(-1);  
scf(1);clf(1);
//MRD 3-9-99
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
	nxblocks  = 0;
	nxbumps   = 0;
	nxheavi   = 0;
	nxDoppler = 0;
	FirstOnly = 1;
//
	nspin =16;
	for i=0:(nspin-1),		
		[chblocks]  = cyclespin(yblocks,  i);
		[chbumps]   = cyclespin(ybumps,   i);
		[chheavi]   = cyclespin(yheavi,   i);
		[chDoppler] = cyclespin(yDoppler, i);
//
		[dhblocks]  = WaveShrink(chblocks,  'SURE',L,QMF_Filter);
		[dhbumps]   = WaveShrink(chbumps,   'SURE',L,QMF_Filter);
		[dhheavi]   = WaveShrink(chheavi,   'SURE',L,QMF_Filter);
		[dhDoppler] = WaveShrink(chDoppler, 'SURE',L,QMF_Filter);
//
		[dhblocks]  = cyclespin(dhblocks,  -i);
		[dhbumps]   = cyclespin(dhbumps,   -i);
		[dhheavi]   = cyclespin(dhheavi,   -i);
		[dhDoppler] = cyclespin(dhDoppler, -i);
//
		[xhblocks]  = xhblocks  + dhblocks;
		[xhbumps]   = xhbumps   + dhbumps;
		[xhheavi]   = xhheavi   + dhheavi;
		[xhDoppler] = xhDoppler + dhDoppler;
//
		if i==0,
			[zblocks]  = dhblocks;
			[zbumps]   = dhbumps;
			[zheavi]   = dhheavi;
			[zDoppler] = dhDoppler;
		end
//
		if i==0 | (i > 0 & ~FirstOnly),
			nxblocks = nxblocks  + norm(dhblocks-xblocks).^2;
			nxbumps  = nxbumps   + norm(dhbumps-xbumps).^2;
			nxheavi  = nxheavi   + norm(dhheavi-xheavi).^2;
			nxDoppler= nxDoppler + norm(dhDoppler-xDoppler).^2;
		end
//
	end
//
	[xhblocks]  = xhblocks/nspin;
	[xhbumps]   = xhbumps/nspin;
	[xhheavi]   = xhheavi/nspin;
	[xhDoppler] = xhDoppler/nspin;
//
	if FirstOnly, denom=1; else, denom=nspin; end
	nxblocks = sqrt(nxblocks/denom);
	nxbumps  = sqrt(nxbumps/denom);
	nxheavi  = sqrt(nxheavi/denom);
	nxDoppler= sqrt(nxDoppler/denom);
//
	if FirstOnly, 
		labelstr = 'RMS(SURE,Orig)'; 
	else, 
		labelstr = 'Root(Ave(MSE(SURE,Shifted)))';
	end
//
	printf('Blocks:    RMS(SURE,CSpin) =%g %s = %g \n',norm(xhblocks-xblocks),labelstr,nxblocks)
	printf('Bumps :    RMS(SURE,CSpin) =%g %s = %g \n',norm(xhbumps-xbumps),labelstr,nxbumps)
	printf('HeaviSine: RMS(SURE,CSpin) =%g %s = %g \n',norm(xhheavi-xheavi),labelstr,nxheavi)
	printf('Doppler:   RMS(SURE,CSpin) =%g %s = %g \n',norm(xhDoppler-xDoppler),labelstr,nxDoppler)
//
// 	figure;
	versaplot(221,t,xhblocks, [],'  11 (a) SURE,SpinCycle[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],'  11 (b) SURE,SpinCycle[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],'  11 (c) SURE,SpinCycle[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],'  11 (d) SURE,SpinCycle[yDoppler] '  ,[],[])
    
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf12 -- Two examples for time-frequency de-noising
//
mode(-1);  
scf(1);clf(1);
//
	N = 2048;
	     rho = 7;
	t = (0:(N-1))/N;
//
//
	HeaviSine = MakeSignal('HeaviSine',N);
	Bumps     = MakeSignal('Bumps',N);
	Blocks    = MakeSignal('Blocks',N);
	Doppler   = MakeSignal('Doppler',N);
//
	[xblocks,yblocks] = NoiseMaker(Blocks,rho);
	[xbumps,ybumps]   = NoiseMaker(Bumps,rho);
	[xheavi,yheavi]   = NoiseMaker(HeaviSine,rho);
	[xDoppler,yDoppler] = NoiseMaker(Doppler,rho);
//
	n = N;
	QuadChirp = MakeSignal('QuadChirp',n);
	MishMash  = MakeSignal('MishMash',n);
//
	[xQuad,yQuad]       = NoiseMaker(QuadChirp,rho);
	[xMish,yMish]       = NoiseMaker(MishMash,rho);
//
// 	figure;
	axQuad = [.05 .35 -15 15]; axQErr = [.05 .35 -4 4];
	axMish = [.05 .35 -20 20]; axMErr = [.05 .35 -4 4];
	subplot(221)
	plot(t,xQuad); title(' 12 (a) QuadChirp ');  aa=gca();aa.data_bounds=(axQuad);
	subplot(222)
	plot(t,xMish); title(' 12 (b) MishMash ');  aa=gca();aa.data_bounds=(axMish);
	subplot(223)
	plot(t,yQuad); title(' 12 (c) Noisy QuadChirp ');  aa=gca();aa.data_bounds=(axQuad);
	subplot(224)
	plot(t,yMish); title(' 12 (d) Noisy MishMash ');  aa=gca();aa.data_bounds=(axMish);
//
    

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf13 -- Ordinary Non-Spinning CP De-Noising
//
mode(-1);  
scf(1);clf(1);
//
	D = 7;
	[cQuad,bQuad,sQuad]          = CPDeNoise(yQuad,D,'Sine');
	[cMish,bMish,sMish]          = CPDeNoise(yMish,D,'Sine');
//
//
// 	figure;
	axQuad = [.05 .35 -15 15]; axQErr = [.05 .35 -4 4];
	axMish = [.05 .35 -20 20]; axMErr = [.05 .35 -4 4];
	subplot(221);plot(t,cQuad);  aa=gca();aa.data_bounds=(axQuad);	title(' 13(a) SURE CP DeNoising, QuadChirp')
	subplot(222);plot(t,cMish);  aa=gca();aa.data_bounds=(axMish);	title(' 13(b) SURE CP DeNoising, MishMash')
	subplot(223);plot(t,cQuad-xQuad);  aa=gca();aa.data_bounds=(axQErr);	title(' 13(c) Error: SURE CP, Quad')
	subplot(224);plot(t,cMish-xMish);  aa=gca();aa.data_bounds=(axMErr);	title(' 13(d) Error: SURE CP, Mish')
    
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf14 -- CycleSpinning CP De-Noising
//
//
mode(-1);  
scf(1);clf(1);
//
    D=7;        //AM 10/05
	[xhQuad]  = zeros((yQuad));
	[xhMish]  = zeros((yMish));
//
	nxQuad    = 0;
	nxMish    = 0;
	FirstOnly = 1;
//
	nspin =16;
	for i=0:(nspin-1),		
		[chQuad]   = cyclespin(yQuad,  i);
		[chMish]   = cyclespin(yMish,  i);
//
		[dhQuad]   = CPDeNoise(chQuad,D,'Sine');
		[dhMish]   = CPDeNoise(chMish,D,'Sine');
//
		[dhQuad]   = cyclespin(dhQuad,  -i);
		[dhMish]   = cyclespin(dhMish,  -i);
//
		[xhQuad]   = xhQuad   + dhQuad;
		[xhMish]   = xhMish   + dhMish;
//
		if i==0,
			[zQuad]  = dhQuad;
			[zMish]  = dhMish;
		end
//
		if i==0 | (i > 0 & ~FirstOnly),
			nxQuad = nxQuad  + norm(dhQuad-xQuad).^2;
			nxMish  = nxMish + norm(dhMish-xMish).^2;
		end
//
	end
//
	[xhQuad]   = xhQuad/nspin;
	[xhMish]   = xhMish/nspin;
//
	if FirstOnly, denom=1; else, denom=nspin; end
	nxQuad  = sqrt(nxQuad/denom);
	nxMish  = sqrt(nxMish/denom);
//
	if FirstOnly, 
		labelstr = 'RMS(Orig)'; 
	else, 
		labelstr = 'Root(Ave(MSE(Shifted)))';
	end
//
	printf('Quad:    RMS(CSpin) =%g %s = %g \n',norm(xhQuad-xQuad),labelstr,nxQuad)
	printf('Mish:    RMS(CSpin) =%g %s = %g \n',norm(xhMish-xMish),labelstr,nxMish)
//

// figure; 
	axQuad = [.05 .35 -15 15]; axQErr = [.05 .35 -4 4];
	axMish = [.05 .35 -20 20]; axMErr = [.05 .35 -4 4];
subplot(221);plot(t,xhQuad);  aa=gca();aa.data_bounds=(axQuad); 			title(' 14(a) Cycle-Spin SURE CP, QuadChirp')
subplot(222);plot(t,xhMish);  aa=gca();aa.data_bounds=(axMish);			title(' 14(b) Cycle-Spin SURE CP, MishMash')
subplot(223);plot(t,xhQuad-xQuad);  aa=gca();aa.data_bounds=(axQErr);	title(' 14(c) Error: Cycle-Spin SURE CP')
subplot(224);plot(t,xhMish-xMish);  aa=gca();aa.data_bounds=(axMErr);	title(' 14(d) Error: Cycle-Spin SURE CP')

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf15 -- Two Sinusoids for Fourier Denoising
//
mode(-1);  
scf(1);clf(1);
//
	nsine =128;
	tsine = (0:(nsine-1))./nsine;
//
	RatSine   = 4*sin(tsine .* 2* %pi .* 8 );
	IrrSine   = 4*sin(tsine .* 2* %pi .* 7.33333);
//
	yRatSine  =  RatSine + WhiteNoise(RatSine) + sqrt(-1) .* WhiteNoise(RatSine);
	yIrrSine  =  IrrSine + WhiteNoise(RatSine) + sqrt(-1) .* WhiteNoise(RatSine);
//
// yehi RatSine
//
// 	figure;
	subplot(221); plot(RatSine);  title('15 (a) RatSine');	
	subplot(222); plot(IrrSine);  title('15 (b) IrrSine');
	subplot(223); plot(real(yRatSine)); title('15 (c) real(yRatSine)');
	subplot(224); plot(real(yIrrSine)); title('15 (d) real(yIrrSine)');
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf16 -- Non-Spinning Fourier De-Noising
//
mode(-1);  
scf(1);clf(1);
//
		fRatSine = real(FourierDeNoise(yRatSine));
//
		fIrrSine = real(FourierDeNoise(yIrrSine));
//
// 	figure;
	subplot(221); plot(fRatSine); title(' 16(a) Fourier DeNoise[yRatSine] ');
	subplot(222); plot(fIrrSine); title(' 16(b) Fourier DeNoise[yIrrSine] ');
    
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf17 -- Cycle-Spinning Fourier De-Noising
//
mode(-1);  
scf(1);clf(1);
//
	nsine =128;                                       //AM 10/05
	tsine = (0:(nsine-1))./nsine;                     //AM 10/05
	RatSine   = 4*sin(tsine .* 2* %pi .* 8 );          //AM 10/05
	IrrSine   = 4*sin(tsine .* 2* %pi .* 7.33333);     //AM 10/05
	yRatSine  =  RatSine + WhiteNoise(RatSine) + sqrt(-1) .* WhiteNoise(RatSine); //AM 10/05
	yIrrSine  =  IrrSine + WhiteNoise(RatSine) + sqrt(-1) .* WhiteNoise(RatSine); //AM 10/05
//
   nspin = 16;
//
function y = ModulateWavelab(x,Freq)
y = x .* exp(%i.*Freq.*(0:(max(size(x))-1)));
endfunction
	for jsig=1:2,
		if jsig==1,
			yLoSine = yRatSine;
		else
			yLoSine = yIrrSine;
		end
		cLoSine = zeros(1,nsine);
	//
		for i=0:(nspin-1),
			y  = ModulateWavelab(yLoSine,2*%pi/(nsine*nspin)*i);
			hy = FourierDeNoise(y);
			my = ModulateWavelab(hy,-2*%pi/(nsine*nspin)*i);
			cLoSine = cLoSine + my;
			if i==0,
			   typical = real(my);
			end
		end
	//
		cLoSine = real(cLoSine ./nspin);
		if jsig==1,
			cRatSine = cLoSine;
		else
			cIrrSine = cLoSine;
		end
	end
//
// 	figure;
	subplot(221); plot(cRatSine); title(' 17(a) CycleSpin Fourier DeNoise[yRatSine] ');
	subplot(222); plot(cIrrSine); title(' 17(b) CycleSpin Fourier DeNoise[yIrrSine] ');
//


//
fRatSine = real(FourierDeNoise(yRatSine));
fIrrSine = real(FourierDeNoise(yIrrSine));

//
	cRatErr = norm(RatSine-cRatSine);
	cIrrErr = norm(IrrSine-cIrrSine);
	fRatErr = norm(RatSine-fRatSine);	
	fIrrErr = norm(IrrSine-fIrrSine);
	printf('cycle spin errors: %g,%g\n', cRatErr, cIrrErr);	
	printf('   usual   errors: %g,%g\n', fRatErr, fIrrErr);
    
//  Revision History
//             10/1/05     AM     the name of the function modulate is changed to
//                                 ModulateWavelab
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf18 -- Translation-Invariant Table of Blocks
//
// Here we display translation-invariant Wavelet Transform.  
// Object blocks
// S8 Wavelet 
//
//  Remark: run CycleSpinInit and cspinf0[12] before this.
//
//  Agenda:  //
mode(-1);  
scf(1);clf(1);
//MRD 3-9-99
//

		HaarQMF = MakeONFilter('Haar');
//
//
		L = 5;
		[tiwtblocks]  = FWT_TI(xblocks,  L,HaarQMF);
//
// 		figure;
		PlotPacketTable(tiwtblocks)
		title('18. TI Table; Haar Wavelet, Blocks Object')
		ylabel('splitting depth, d')
		xlabel('box[location], k[t]')
//
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf19 -- Unscrambling TI Table to Stat Table
//
// Here we display  unscrambled translation-invariant Wavelet Transform.  
// Unscrambling makes it a Continuous Wavelet Transform
// Object Noisy[Blocks]
// S8 Wavelet 
//
//  Remark: run CycleSpinInit and cspinf1[89] before this.
//
//  Agenda:  //
//
mode(-1);  
scf(1);clf(1);
//
    QMF_Filter = MakeONFilter('Symmlet',8);  //AM 10/05
	L = 5;                                   //AM 10/05
    [tiwtblocks]  = FWT_TI(yblocks,  L,QMF_Filter); //AM 10/05
//
// 		figure;
		Stat_Table = TI2Stat(tiwtblocks);
		PlotStatTable(Stat_Table)
		title('19. Stat Table (=Unscrambled TI Table) of Blocks')
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf20 -- Unscrambling TI Table 
//
// Here we display  unscrambled translation-invariant Wavelet Transform.  
// Unscrambling makes it a Continuous Wavelet Transform
// Object Noisy[Blocks]
// S8 Wavelet 
//
//  Remark: run CycleSpinInit and cspinf1[89] before this.
//
//  Agenda:  //
//
mode(-1);  
scf(1);clf(1);
//	MRD 3-9-99
//
		HaarQMF = MakeONFilter('Haar');
//
		L = 5;
		NoisyTI  = FWT_TI(yblocks,  L,HaarQMF);
// 		figure;
		Noisy_Stat_Table = TI2Stat(NoisyTI);
		PlotStatTable(Noisy_Stat_Table)
		title('20. Stat Table of Noisy Blocks')
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// cspinf21 -- Thresholding Translation-Invariant Table of Blocks
//
// Here we display Stationary Wavelet Transform.  
// Object Noisy[Blocks]
// S8 Wavelet 
// Thresholded
//  Remark: run CycleSpinInit and cspinf20 before this.
//
//  Agenda:  //
//
mode(-1);  
scf(1);clf(1);
//
HaarQMF = MakeONFilter('Haar');   //AM 10/05
L = 5;                            //AM 10/05
NoisyTI  = FWT_TI(yblocks,  L,HaarQMF); //AM 10/05
Noisy_Stat_Table = TI2Stat(NoisyTI);    //AM 10/05

//
	thr = sqrt(2* log(N));
//
		//figure;
		[nrow,ncol] = size(Noisy_Stat_Table);
		thrwtblocks  = Noisy_Stat_Table;
		thrwtblocks(:,2:ncol) = SoftThresh(thrwtblocks(:,2:ncol),thr);
		PlotStatTable(thrwtblocks)
		title('21. Thresholding of Stat Table of Noisy Blocks')
        
 
         
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:42 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 

