mode(-1);
function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction



	     N = 2048;


	     rho = 7;

	      alf = .9;

	t = (0:(N-1))/N;
//
	disp('Initializing Parameters:')
	disp(sprintf('N = %g',N))
	disp(sprintf('rho = %g',rho))
	disp(sprintf('alf = %g',alf))
//
	HeaviSine = MakeSignal('HeaviSine',N);
	Bumps     = MakeSignal('Bumps',N);
	Blocks    = MakeSignal('Blocks',N);
	Doppler   = MakeSignal('Doppler',N);
//
	[xblocks,yblocks]   = NoiseMaker(Blocks,rho);
	[xbumps,ybumps]     = NoiseMaker(Bumps,rho);
	[xheavi,yheavi]     = NoiseMaker(HeaviSine,rho);
	[xDoppler,yDoppler] = NoiseMaker(Doppler,rho);


	     nTFA = 1024;

	     rhoTFA = 7;

	tt = (0:(nTFA-1))/nTFA;
//
	disp(sprintf('nTFA = %g',nTFA))
	disp(sprintf('rhoTFA = %g',rhoTFA))
//
	QuadChirp = MakeSignal('QuadChirp',nTFA);
	MishMash  = MakeSignal('MishMash' ,nTFA);
	wBumps    = MakeSignal('Bumps'    ,nTFA);
	wDoppler  = MakeSignal('Doppler'  ,nTFA);
//
	[xQuad,yQuad]       = NoiseMaker(QuadChirp,rhoTFA);
	[xMish,yMish]       = NoiseMaker(MishMash,rhoTFA);
	[uBumps,vBumps]     = NoiseMaker(wBumps,rhoTFA);
	[uDoppler,vDoppler] = NoiseMaker(wDoppler,rhoTFA);


clc;mode(1);lines(0);
// scfig01 -- Short Course 01: De-Noising of NMR Signal
//
// Here a noisy NMR signal is denoised by a simple three-step
// recipe:
//         1.  Transform to Wavelet Domain.
//         2.  Apply thresholding to set coeficients
//             ``at the noise level'' to zero
//         3.  Return to the original domain.
//
// Evidently, the noise is suppressed without broadening the peaks.
// More traditional smoothing methods either suppress the noise and
// broaden peaks or don't suppress the noise and leave peaks narrow.
//
// These data were kindly supplied by Chris Raphael, an NSF post-
// doctoral fellow in the Statistics Department at Stanford.
//
mode(-1);  
scf(1);clf(1);
	nmrsignal  = ReadSignal('RaphaelNMR')';
	QMF8       = MakeONFilter('Symmlet',8);
	scalednmr  = NormNoise(nmrsignal,QMF8);
	y          = scalednmr *1.2;
	[xh,wcoef] = WaveShrink(y,'Visu',5,QMF8); 
	tnmr       =  1:length(nmrsignal);
//
// 	clf;
	versaplot(211,tnmr,y, [],' 1 (a) NMR Spectrum',[],[])
	versaplot(212,tnmr,xh,[],' 1 (b) Wavelet Shrinkage De-Noising',[],[])

halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig02 -- Short Course 02: Noisy Deconvolution
//
// In this example, the object ``Bumps'' is convolved with a recursive
// filter that blurs out the sharp structure; and then noise is added.
// (panels a,b)
//
// The deconvolution problem is ill-posed, in that when we apply the
// inverse filter, we get an object which is extremely noisy and has
// no real resemblance to the original object. (panel c)
//
// When we apply thresholding in the wavelet domain, with thresholds
// specially chosen to adapt to the structure of the deconvolution
// problem, we get a reconstruction which is nearly noise free and which
// also preserves the structure of the Bumps object. (panel d)
//
mode(-1);  
scf(1);clf(1);
//
	N2 = length(Bumps)/2;
	x = [ zeros(1,N2) Bumps zeros(1,N2)];
	sx = filter(1,[1 ((-2 * alf)) (alf^2)],x);
	nsx = sx + WhiteNoise(sx);
	dnsx = filter([1 ((-2 * alf)) (alf^2)],1,nsx);
//
	QMF_Filter  = MakeONFilter('Coiflet',2);
	wcNaive      = FWT_PO(dnsx, 5, QMF_Filter);
	wcDeNoised   = MultiMAD(wcNaive,5);
	recx         = IWT_PO(wcDeNoised,5,QMF_Filter);
//
	wcObject     = FWT_PO(x,5,QMF_Filter);
//
// 	clf;
	ts = [ linspace(-.5,(-1) ./ (2*N2), N2) t linspace(1 + 1 ./ (2*N2), 1.5, N2)];
	subplot(221); plot(ts,x);    title('2 (a) Object')
	subplot(222); plot(ts,nsx);  title('2 (b) Noisy Blurred')
	subplot(223); plot(ts,dnsx); title('2 (c) Naive DeBlurred')
	subplot(224); plot(ts,recx); title('2 (d) WVD Reconstruction')


halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig03 -- Short Course 03: Comparison of Wavelet and Packet DeNoising
//
// Here a synthetic signal, ``MishMash'', containing a quadratic
// and a linear chirp, along with a high-frequency sinusoid, is
// being studied (Panel a).  A noisy version is created, (Panel b) 
// and this noisy version is then de-noised using wavelet shrinkage.
// (Panel c) The results are poor, in that the fine structure of the 
// oscillating noiselss object is lost.
//
// In contrast, De-noising in an adaptively chosen cosine packet basis
// removes the noise and produces an acceptable approximation to the
// original noiseless object. (Panel d)
//
mode(-1);  
scf(1);clf(1);
//
//  xMish, yMish, etc. were created in SCInit
//
ax =  [0 .25 -20 20];
//
	versaplot(221,tt,xMish,[],' 3 (a) Segment of Noiseless object',ax,[]);
	versaplot(222,tt,yMish,[],' 3 (b) Segment of Noisy object',    ax,[]);
//
// wavelets
//
	QCoif3         = MakeONFilter('Coiflet',3);
	[xWave,wcWave] = WaveShrink(yMish,'Visu',3,QCoif3);
	versaplot(223,tt,xWave,[],' 3 (c) Wavelet Basis De-Noising',ax,[]);
//
// wavelet packet
//
	//xWP = WPDeNoise(yMish,7,QCoif3);
	//plot(t,xWP); title(' 3 (c) Wavelet Packet Basis De-Noising');
//
// cosine packet
//
	xCP = CPDeNoise(yMish,6,'Sine');
	versaplot(224,tt,xCP,[],' 3 (d) Cosine Packet Best Basis De-Noising',ax,[]);
    
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig04 -- Short Course 04: Four Spatially Inhomogenoeus Signals
//
// Here we depict four signals chosen as caricatures of signals arising
// in scientific signal processing.
//
// Blocks is a piecewise constant signal, a caricature of a scan line
// through a 2-d image depicting an object with several edges.
//
// Bumps is a very peaky signal, a caricature of an NMR Spectrum.
// 
// HeaviSine is a sinusoid with two clicks.
//
// Doppler is an attenuating sinusoid with time-varying frequency.
//
// These objects are interesting to us because they portray significant
// spatial inhomogeneity.
//
mode(-1);  
scf(1);clf(1);
// //
// 	clf;
	versaplot(221,t,xblocks, [],' 4 (a) Blocks '   ,[],[])
	versaplot(222,t,xbumps,  [],' 4 (b) Bumps '    ,[],[])
	versaplot(223,t,xheavi,  [],' 4 (c) HeaviSine ',[],[])
	versaplot(224,t,xDoppler,[],' 4 (d) Doppler '  ,[],[])
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig05 -- Short Course 05: Noisy Versions of Four Signals
//
// The four objects of Figure 4 with white noise superposed.
// The noise is normally distributed with variance 1.
//
// 
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	versaplot(221,t,yblocks, [],' 5 (a) Noisy Blocks '   ,[],[])
	versaplot(222,t,ybumps,  [],' 5 (b) Noisy Bumps '    ,[],[])
	versaplot(223,t,yheavi,  [],' 5 (c) Noisy HeaviSine ',[],[])
	versaplot(224,t,yDoppler,[],' 5 (d) Noisy Doppler '  ,[],[])
    
    
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig06 -- Short Course 06: Wavelet Shrinkage of the Four Noisy Signals
//
// Here we aapply a specific thresholding rule to the
// four noisy signals depicted in Figure 5.
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a soft thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
// The reconstructions suppress the noise, while preserving the sharp structure
// in the neighborhood of the highly-variable spatial components.
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks]  = WaveShrink(yblocks, 'Visu',L,QMF_Filter);
	[xhbumps]   = WaveShrink(ybumps,  'Visu',L,QMF_Filter);
	[xhheavi]   = WaveShrink(yheavi,  'Visu',L,QMF_Filter);
	[xhDoppler] = WaveShrink(yDoppler,'Visu',L,QMF_Filter);
//
// 	clf;
	versaplot(221,t,xhblocks, [],' 6 (a) VisuShrink[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],' 6 (b) VisuShrink[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],' 6 (c) VisuShrink[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],' 6 (d) VisuShrink[yDoppler] '  ,[],[])

 
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig07 -- Short Course 07: AutoSpline Reconstructions from Noisy Data
//
// Here we depict a reconstruction using penalized thin-plate splines,
// in which periodic thin-plate splines are used to smooth the data,
// with roughness penalty proportional to the energy stored in the
// second derivative.  The constant of proportionality (or Lagrangian
// tuning parameter) is the empirical minimizer of the Stein Unbiased
// Estimate of Risk.
//
mode(-1);  
scf(1);clf(1);
// clf;
//SplineInit
//
	[xhat, c] = SplineUChoose(yblocks,2.);
	versaplot(221,t,xhat,[],' 7 (a) AutoSpline[Blocks]',[],[])
//
	[xhat,c] = SplineUChoose(ybumps,2.);
	versaplot(222,t,xhat,[],' 7 (b) AutoSpline[Bumps]',[],[])
//
	[xhat,c] = SplineUChoose(yheavi,2.);
	versaplot(223,t,xhat,[],' 7 (c) AutoSpline[HeaviSine]',[],[])
//
	[xhat,c] = SplineUChoose(yDoppler,2.);
	versaplot(224,t,xhat,[],' 7 (d) AutoSpline[Doppler]',[],[])
    
    
 halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig08 -- Short Course 08: AutoTrunc Truncated Fourier Reconstructions
//
// Here we depict a reconstruction using truncated Fourier expansions,
// in which only the low-order fourier components of the noisy signal
// are retained in reconstruction. The cut-off point for reconstruction
// in the frequency domain is the empirical minimizer of the Stein
// Unbiased Estimate of Risk.
//
mode(-1);  
scf(1);clf(1);
//
// clf;
//
	xhat = AutoTrunc(yblocks,1.);
	versaplot(221,t,xhat,[],' 8 (a) AutoTrunc[yBlocks]',[],[])
//
	xhat = AutoTrunc(ybumps,1.);
	versaplot(222,t,xhat,[],' 8 (b) AutoTrunc[yBumps]',[],[])
//
	xhat = AutoTrunc(yheavi,1.);
	versaplot(223,t,xhat,[],' 8 (c) AutoTrunc[yHeaviSine]',[],[])
//
	xhat = AutoTrunc(yDoppler,1.);
	versaplot(224,t,xhat,[],' 8 (d) AutoTrunc[yDoppler]',[],[])
    
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig09 -- Short Course 09: WaveShrink of object yBlocks in Haar Basis
//
// (Panel a) depicts the noisy object yBlocks, its Haar transform (Panel
// c), wavelet shrinkage reconstruction using the Haar wavelet (Panel b),
// and the Haar Transform of the reconstruction (Panel d).
//
// The viewer is supposed to notice that in the Haar domain, the noise is
// spread out among all coefficients, while the signal is concentrated in
// only a few coefficients. Hence thresholding mostly affects the noise
// without disturbing the signal.
//
mode(-1);  
scf(1);clf(1);
//
	HL = 3; 
	HQMF       = MakeONFilter('Haar');
	[x,y]      = NoiseMaker(Blocks,7);
	[xhat,xw]  = WaveShrink(y,'Visu',HL,HQMF);
	yw         = FWT_PO(y,HL,HQMF);
//
// 	clf; 
    scal = .05;





	versaplot(221,t,y,   [],' 9 (a) Noisy Data y',             [0 1 (-20) (20)],[]);
	versaplot(222,t,xhat,[],' 9 (b) VisuShrink Reconstruction',[0 1 (-20) (20)],[]);
	subplot(223); PlotWaveCoeff(yw,HL,scal); title(' 9 (c) Haar[y]')
	subplot(224); PlotWaveCoeff(xw,HL,scal); title(' 9 (d) Haar[Reconstruction]')
    
    
 halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig10 -- Short Course 10: Comparing Compression Abilities
//
// Here we depict the compression numbers c_n in three different signal
// domains {Wavelet, Haar, Cosine} of four different signals {Bumps,
// Blocks, HeaviSine, and Doppler}. The numbers c_n are the mean-squared
// reconstruction errors of reconstructions which use at most n nonzero
// coefficients in the transfrom domain.
//
// Blocks: The Haar Basis has the best compression numbers, for obvious
// reasons.  The Wavelet basis is not bad, and the Fourier basis is far
// worse than either the Wavelet or Haar basis.
//
// Bumps: The Wavelet Basis has the best compression numbers, with the Haar
// not bad, and the Fourier basis being far inferior.
//
// HeaviSine: The near-sinusoidal behavior make the Fourier basis a good
// choice but Wavelets really are not bad here. Surprisingly, if very high
// accuracy is required, the Haar basis beats Fourier, because the Fourier
// basis has trouble modelling jumps.
//
// Doppler: Wavelets are much better than either Fourier or Haar.
//
//
mode(-1);  
scf(1);clf(1);
//

function CompressoGram(Sig,QMF_Filter)
// CompressoGram -- compare compress abilities of four transforms
//

// Haar Transform
        HaarQMF = MakeONFilter('Haar');
        hSig = FWT_PO(Sig,1,HaarQMF);
        epsilon = 1.e-16;
        ehSig = reverse(cumsum(mtlb_sort(hSig.^2)))/sum(hSig.^2) + epsilon;
// Cosine Transform
        fSig = dct_iv(Sig);
        efSig = reverse(cumsum(mtlb_sort(fSig.^2)))/sum(fSig.^2) + epsilon;
// Wavelet Transform
        wSig = FWT_PO(Sig,5,QMF_Filter);
        ewSig = reverse(cumsum(mtlb_sort(wSig.^2)))/sum(wSig.^2) + epsilon;
        i = 1:length(ewSig);
//
        LockAxes([0 length(ewSig)/2 -8 0]);
        xlabel('n')
        ylabel('Log(c_n)')
        plot(i,log(ewSig),'r-');
        plot(i,log(ehSig),'g-.');
        plot(i, log(efSig),'c--')
        UnlockAxes

//       Revision History
//               09/29/99        DLD        added epsilon to avoid log(0)
//       10/1/05     AM     Changing the name of the variable QMF

endfunction





QSymm8 = MakeONFilter('Symmlet',8);
// clf; 
//
   subplot(221)
   CompressoGram(Blocks,QSymm8)
   title('10 (a) Blocks')
//
   subplot(222)
   CompressoGram(Bumps,QSymm8)
   title('10 (b) Bumps')
//
   subplot(223)
   CompressoGram(HeaviSine,QSymm8)
   title('10 (c) HeaviSine')
//
   subplot(224)
   CompressoGram(Doppler,QSymm8)
   title('10 (d) Doppler')
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig11 -- Short Course 11: Compare Wavelet and DCT Partial Reconstructions
//
// Here we compare Wavelet and Cosine Transform behavior in reconstruction 
// of real signals.  The signals are both of length 1024 and only 100 
// coefficients are used in reconstruction.
//
// The two signals are a seismic trace and an NMR spectrum.
//
// The Wavelet reconstructions are visibly better.  Moreover, they are
// free of an annoying ``noise'' present throughout the DCT reconstruction.
//
mode(-1);  
scf(1);clf(1);
//   Seismic Signal
//
	dad = ReadSignal('Seismic')';
	QMF_Filter = MakeONFilter('Coiflet',3);
	wcseism = FWT_PO(dad,4,QMF_Filter);
// 	clf; 
    subplot(321); plot(dad); title(' 11(a) Seismic Signal')
//
//   nmr signal
//
	nmrsig = ReadSignal('HochNMR')';
	nmrsig = log(abs(nmrsig)+%eps);
	subplot(322); plot(nmrsig); title(' 11(b) Log(Abs(NMR Spectrum))')
	wcNMR = FWT_PO(nmrsig,4,QMF_Filter);
//
//   Show Wavelet Compression of Seismic
//
	rwcseism = reverse(mtlb_sort(abs(wcseism)));
	thresh   = rwcseism(100);
	wctseism = wcseism .* bool2s(abs(wcseism) > thresh);
	seismhat = IWT_PO(wctseism,4,QMF_Filter);
	subplot(323); plot(seismhat)
	title(' 11(c) Using Best 100 wavelet coeffts')
//
//   Show Wavelet Compression of NMR
//
	rwcNMR = reverse(mtlb_sort(abs(wcNMR)));
	thresh = rwcNMR(100);
	wctNMR = wcNMR .* bool2s(abs(wcNMR) > thresh);
	NMRhat = IWT_PO(wctNMR,4,QMF_Filter);
	subplot(324); plot(NMRhat)
	title(' 11(d) Using Best 100 wavelet coeffts')
//
//   Show DCT Compression of Seismic
//
	fcseism = dct_iv(dad);
	rfcseism = reverse(mtlb_sort(abs(fcseism)));
	thresh = rfcseism(100);
	fctseism = fcseism .* bool2s(abs(fcseism) > thresh);
	Seismfhat = dct_iv(fctseism);
	subplot(325); plot(Seismfhat); title(' 11(e) Using Best 100 Cosine Coeffts')
//
//   Show DCT Compression of NMR
//
	fcNMR = dct_iv(nmrsig);
	rfcNMR = reverse(mtlb_sort(abs(fcNMR)));
	thresh = rfcNMR(100);
	fctNMR = fcNMR .* bool2s(abs(fcNMR) > thresh);
	NMRfhat = dct_iv(fctNMR);
	subplot(326); plot(NMRfhat); title(' 11(f) Using Best 100 Cosine Coeffts')

halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig12 -- Short Course 12: DeNoising a 2-d object
//
// Here we display the image of Ingrid Daubechies, a noisy version of same
// and noisy and de-noised closeups.
//
// The de-noising was accomplished by
//
//    1. Transforming to the wavelet domain (Coiflets with 3 vanishing moments)
//    2. Applying a threshold at 2 standard deviations
//    3. Returning to the signal domain.
//
mode(-1);  
scf(1);clf(1);
	Ingrid = ReadImage('Daubechies');
	NoisyIngrid = Ingrid + 5*WhiteNoise(Ingrid);
//
	CoifQMF = MakeONFilter('Coiflet',3);
	wc_Noisy = FWT2_PO(NoisyIngrid,3,CoifQMF);
	Coarse  = wc_Noisy(1:8,1:8);
	thr     = 10;
	Thr_wc_Noisy = SoftThresh(wc_Noisy,thr);
	Thr_wc_Noisy(1:8,1:8) = Coarse;
	CleanIngrid = IWT2_PO(Thr_wc_Noisy,3,CoifQMF);
//
	subplot(221); GrayImage(Ingrid);
	title('Ingrid Daubechies');
//
	subplot(222); GrayImage(Ingrid); aa=gca();aa.data_bounds=([110 160 110 160]);
	title('Closeup');
//
	subplot(223); GrayImage(NoisyIngrid); aa=gca();aa.data_bounds=([110 160 110 160]);
	title('Noisy (closeup)');
//
	subplot(224); GrayImage(CleanIngrid); aa=gca();aa.data_bounds=([110 160 110 160]);
	title('De-Noised (closeup)');
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig13 -- Short Course 13: Smoothing Counts data by square roots; ESCA data
//  
// Here we illustrate the application of wavelet thresholding to Poisson
// Counts data. An ESCA spectrum is transformed by the Anscombe (1948) 
// variance-stabilizing transformation for poisson data, which are
// then processed as in earlier panels.
//
mode(-1);  
scf(1);clf(1);

	ESCA = ReadSignal('ESCA')';
	y = 2.*sqrt(ESCA + .375); 
	t = 1:length(ESCA);
	QMF_Filter = MakeONFilter('Coiflet',3);
	[xh,wcoef] = WaveShrink(y,'Visu',5,QMF_Filter);
//
// 	clf; 
	versaplot(211,t,y,[],'13 (a) Square Root of ESCA Spectrum',[],[])
	versaplot(212,t,xh,[],'13 (b) Wavelet Smoothed'           ,[],[])

    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig14 -- Short Course 14: Estimating Time Series Spectrum
//
// Here we illustrate the use of Wavelet Shrinkage in a time series setting.
// Our example is taken from Hong-Ye Gao's 1993 Ph.D. Thesis, U.C. Berkeley
// The example is constructed as follows.
//    1. Generate ARMA(24,1) Time Series having spectrum with poles near unit 
//       circle. This gives a log-spectrum with significant peaks.
//    2. Calculate the log-periodogram of the series; normalize it by the 
//       Wahba (1980) Variance-Stabilizing transform.
//    3. Apply Wavelet Shrinkage to the normalized log-periodogram
//
//
mode(-1);  
scf(1);clf(1);

	Fig14Filter = [1 -2.5216281  4.7715359  -7.9199915  11.9769211  -16.0778828  ...
        20.6343346  -25.0531521  28.8738136  -31.8046265  34.0071373 ...
        -34.7700272  34.3151321  -32.7861099  30.2861233  -26.7109356 ...
        22.8838310  -18.7432098  14.5717688  -10.7177744  7.5322194  ...
        -4.7226319  2.6807923  -1.3391306  0.5167125];
//
// 1. Generate ARMA Process
//
	z   = WhiteNoise(zeros(1,4096));
	ser = filter(1,Fig14Filter,z) + .01 .* WhiteNoise(z); // Recursive Filter
	ser = ser(2049:4096); // kill transients
//
// 2. Generate Log-o-Gram

function [t,g] = LogoGram(ser)
// LogoGram -- Time Series Spectrum Estimation
//  Usage
//    [t,g] = LogoGram(ser)
//  Inputs
//    ser      zero-mean time series, dyadic length
//  Outputs
//    t        ordinate of logogram
//    g        abscissa of logogram
//
n = max(size(ser));
Ij = abs(Wavelab_fft(ser)).^2 ./ ( n);
Yj = log(Ij) + .57721;
Yj(1) = Yj(1) - .57721 + (log(2) + .57721)/%pi ;
Yj(n/2+1) = Yj(n/2+1) - .57721 + (log(2) + .57721)/%pi ;
g = Yj .* sqrt(6)/%pi;
t = 2 * %pi * (0: (n-1)) ./ n;
endfunction
//
	[tg,g] = LogoGram(ser);
//
// 3. Wavelet Shrinkage
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	[xh,wcoef] = WaveShrink(g,'Visu',7,QMF_Filter);
//
// 4. Display
//
// 	clf; 
	versaplot(211,tg, g,[],'14(a) LogoGram'         ,[0 %pi -5 10],[]);
	versaplot(212,tg,xh,[],'14 (b) Wavelet Smoothed',[0 %pi -5 10],[]);
    

halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig15 -- Short Course 15: Noisy Differentiation by WVD
//
// Here we illustrate the use of wavelets for noisy differentiation.
// (Panel a) displays object Bumps, (panel b) its noisy cumulative, 
// and (Panel c) a naive inversion based on differencing. 
//
// The naive inversion is very noisy and displays only a hint of the 
// structure of the underlying function.
//
// We also display a wavelet-shrinkage reconstruction, in which noise is
// suppressed while the structure remains. 
//
// The wavelet-shrinkage reconstruction goes as follows
//
//       1.  Transform the naive reconstruction into the wavelet domain.
//       2.  Apply level-dependent thresholds which scale inversely with 
//           resolution.
//       3.  Return to the wavelet domain.
//
//  Coiflets with 3 vanishing moments are used.
//
mode(-1);  
scf(1);clf(1);
//
//   1. Generate signal(Bumps), Noisy Cumulative (x), Naive Inversion(y)
//
	zBumps = cumsum(Bumps);
	N = length(Bumps);
	t = (0:(N-1))/N;
	x = zBumps + WhiteNoise(zBumps);
	z = diff([0 x]);
//
//   2. Apply resolution-dependent thresholding
//
	QMF_Filter= MakeONFilter('Coiflet',3);
	w         = FWT_PO(z, 5,QMF_Filter);
	ws        = InvShrink(w,5,4,1);
	zrec      = IWT_PO(ws,5,QMF_Filter);
//
//   3. Displays
//
	wb = FWT_PO(Bumps,5,QMF_Filter);
//
// 	clf;
	subplot(221); plot(t,Bumps); title('15 (a) Object Bumps')
	subplot(222); plot(t,x);     title('15 (b) Noisy Cumulative')
	subplot(223); plot(t,z);     title('15 (c) Naive Reconstruction by Differencing')
	subplot(224); plot(t,zrec);  title('15 (d) WVD Reconstruction')
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig16 -- Short Course 16: Noisy Differentiation by WVD in Wavelet Domain
//
// Here the procedure of Figure 16 is displayed in the Wavelet domain.
//
// The noise in the naive inversion grows rapidly in size 
// as we move to finer resolutions.
//
mode(-1);  
scf(1);clf(1);
//
zBumps = cumsum(Bumps);                 //AM 10/05
x = zBumps + WhiteNoise(zBumps);        //AM 10/05
z = diff([0 x]);                        //AM 10/05
QMF_Filter= MakeONFilter('Coiflet',3);  //AM 10/05
w         = FWT_PO(z, 5,QMF_Filter);    //AM 10/05
ws        = InvShrink(w,5,4,1);         //AM 10/05
wb = FWT_PO(Bumps,5,QMF_Filter);        //AM 10/05

// 	clf;
	subplot(221); PlotWaveCoeff(wb,5,0.); title('16 (a) WT[ Object ]')
	subplot(222); PlotWaveCoeff(w,5,0.); title('16 (b) WT[ Naive Recon. ]')
	subplot(223); PlotWaveCoeff(ws,5,0.); title('16 (c) WT[ WVD Reconstruction ]')
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig17 -- Short Course 17: Noisy Differentiation by Ideal Fourier Damping
//
// This figure displays the results of an ideal Fourier Damping
// for deconvolution, in which each frequency is damped optimally
// based on its signal-to-noise ratio. For comparison, the Naive
// reconstruction based on simple differencing is also shown.
//
// Unlike the wavelet thresholding of Figure 15, ideal Fourier
// damping is not able to suppress noise while preserving resolution.
//
mode(-1);  
scf(1);clf(1);
//
	sig = cumsum(Bumps) + WhiteNoise(Bumps);
	x = diff([0 sig]);
//
	z = Wavelab_fft(x);
	w = Wavelab_fft(Bumps);
	omega = 2 * %pi .* (0:(length(w)-1)) ./ length(w);
	sigma2 = length(x) .* 4 .* sin(omega/2).^2;
	wate = abs(w).^2 ./ (abs(w).^2 + sigma2);
	whate = wate .* z;
	BumpsHat= real(ifft(whate));
//
// 	clf;
	s = linspace(0,1,length(x)); 
	subplot(221); plot(s,Bumps) ;    title('17 (a) Object')
	subplot(222); plot(s,sig);       title('17 (b) Noisy Cumulative')
	subplot(223); plot(s,x) ;        title('17 (c) Difference of Noisy Cumulative')
	subplot(224); plot(s,BumpsHat) ; title('17 (d) Ideal Fourier Damping')
    
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
 
// scfig18 -- Short Course 18: Depict Deconvolution in Wavelet Domain
//
// The Figure depicts the wavelet deconvolution of Figure 2 in the 
// wavelet domain.
//
// Again, the noise is very large at high resolution. The resolution-
// dependent thresholds increase with the reciprocal of resolution 
// in an appropriate way,
//
mode(-1);  
scf(1);clf(1);
// if isempty(wcNaive),   // run figure 2
//      scfig02  
// end
// clf;

function WaveCoeffLim(wavecoef,scal,L,xlo,xhi)
// WaveCoeffLim -- Plot WT with non-standard limits of x-range
//
        if scal==0,
                scal = 1. / max(abs(wavecoef((2^L+1):max(size(wavecoef)))));
        end
        [n,J] = dyadlength(wavecoef);
        LockAxes([xlo xhi -(J) (-L+1)]);
//
        for j=J-1:-1:L
          tj = xlo + (.5:(2^(j)-.5))./2^(j) .* (xhi - xlo);
          base = -j;
          tt = [tj ; tj ; tj ];
          x = wavecoef(dyad(j)) .* scal;
          b = zeros(x) + base;
          xx = [b ; x+base ; b ];
          u = [ xlo     ; tt(:) ; xhi ];
          v = [  base ; xx(:) ; base ];
          plot(u,v);
        end
        UnlockAxes;
endfunction

subplot(221); 
WaveCoeffLim(wcObject  ,0.,5,-.5,1.5); title('18 (a) WT[Object]')
subplot(222); 
WaveCoeffLim(wcNaive   ,0.,5,-.5,1.5); title('18 (b) WT[Naive Reconstruction]')
subplot(223); 
WaveCoeffLim(wcDeNoised,0.,5,-.5,1.5); title('18 (c) WT[ WVD Reconstruction]')
    
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig19 -- Short Course 19: Display Vaguelette Kernels
//
// (Panels a-c) display three mother vaguelettes used in inversion
// of the Radon transform. The integral of sine-o-gram data
// against these vaguelettes will result in estimates of wavelet
// coefficients at scale-location (0,0) and orientation {Horizontal,
// Vertical, Diagonal}. (Panel d) shows one vaguelette having 
// undergone twisted dilation, so that it measures the wavelet 
// coefficient at scale 2^{-3} and location (kx=4,ky=2)
//
mode(-1);  
scf(1);clf(1);

demopath = get_absolute_file_path("SCDemo.sce");
loadmatfile(demopath+"/Figure19.mat");
//
// 	clf;  
    view = [-37.5 45];
	subplot(221); mesh(pfm,view);  title('19 (a) Gamma(0,0,Vert)')
	subplot(222); mesh(pmf,view);  title('19 (b) Gamma(0,0,Horiz)')
	subplot(223); mesh(pmm,view);  title('19 (c) Gamma(0,0,Diag)')
	subplot(224); mesh(real(pgen),view); title('19 (d) Gamma(j=3,(kx=4,ky=2),Diag)')
    
    
 halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig20 -- Short Course 20: Four Time-Frequency test signals
//
// We display here four signals used to study time-frequency DeNoising.
//
// QuadChirp: a quadratic chirp law
//
// MishMash: The superposition of QuadChirp with a linear chirp
//           and a high-frequency sinusoid.
// 
// Bumps:    Studied earlier (see Figures 5-9)
//
// Doppler:  Studied earlier (see Figures 5-9)
//
// We are interested in the extent to which one can recover
// oscillatory signals like QuadChirp and MishMash while still
// getting the advantages of wavelet reconstruction as in
// Bumps and Doppler
//
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	subplot(221); plot(tt,xQuad);    title(' 20 (a) QuadChirp ')
	subplot(222); plot(tt,xMish);    title(' 20 (b) MishMash ')
	subplot(223); plot(tt,uBumps);   title(' 20 (c) Bumps ')
	subplot(224); plot(tt,uDoppler); title(' 20 (d) Doppler ')
    
    
 
 halt("press a key to proceed!");
clc;mode(1);lines(0);

// scfig21 -- Short Course 21: Four Noisy Time-Frequency test signals
//
// We display here four noisy versions of the signals in Figure 20.
//
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	versaplot(221,tt,yQuad,[],   ' 21 (a) Noisy QuadChirp ',[],[])
	versaplot(222,tt,yMish,[],   ' 21 (b) Noisy MishMash ',[],[])
	versaplot(223,tt,vBumps,[],  ' 21 (c) Noisy Bumps ',[],[])
	versaplot(224,tt,vDoppler,[],' 21 (d) Noisy Doppler ',[],[])
    
    
 
 
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig22 -- Short Course 22: Wavelet Packet DeNoising
//
// In this figure, we DeNoise the signals in Figure 21
// by the following procedure
//
//    1.  Select a Wavelet Packet Basis minimizing the SURE
//        entropy criterion.  This is a criterion that estimates
//        the quality of thresholding reconstruction 
//        in a given basis.
//    2.  Apply soft thresholding in the adaptively selected basis.
//    3.  Reconstruct an estimate of the signal from its thresholded 
//        coefficients
//
// The results are competitive with wavelet-based methods on the two
// signals Bumps and Doppler that we previously restored by wavelet 
// methods.  The results are much better than wavelet methods on the
// two other signals.
//
mode(-1);  
scf(1);clf(1);
//
	D = 5;
	QCoif3         = MakeONFilter('Coiflet',3);
//
	wQuad          = WPDeNoise(yQuad,   D,QCoif3);
	wMish          = WPDeNoise(yMish,   D,QCoif3);
	wBumps         = WPDeNoise(vBumps,  D,QCoif3);
	wDoppler       = WPDeNoise(vDoppler,D,QCoif3);
//
// 	clf; 
	versaplot(221,tt,wQuad,   [],' 22 (a) WP Denoising QuadChirp',[],[])
	versaplot(222,tt,wMish,   [],' 22 (b) WP Denoising MishMash' ,[],[])
	versaplot(223,tt,wBumps,  [],' 22 (c) WP Denoising Bumps'    ,[],[])
	versaplot(224,tt,wDoppler,[],' 22 (d) WP Denoising Doppler'  ,[],[])
    
    
 
 
halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig23 -- Short Course 23: Compare Four DeNoising methods
//
// Here we compare the use of thresholding in four different transform
// domains:
//
//   ``Fourier''        -- discrete cosine transform
//   ``Wavelet''        -- nearly symmetric wavelet with 8 vanishing moments
//   ``Wavelet Packet'' -- adaptively selected Wavelet Packet basis
//   ``Cosine Packet''  -- adaptively selected Cosine Packet basis
//
// In each case, the noisy coefficients in the transform domain are
// subjected to thresholding, and the thresholded coefficients are
// inverse transformed to restore the object in question.
//
// To the author's eye, the Cosine Packet basis does the best job. Certainly
// the results are much better than the wavelets basis. 
// 
mode(-1);  
scf(1);clf(1);
//
// 	clf; 
	ax = [0. .25 -20 20];
	QSymm8 = MakeONFilter('Symmlet',8);
	[n,J] = dyadlength(yMish);
	thr = sqrt(2*log(n));
//
// dct-iv
//
	c = dct_iv(yMish);
	dc = c(1);
	chat = SoftThresh(c,thr);
	chat(1) = dc;   // don't shrink DC component
	xDCT = dct_iv(c);
	versaplot(221,tt,xDCT,[],' 23 (a) Cosine Basis De-Noising',ax,[]);
//
// Wavelets
//
	[xWave,wcWave] = WaveShrink(yMish,'Visu',6,QSymm8);
	versaplot(222,tt,xWave,[],' 23 (b) Wavelet Basis De-Noising',ax,[]);
//
// Wavelet packet
//
	xWP = WPDeNoise(yMish,6,QSymm8);
	versaplot(223,tt,xWP ,[],' 23 (c) Wavelet Packet Basis De-Noising',ax,[]);
//
// Cosine packet
//
	xCP = CPDeNoise(yMish,6,'Sine');
	versaplot(224,tt,xCP ,[],' 23 (d) Cosine Packet Basis De-Noising',ax,[]);
    
    
    
 halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig24 -- Short Course 24: Compare Segmented and Ordinary Refinement
//
// (Panel a) shows signal ``Ramp'' with a discontinuity, and the results of
// refining its coarse-scale averages by segmented MRA (Panel a) and 
// by ordinary MRA (Panel b).
//
// Segmented refinement **with correct choice of segmentation** reconstructs
// the fine-scale version of Ramp *perfectly* from the coarse-scale averages.
//
// Non-segmented refinement smooths out the discontinuity.
//
mode(-1);  
scf(1);clf(1);


	afine = zeros(1,128);
	afine(1:37) = ((1:37) - .5)./37;
	afine(38:128) = ((38:128) - 38.5)./91;
	a2 = HCoarsen(afine,1);
	ac = HCoarsen(a2,1);
	E2 = MakeAIBdryFilter(2);
	F2 = MakeAIFilter(2);
	t = 37 ./128;
//
	r2 = SegRefine(ac,2,F2,E2,t,5);
	r4 = SegRefine(r2,2,F2,E2,t,6);
	o2 = AIRefine(ac,2,F2,E2);
	o4 = AIRefine(o2,2,F2,E2);
//
// 	clf;
	ax = [ 0 100 0 2];
	versaplot(211,[],afine,'.',' 24 (a) Segmented Multi-Resolution Analysis',ax,1);
	plot(r4); //hold off;
	aa=gca();aa.data_bounds=([ 0 100 0 2]);
	versaplot(212,[],o4,   '.',' 24 (b) Ordinary Multi-Resolution',ax,0)
    

halt("press a key to proceed!");
clc;mode(1);lines(0);
// scfig25 -- Short Course 25: DeNoising a segmented transform
// 
// Here we show the results of DeNoising by applying thresholding
// to the empirical wavelet coefficients in an ideally-segmented
// wavelet transform (Panel d); for comparison we also show ordinary 
// wavelet threshold  DeNoising (Panel c).
//
mode(-1);  
scf(1);clf(1);


	afine = zeros(1,1024); it = 37 * 1024 /128 ;
	afine(1:it) = ((1:it) - .5)./it;
	afine((it+1):1024) = (((it+1):1024) - (it+1.5)) ./ (1024-it);
	afine = afine * 5;
	E2 = MakeAIBdryFilter(2);
	F2 = MakeAIFilter(2);
	t = 37 ./128;
//
	y = afine + WhiteNoise(afine);
// 	clf;  
    ax= [0 1000 -5 10];
	versaplot(221,[],afine,[],' 25 (a) Signal',ax,[])
	versaplot(222,[],y,    [],' 25 (b) Noisy' ,ax,[])
//
	QMF_Filter  = MakeONFilter('Coiflet',3); 
	xhat = WaveShrink(y,'Visu',4,QMF_Filter);
//
	versaplot(223,[],xhat,[],' 25 (c) Ordinary Periodized Wavelet Denoising',ax,[])
//
	L=4; D=2;
	wc = FWT_SegAI(y,L,D,F2,E2,t);
	shc= MultiVisu(wc,L);
	sy = IWT_SegAI(shc,L,D,F2,E2,t);
//
	versaplot(224,[],sy,[],' 25 (d) Segmented Denoising',ax,[])
    


    halt("press a key to proceed!");
clc;mode(1);lines(0);

// scfig26 -- Short Course 26: Sine signal with Cauchy Contamination
//
// (Panel a) shows a sinusuoid and (Panel b) the same sinusoid
// contaminated with Cauchy noise. Cauchy noise has infinite variance and
// hence enormous outliers.  Those outliers skew the plot scaling so that
// they are the only thing visible in (Panel b).
//
mode(-1);  
scf(1);clf(1);
//
	SineSig = 4 .* sin( (1:729) ./40 );
// 	clf; 
	versaplot(211,[],SineSig,[],' 26 (a) Signal',[],[])
//
	z = WhiteNoise(SineSig) ./ WhiteNoise(SineSig); // Cauchy = Z/Z
	ySine = SineSig+z;
	versaplot(212,[],ySine,[],' 26 (b) Signal with Cauchy Noise',[],[]);
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
 
// scfig27 -- Short Course 27: Linear Smoothing of Cauchy Noise
//
// Here we show the results of ``linear de-noising'':
//
//  (i) set to zero all the wavelet coefficients at the finest scales of 
//      analysis;
// (ii) reconstruct from the modified coefficient set
//
// Ordinarily, this acts as a smoothing operator.
//
// With Cauchy data it has very little effect; the sinusoidal nature of 
// the signal is still hidden after smoothing.
//
mode(-1);  
scf(1);clf(1);
//
// clf;
HaarQMF = MakeONFilter('Haar');
//
	wc = FWT_PO(ySine(1:512),1,HaarQMF);
	wc(dyad(8)) = 0 .* wc(dyad(8));
	xhat = IWT_PO(wc,1,HaarQMF);
	versaplot(221,[],xhat,[],' 27 (a) Linear Recovery; Kill Dyad Level 8',[],[]);
//
	wc(dyad(8)) = 0 .* wc(dyad(8));
	xhat = IWT_PO(wc,1,HaarQMF);
	versaplot(222,[],xhat,[],' 27 (b) Linear Recovery; Kill Dyad Levels 7 & 8',[],[]);
    
    
    
 halt("press a key to proceed!");
clc;mode(1);lines(0);
 
// scfig28 -- Short Course 28: Robust De-Noising
//
// Here we apply a robust wavelet transform where ``low-pass filtering''
// is replaced by applying medians of 3 in a triadic multi-resolution 
// analysis.
//  
// The nonlinear smoothing operator which results from setting to zero those
// coefficients at the finest scales has a pronounced noise-killing effect. 
// It restores the underlying sinusoidal character of the signal.
//
//
mode(-1);  
scf(1);clf(1);

//
SineSig = 4 .* sin( (1:729) ./40 );                             //Am 10/05
z = WhiteNoise(SineSig) ./ WhiteNoise(SineSig); // Cauchy = Z/Z
ySine = SineSig+z;                                              //AM 10/05
//
	wc = FHT_Med(ySine);
	wc(triad(6)) = 0 .* wc(triad(6)) ;
	xhat6 = IHT_Med(wc);
//
	ax = [0 length(ySine) -10 10];
	versaplot(221,[],xhat6,[],' 28(a) (Nonlinear MRA) Kill Triad Level 6',ax,[])
//
	wc(triad(5)) = 0 .* wc(triad(5)) ;
	xhat = IHT_Med(wc);
	versaplot(222,[],xhat,[],' 28(b) (Nonlinear MRA) Kill Triad Levels 5 & 6',ax,[])
//
	wc(triad(4)) = 0 .* wc(triad(4)) ;
	xhat = IHT_Med(wc);
	versaplot(223,[],xhat,[],' 28(c) (Nonlinear MRA) Kill Triad Levels 4, 5 & 6',ax,[])
    
    
    
  
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:42 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
