mode(-1);
function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction


function CompressoGram(Sig,QMF_Filter)
// CompressoGram -- compare compress abilities of four transforms
//

// Haar Transform
        HaarQMF = MakeONFilter('Haar');
        hSig = FWT_PO(Sig,1,HaarQMF);
        epsilon = 1.e-16;
        ehSig = reverse(cumsum(mtlb_sort(hSig.^2)))/sum(hSig.^2) + epsilon;
// Cosine Transform
        fSig = dct_iv(Sig);
        efSig = reverse(cumsum(mtlb_sort(fSig.^2)))/sum(fSig.^2) + epsilon;
// Wavelet Transform
        wSig = FWT_PO(Sig,5,QMF_Filter);
        ewSig = reverse(cumsum(mtlb_sort(wSig.^2)))/sum(wSig.^2) + epsilon;
        i = 1:length(ewSig);
//
        LockAxes([0 length(ewSig)/2 -8 0]);
        xlabel('n')
        ylabel('Log(c_n)')
        plot(i,log(ewSig),'r-');
        plot(i,log(ehSig),'g-.');
        plot(i, log(efSig),'c--')
        UnlockAxes

//       Revision History
//               09/29/99        DLD        added epsilon to avoid log(0)
//       10/1/05     AM     Changing the name of the variable QMF

endfunction

function [t,g] = LogoGram(ser)
// LogoGram -- Time Series Spectrum Estimation
//  Usage
//    [t,g] = LogoGram(ser)
//  Inputs
//    ser      zero-mean time series, dyadic length
//  Outputs
//    t        ordinate of logogram
//    g        abscissa of logogram
//
n = max(size(ser));
Ij = abs(Wavelab_fft(ser)).^2 ./ ( n);
Yj = log(Ij) + .57721;
Yj(1) = Yj(1) - .57721 + (log(2) + .57721)/%pi ;
Yj(n/2+1) = Yj(n/2+1) - .57721 + (log(2) + .57721)/%pi ;
g = Yj .* sqrt(6)/%pi;
t = 2 * %pi * (0: (n-1)) ./ n;
endfunction
//
function WaveCoeffLim(wavecoef,scal,L,xlo,xhi)
// WaveCoeffLim -- Plot WT with non-standard limits of x-range
//
        if scal==0,
                scal = 1. / max(abs(wavecoef((2^L+1):max(size(wavecoef)))));
        end
        [n,J] = dyadlength(wavecoef);
        LockAxes([xlo xhi -(J) (-L+1)]);
//
        for j=J-1:-1:L
          tj = xlo + (.5:(2^(j)-.5))./2^(j) .* (xhi - xlo);
          base = -j;
          tt = [tj ; tj ; tj ];
          x = wavecoef(dyad(j)) .* scal;
          b = zeros(x) + base;
          xx = [b ; x+base ; b ];
          u = [ xlo     ; tt(:) ; xhi ];
          v = [  base ; xx(:) ; base ];
          plot(u,v);
        end
        UnlockAxes;
endfunction
function [t,y] = rootogram(x,n)
// Rootogram -- compute rootogram of counts data
//  Usage
//    [t,y] = rootogram(x,n)
//  Inputs
//    x        sample of data, no need for dyadic length
//    n        number of bins, dyadic
//  Outputs
//    t        ordinate of rootogram
//    y        abscissa of rootogram
//
[t,y] = fasthist(x,n);
y = sqrt(y + .375);
    
    
endfunction
function [bloc,count] = fasthist(w,M)
// FastHist -- fast histogram tool
	q = (max(w) - min(w))/ M ;
	lo = min(w);
	x = mtlb_sort( [ (0:(M-1)) floor( (w -lo) / q )] );
	x(max(size(x))) = M-1;
	y = diff([(-1) x]) > .01 ;
	n = 1:max(size(x));
	cum = [n( y) (max(size(x))+1)];
	count = (diff(cum)-1);
	count = count(1:M);
	bloc = lo + (0:(M-1)).*q;
    
endfunction

	     N = 2048;


	     rho = 7;

	      alf = .9;

	t = (0:(N-1))/N;
//
	disp('Initializing Parameters:')
	disp(sprintf('N = %g',N))
	disp(sprintf('rho = %g',rho))
	disp(sprintf('alf = %g',alf))
//
	HeaviSine = MakeSignal('HeaviSine',N);
	Bumps     = MakeSignal('Bumps',N);
	Blocks    = MakeSignal('Blocks',N);
	Doppler   = MakeSignal('Doppler',N);
//
	[xblocks,yblocks] = NoiseMaker(Blocks,rho);
	[xbumps,ybumps]   = NoiseMaker(Bumps,rho);
	[xheavi,yheavi]   = NoiseMaker(HeaviSine,rho);
	[xDoppler,yDoppler] = NoiseMaker(Doppler,rho);
    
clc;mode(1);lines(0);
// toufig01 -- Tour Figure 01: Four Spatially Inhomogenoeus Signals
//
// These four signals are caricatures of signals arising
// in scientific signal processing.
//
// Blocks is a piecewise constant signal, a caricature of a scan line
// through a 2-d image depicting an object with several edges.
//
// Bumps is a very peaky signal, a caricature of an NMR Spectrum.
// 
// HeaviSine is a sinusoid with two clicks.
//
// Doppler is an attenuating sinusoid with time-varying frequency.
//
// These objects are interesting to us because they portray significant
// spatial inhomogeneity.
//
mode(-1);  
scf(1);clf(1);
//
// clf;
versaplot(221,t,xblocks, [],' 1 (a) Blocks '   ,[],[])
versaplot(222,t,xbumps,  [],' 1 (b) Bumps '    ,[],[])
versaplot(223,t,xheavi,  [],' 1 (c) HeaviSine ',[],[])
versaplot(224,t,xDoppler,[],' 1 (d) Doppler '  ,[],[])

       halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig02 -- Tour Figure 02: Noisy Versions of Four Signals
//
// The four objects of Figure 1 with white noise superposed.
// The noise is normally distributed with variance 1.
//
// 
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	versaplot(221,t,yblocks, [],' 2 (a) Noisy Blocks '   ,[],[])
	versaplot(222,t,ybumps,  [],' 2 (b) Noisy Bumps '    ,[],[])
	versaplot(223,t,yheavi,  [],' 2 (c) Noisy HeaviSine ',[],[])
	versaplot(224,t,yDoppler,[],' 2 (d) Noisy Doppler '  ,[],[])
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);   
// toufig03 -- Tour Figure 03: Wavelet Shrinkage of the Four Noisy Signals
//
// Here we aapply a specific thresholding rule to the
// four noisy signals depicted in Figure 5.
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a soft thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
// The reconstructions suppress the noise, while preserving the sharp structure
// in the neighborhood of the highly-variable spatial components.
//
mode(-1);  
scf(1);clf(1);
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks] = WaveShrink(yblocks,  'Visu',L,QMF_Filter);
	[xhbumps]  = WaveShrink(ybumps,   'Visu',L,QMF_Filter);
	[xhheavi]  = WaveShrink(yheavi,   'Visu',L,QMF_Filter);
	[xhDoppler] = WaveShrink(yDoppler,'Visu',L,QMF_Filter);
//
// 	clf;
	versaplot(221,t,xhblocks, [],' 3 (a) VisuShrink[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],' 3 (b) VisuShrink[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],' 3 (c) VisuShrink[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],' 3 (d) VisuShrink[yDoppler] '  ,[],[])
	
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig04 -- Tour Figure 04: AutoSpline Reconstructions from Noisy Data
//
// Here we depict a reconstruction using penalized thin-plate splines,
// in which periodic thin-plate splines are used to smooth the data,
// with roughness penalty proportional to the energy stored in the
// second derivative.  The constant of proportionality (or Lagrangian
// tuning parameter) is the empirical minimizer of the Stein Unbiased
// Estimate of Risk.
//
mode(-1);  
scf(1);clf(1);
// 
// clf;
// SplineInit
//
	[xhat, c] = SplineUChoose(yblocks,2.);
	versaplot(221,t,xhat,[],' 4 (a) AutoSpline[Blocks]',[],[])
//
	[xhat,c] = SplineUChoose(ybumps,2.);
	versaplot(222,t,xhat,[],' 4 (b) AutoSpline[Bumps]',[],[])
//
	[xhat,c] = SplineUChoose(yheavi,2.);
	versaplot(223,t,xhat,[],' 4 (c) AutoSpline[HeaviSine]',[],[])
//
	[xhat,c] = SplineUChoose(yDoppler,2.);
	versaplot(224,t,xhat,[],' 4 (d) AutoSpline[Doppler]',[],[])
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);   
// toufig05 -- Tour Figure 05: AutoTrunc Truncated Fourier Reconstructions
//
// Here we depict a reconstruction using truncated Fourier expansions,
// in which only the low-order fourier components of the noisy signal
// are retained in reconstruction. The cut-off point for reconstruction
// in the frequency domain is the empirical minimizer of the Stein Unbiased
// Estimate of Risk.
//
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	xhat = AutoTrunc(yblocks,1.);
	versaplot(221,t,xhat,[],' 5 (a) AutoTrunc[yBlocks]',[],[])
//
	xhat = AutoTrunc(ybumps,1.);
	versaplot(222,t,xhat,[],' 5 (b) AutoTrunc[yBumps]',[],[])
//
	xhat = AutoTrunc(yheavi,1.);
	versaplot(223,t,xhat,[],' 5 (c) AutoTrunc[yHeaviSine]',[],[])
//
	xhat = AutoTrunc(yDoppler,1.);
	versaplot(224,t,xhat,[],' 5 (d) AutoTrunc[yDoppler]',[],[])
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);   
// toufig06 -- Tour Figure 06: WaveShrink of object yBlocks in Haar Basis
//
// (Panel a) depicts the noisy object yBlocks, its Haar transform (Panel c),
// wavelet shrinkage reconstruction using the Haar wavelet (Panel b), and 
// the Haar Transform of the reconstruction (Panel d).
//
// The viewer is supposed to notice that in the Haar domain, the
// noise is spread out among all coefficients, while the signal is
// concentrated in only a few coefficients. Hence thresholding mostly
// affects the noise without disturbing the signal.
//
mode(-1);  
scf(1);clf(1);
//
	HL = 3; 
	HQMF       = MakeONFilter('Haar');
	[x,y]      = NoiseMaker(Blocks,7);
	[xhat,xw]  = WaveShrink(y,'Visu',HL,HQMF);
	yw         = FWT_PO(y,HL,HQMF);
//
// 	clf; 
    scal = .05;
	versaplot(221,t,y,   [],' 6 (a) Noisy Data y',            [0 1 (-20) (20)],[]);
	versaplot(222,t,xhat,[],' 6 (b) VisuShrink Reconstruction',[0 1 (-20) (20)],[]);
	subplot(223);
	PlotWaveCoeff(yw,HL,scal); title(' 6 (c) Haar[y]')
	subplot(224);
	PlotWaveCoeff(xw,HL,scal); title(' 6 (d) Haar[Reconstruction]')


   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig07 -- Tour Figure 07: Comparing Compression Abilities
//
// Here we depict the compression numbers c_n in three different
// signal domains {Wavelet, Haar, Cosine} of four different signals
// {Bumps, Blocks, HeaviSine, and Doppler}. The numbers c_n are the
// mean-squared reconstruction errors of reconstructions which use
// at most n nonzero coefficients in the transfrom domain. 
//
// Blocks: The Haar Basis has the best compression numbers,
// for obvious reasons.  The Wavelet basis is not bad, and the Fourier basis
// is far worse than either the Wavelet or Haar basis.
//
// Bumps: The Wavelet Basis has the best compression numbers, with the Haar
// not bad, and the Fourier basis being far inferior.
//
// HeaviSine: The near-sinusoidal behavior make the Fourier basis a good choice
// but Wavelets really are not bad here. Surprisingly, if very high accuracy is
// required, the Haar basis beats Fourier, because the Fourier basis has trouble 
// modelling jumps.
//
// Doppler: Wavelets are much better than either Fourier or Haar.
//
mode(-1);  
scf(1);clf(1);
//
QSymm8 = MakeONFilter('Symmlet',8);
// clf; 
//
   subplot(221)
   CompressoGram(Blocks,QSymm8)
   title('7 (a) Blocks')
//
   subplot(222)
   CompressoGram(Bumps,QSymm8)
   title('7 (b) Bumps')
//
   subplot(223)
   CompressoGram(HeaviSine,QSymm8)
   title('7 (c) HeaviSine')
//
   subplot(224)
   CompressoGram(Doppler,QSymm8)
   title('7 (d) Doppler')

   halt("press a key to proceed!");
clc;mode(1);lines(0);

// toufig08 -- Tour Figure 08: Root-Density example
//  1. take a random sample from a mixture of 3 Gaussians
//  2. Bin the data, obtaining counts
//  3. Take an appropriate square root transform of the counts
//  4. Apply Wavelet Shrinkage to the root-counts
//    
mode(-1);  
scf(1);clf(1);
	N = 1024;
	z = zeros(1,N);
	z = WhiteNoise(z);
	u = zeros(1,N);
	// rand('uniform');
	u = rand(size(u));
	z(u < .3) = 1 + z(u < .3) ./ 5;
	z(u >= .3) = 1.6 + z(u >= .3) ./ 7;
	z(u >= .8) = z( u >= .8) + .6;
//   2.  make rootogram
	[t,r] = rootogram(z,256);
//   3.  standardize
	y = 2.*r;
//   4.  wavelet shrinkage 
	QMF_Filter = MakeONFilter('Symmlet',8);
	[xh,wcoef] = WaveShrink(y,'Visu',4,QMF_Filter);
//   5.  plot
// 	clf; 
	subplot(211); plot(t,r); title('8 (a) Rootogram')
	subplot(212); plot(t,xh); title('8 (b) Wavelet Smoothed')


   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig09 -- Tour Figure 09: Estimating Time Series Spectrum
//
// Here we illustrate the use of Wavelet Shrinkage in a time series setting.
// Our example is taken from Hong-Ye Gao's 1993 Ph.D. Thesis, U.C. Berkeley
// The example is constructed as follows.
//    1. Generate ARMA(24,1) Time Series having spectrum with poles near unit 
//       circle. This gives a log-spectrum with significant peaks.
//    2. Calculate the log-periodogram of the series; normalize it by the 
//       Wahba (1980) Variance-Stabilizing transform.
//    3. Apply Wavelet Shrinkage to the normalized log-periodogram
//
//
mode(-1);  
scf(1);clf(1);
	Fig9Filter = [1 -2.5216281  4.7715359  -7.9199915  11.9769211  -16.0778828  ...
        20.6343346  -25.0531521  28.8738136  -31.8046265  34.0071373 ...
        -34.7700272  34.3151321  -32.7861099  30.2861233  -26.7109356 ...
        22.8838310  -18.7432098  14.5717688  -10.7177744  7.5322194  ...
        -4.7226319  2.6807923  -1.3391306  0.5167125];
// 1. Generate ARMA Process
	z   = WhiteNoise(zeros(1,4096));
	ser = filter(1,Fig9Filter,z) + .01 .* WhiteNoise(z); // Recursive Filter
	ser = ser(2049:4096); // kill transients
// 2. Generate Log-o-Gram
	[tt,g] = LogoGram(ser);
// 3. Wavelet Shrinkage
	QMF_Filter        = MakeONFilter('Symmlet',8);
	[xh,wcoef] = WaveShrink(g,'Visu',7,QMF_Filter);
// 4. Figures
// 	clf; 
	versaplot(211,tt,g,[],'9 (a) LogoGram',[0 %pi -5 10],[]);
	versaplot(212,tt,xh,[],'9 (b) Wavelet Smoothed',[0 %pi -5 10],[]);


   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig10 -- Tour Figure 10: Noisy Differentiation
//
// Here we illustrate the use of wavelets for noisy differentiation.
// (Panel a) displays object Bumps, (panel b) its noisy cumulative, 
// and (Panel c) a naive inversion based on differencing. The naive inversion 
// is very noisy, and displays only a hint of the structure of the underlying
// function.
//
// We also display a wavelet-shrinkage reconstruction, in which noise is
// suppressed while the structure remains. 
//
// The wavelet-shrinkage reconstruction goes as follows
//
//       1.  Transform the naive reconstruction into the wavelet domain.
//       2.  Apply level-dependent thresholds which scale inversely with 
//           resolution.
//       3.  Return to the wavelet domain.
//
//  Coiflets with 3 vanishing moments are used.
//
mode(-1);  
scf(1);clf(1);
//
	zBumps = cumsum(Bumps);
	N = length(Bumps);
	t = (0:(N-1))/N;
	x = zBumps + WhiteNoise(zBumps);
	z = diff([0 x]);
//
	QMF_Filter = MakeONFilter('Coiflet',3);
	w    = FWT_PO(z, 5,QMF_Filter);
	ws   = InvShrink(w,5,4,1);
	zrec = IWT_PO(ws,5,QMF_Filter);
//
	wb = FWT_PO(Bumps,5,QMF_Filter);
//
// 	clf;
	subplot(221); plot(t,Bumps); title('10 (a) Object Bumps')
	subplot(222); plot(t,x); title('10 (b) Noisy Cumulative')
	subplot(223); plot(t,z); title('10 (c) Difference of Noisy Cumulative')
	subplot(224); plot(t,zrec); title('10 (d) WVD Reconstruction')


   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig11 -- Tour Figure 11: Noisy Differentiation in Wavelet Domain
//
// Here the procedure of Figure 16 is displayed in the Wavelet domain.
//
// The noise in the naive inversion grows rapidly in size 
// as we move to finer resolutions.
//
mode(-1);  
scf(1);clf(1);
//
// 	clf;
	subplot(221); PlotWaveCoeff(wb,5,0.); title('11 (a) WT[Object]')
	subplot(222); PlotWaveCoeff(w,5,0.); title('11 (b) WT[ Naive Reconstruction ]')
	subplot(223); PlotWaveCoeff(ws,5,0.); title('11 (c) WT[ WVD Reconstruction ]')
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig12 -- Tour Figure 12: Noisy Differentiation by Ideal Fourier Damping
//
// This figure displays the results of an ideal Fourier Damping
// for deconvolution, in which each frequency is damped optimally
// based on its signal-to-noise ratio.
//
// Unlike the wavelet thresholding of Figure 15, ideal Fourier
// damping is not able to suppress noise while preserving resolution.
//
mode(-1);  
scf(1);clf(1);
//
	sig = cumsum(Bumps) + WhiteNoise(Bumps);
	x = diff([0 sig]);
//
	z = Wavelab_fft(x);
	w = Wavelab_fft(Bumps);
	omega = 2 * %pi .* (0:(length(w)-1)) ./ length(w);
	sigma2 = length(x) .* 4 .* sin(omega/2).^2;
	wate = abs(w).^2 ./ (abs(w).^2 + sigma2);
	whate = wate .* z;
	BumpsHat= real(Wavelab_ifft(whate));
//
	s = linspace(0,1,length(x));
// 	clf; 
	subplot(221); plot(s,Bumps) ; title('12 (a) Object')
	subplot(222); plot(s,sig); title('12 (b) Noisy Cumulative')
	subplot(223); plot(s,x) ; title('12 (c) Difference of Noisy Cumulative')
	subplot(224); plot(s,BumpsHat) ; title('12 (d) Ideal Fourier Damping')
    

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig13 -- Tour Figure 13: Noisy Deconvolution
//
// In this example, the object ``Bumps'' is convolved with a recursive
// filter that blurs out the sharp structure; and then noise is added.
// (panels a,b)
//
// The deconvolution problem is ill-posed, in that when we apply the
// inverse filter, we get an object which is extremely noisy and has
// no real resemblance to the original object. (panel c)
//
// When we apply thresholding in the wavelet domain, with thresholds
// specially chosen to adapt to the structure of the deconvolution
// problem, we get a reconstruction which is nearly noise free and which
// also preserves the structure of the Bumps object. (panel d)
//
mode(-1);  
scf(1);clf(1);
//
	N2 = length(Bumps)/2;
	x = [ zeros(1,N2) Bumps zeros(1,N2)];
	tt = [ linspace(-.5,(-1) ./ (2*N2), N2) t linspace(1 + 1 ./ (2*N2), 1.5, N2)];
	sx = filter(1,[1 ((-2 * alf)) (alf^2)],x);
	nsx = sx + WhiteNoise(sx);
	dnsx = filter([1 ((-2 * alf)) (alf^2)],1,nsx);
//
	QMF_Filter  = MakeONFilter('Coiflet',2);
	w    = FWT_PO(dnsx, 5, QMF_Filter);
	ws   = MultiMAD(w,5);
	recx = IWT_PO(ws,5,QMF_Filter);
//
	wb   = FWT_PO(x,5,QMF_Filter);
//
// 	clf;
	subplot(221); plot(tt,x); title('13 (a) Object')
	subplot(222); plot(tt,sx); title('13 (b) Noisy Blurred')
	subplot(223); plot(tt,dnsx); title('13 (c) Naive DeBlurred')
	subplot(224); plot(tt,recx); title('13 (d) WVD Reconstruction')

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig14 -- Tour Figure 14: Depict Deconvolution in Wavelet Domain
//
// The Figure depicts the wavelet deconvolution of Figure 2 in the 
// wavelet domain.
//
// Again, the noise is very large at high resolution. The resolution-
// dependent thresholds increase with the reciprocal of resolution 
// in an appropriate way,
mode(-1);  
scf(1);clf(1);
// clf;
//
	zBumps = cumsum(Bumps);                 //AM 10/05
    x = zBumps + WhiteNoise(zBumps);        //AM 10/05
	z = diff([0 x]);                        //AM 10/05
    QMF_Filter = MakeONFilter('Coiflet',3); //AM 10/05
	w    = FWT_PO(z, 5,QMF_Filter);         //AM 10/05
	ws   = InvShrink(w,5,4,1);              //AM 10/05
	wb = FWT_PO(Bumps,5,QMF_Filter);        //AM 10/05
//
	subplot(221); 
	WaveCoeffLim(wb,0.,5,-.5,1.5); title('14 (a) WT[Object]')
//
	subplot(222); 
	WaveCoeffLim(w ,0.,5,-.5,1.5); title('14 (b) WT[Naive Reconstruction]')
//
	subplot(223); 
	WaveCoeffLim(ws,0.,5,-.5,1.5); title('14 (c) WT[ WVD Reconstruction ]')
    

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// toufig15 -- Tour Figure 15: Display Vaguelette Kernels
//
// (Panels a-c) display three mother vaguelettes used in inversion
// of the Radon transform. The integral of sine-o-gram data
// against these vaguelettes will result in estimates
// of wavelet coefficients at scale-location (0,0) and orientation
// {Horizontal, Vertical, Diagonal}. (Panel d) shows one vaguelette 
// having undergone twisted dilation, so that it measures the wavelet 
// coefficient at scale 2^{-3} and location (kx=4,ky=2)
//
// 
mode(-1);  
scf(1);clf(1);
demopath = get_absolute_file_path("TourDemo.sce");
loadmatfile(demopath+"/Figure19.mat");

if ~exists('pfm'),
   disp('Sorry -- data not available for figure 15')
else
  //clf;
  view = [-37.5 45];
  subplot(221); mesh(pfm,view); title('15 (a) Gamma(0,0,Vert)')
  subplot(222); mesh(pmf,view); title('15 (b) Gamma(0,0,Horiz)')
  subplot(223); mesh(pmm,view); title('15 (c) Gamma(0,0,Diag)')
  subplot(224); mesh(real(pgen),view); title('15 (d) Gamma(j=3,(kx=4,ky=2),Diag)')
end
    
    
 

      
 


