clc;mode(1);lines(0);
// vdlfig01 -- Plot of Doppler Signal
//
// Display the Doppler signal built-into WaveLab.
//
// Distribution of datasets, both synthetic and real, is a crucial
// part of reproducibility.  Here we illustrate one interface to
// retrieving such data from WaveLab.
//
mode(-1);  
scf(1);clf(1);
doppler = MakeSignal('Doppler',1024);
plot(doppler);
title('Figure 1: Doppler Signal');
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig02 -- Plot of Meyer wavelet
//
// WaveLab offers a full complement of wavelet transforms: the standard
// orthogonal periodized, standard boundary-corrected, standard periodized
// biorthogonal, the "Deslaurier-Dubuc" wavelets (based on interpolating
// schemes) and the Meyer wavelet, studied in the Stanford Ph.D. thesis
// of Eric Kolaczyk.
//
// Here we display a Meyer wavelet with a third-order polynomial window.
//
mode(-1);  
scf(1);clf(1);
meyer=MakeWavelet(4,7,'Meyer',3,'Mother',1024);
plot(meyer);
title('Figure 2: Meyer Wavelet');
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig03 -- 95% wavelet/dct compression of seismic signal
//
// Wavelets have been used successfully to compress data.  By compression
// we mean reconstructing from a subset of the entire list of n coefficients
// that represent the transform of a signal of length n, i.e. setting the
// others to zero.  Here we illustrate the Seismic signal (built-into
// WaveLab) and show both the Wavelet and DCT reconstructions based on 5%
// of its original 1024 coefficients.
//
// The visual superiority of the wavelet reconstruction is evident.
//
mode(-1);  
scf(1);clf(1);
	Trace = ReadSignal('Seismic')';
	n = length(Trace);
	p = ceil(n*.05);
//
	qmf = MakeONFilter('Coiflet',3);
	wc  = FWT_PO(Trace,4,qmf);
//
	wprev       = reverse((mtlb_sort(wc.^2)));
	thresh      = sqrt(wprev(p));
	wct         = wc .* bool2s(abs(wc) >= thresh);
	wave_recon  = IWT_PO(wct,4,qmf);
//
	dctcoef     = dct_iv(Trace);
//
	dcrev       = reverse((mtlb_sort(dctcoef.^2)));
	thresh      = sqrt(dcrev(p));
	dctt        = dctcoef .* bool2s(abs(dctcoef) >= thresh);
	dct_recon   = dct_iv(dctt);
//
	subplot(3,1,1)
	plot(Trace)
	title('Figure 3(a): Seismic Trace')
	//ax = axis;
//	
	subplot(3,1,2)
	plot(wave_recon)
	title('Figure 3(b): 5% Wavelet Reconstruction');
	//axis(ax);
//	
	subplot(3,1,3)
	plot(dct_recon)
	title('Figure 3(c): 5% DCT Reconstruction');
	//axis(ax);


   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig04 -- 95% wavelet/dct compression curves for Ingrid Daubechies
//
// Compression curves plot l^2 reconstruction error versus the number of
// coefficients used in the reconstruction.  Here we illustrate an image of
// Ingrid Daubechies, part of WaveLab's standard dataset distribution, and
// the compression curves for both Wavelets and DCT.  They provide a formal
// way to illustrate the compressibility of different transforms.
//
mode(-1);  
scf(1);clf(1);
	ingrid = ReadImage('Daubechies');
//
	subplot(211);
	GrayImage(ingrid,256);
	title('Figure 4(a): Ingrid Daubechies');
//
	qmf = MakeONFilter('Coiflet',2);
	wingrid = FWT2_PO(ingrid,3,qmf);
	wcsort = mtlb_sort(abs(wingrid(:)));
	wcerr = cumsum(wcsort.^2);
	wcerr = flipud(wcerr);
//
	fingrid = dct2_iv(ingrid);
	fcsort = mtlb_sort(abs(fingrid(:))); 
	fcerr = cumsum(fcsort.^2);
	fcerr = flipud(fcerr);
//
	front = 1:5537;
	ymax = fcerr(1);
	txt1 = log10(ymax)-1;
	txt2 = log10(ymax)-1.5;
//
	subplot(212);
	plot2d([fcerr(front);wcerr(front)],logflag="nl"); //hold
	//semilogy(wcerr(front),logflag="nl"); 
	xlabel('Number of Coefficients Retained'); ylabel('sum(error^2)')
	title('Figure 4(b): Wavelet Compression vs. DCT Compression on Ingrid')
	xstring(4000,10^txt1,'DCT --'); //set(h,'Color','Yellow');
	xstring(4000,10^txt2,'DWT -');  //set(h,'Color','Red');	
	//hold off;
    
// 
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig05 -- Use stationary Haar transform to denoise Blocks
//
// Since the Wavelet transform is not translation-invariant, in denoising
// it makes sense to average the denoising process in some sense over
// all translations of the data (see SpinDemo for more examples).  Here we
// show the signal Blocks, noise added to it, and both the VisuThresh
// denoising and the translation-invariant denoising techniques.
//
mode(-1);  
scf(1);clf(1);
	N = 2048;
	t = (0:(N-1))/N;
	L = 2;
	qmf = MakeONFilter('Haar');
	Blocks = MakeSignal('Blocks',N);
//
	[xblocks,yblocks] = NoiseMaker(Blocks,4);
//
	dhblocks = WaveShrink(yblocks,'Visu',L,qmf);
//
	D = 6; 
	thr = sqrt(2* log(N));
	[tiwtblocks] = FWT_TI(yblocks,L,qmf);
	thrwtblocks = tiwtblocks;
	[nr,nc] = size(tiwtblocks);
	thrwtblocks(:,2:nc) = SoftThresh(tiwtblocks(:,2:nc),thr);
	[xhblocks]  = IWT_TI(thrwtblocks,qmf);
//
	ax = [0 1 -4 12];
         
	subplot(411);plot(t,xblocks);title('Figure 5: De-Noising of Blocks');
        a=gca();a.data_bounds=ax;
	ylabel('Blocks');
	subplot(412);plot(t,yblocks);
        a=gca();a.data_bounds=ax;
	ylabel('Noisy');
	subplot(413);plot(t,dhblocks);
        a=gca();a.data_bounds=ax;
	ylabel('Haar');
	subplot(414);plot(t,xhblocks);
        a=gca();a.data_bounds=ax;
	ylabel('TI');
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig06 -- Show WP and CP phase planes for Tweet signal
//
// Here we display the WP and CP phase planes for the Tweet signal.
// This illustrates an artifact of wavelet packets caused when the
// signal of interest concentrates near a frequency with simple dyadic
// structure.  The cosine packets phase plane is dramatically clearer.
//
mode(-1);  
scf(1);clf(1);
	tweet = ReadSignal('Tweet');
	n = max(size(tweet));
	t = (0:(n-1))./n;
	qmf = MakeONFilter('Coiflet',3);
	D = log2(n);
//
	subplot(2,2,1);
	plot(t,tweet);
	title('Figure 6(a): Tweet');
//
	subplot(2,2,2);
	plot(t.*(2*%pi),abs(fft(tweet)));
	title('Figure 6(b): |FT(Tweet)|');
//
	wp = WPAnalysis(tweet,D,qmf);
	stree = CalcStatTree(wp,'Entropy');
	[btree,vtree] = BestBasis(stree,D);
//
	subplot(2,2,3);
	ImagePhasePlane('WP',btree,wp,[],256,qmf);
	//a=gca();a.data_bounds=([0 1 .4 .6]);
	title('Figure 6(c): WP Phase Plane');
//
	cp = CPAnalysis(tweet,D,'Sine');
	stree = CalcStatTree(cp,'Entropy');
	[btree,vtree] = BestBasis(stree,D);
//
	subplot(2,2,4);
	ImagePhasePlane('CP',btree,cp,[],256);
	//a=gca();a.data_bounds=([0 1 .4 .6]);
	title('Figure 6(d): CP Phase Plane');
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig07 -- Show CW and l^1 entropy phase planes for Werner Sorrows signal
//
// In selecting a "best-basis" from the packets table, most people use the
// original cost-functional, or "entropy," proposed by Coifman and Wickerhauser,
// which is related to the Shannon entropy in information theory.  We are
// unaware of any specific rationale for this choice of entropy which can be
// tied to performance.  In fact, other entropies can often perform better.
//
// Here we illustrate the phase planes for the BOB based on the Coifman-
// Wickerhauser entropy and also based on the l^1 entropy, which chooses a
// time-varying basis which reveals the time-frequency structure much more
// clearly than the CW entropy.
//
mode(-1);  
scf(1);clf(1);
	n = 512;
	x = MakeSignal('WernerSorrows',n);
	D = log2(n); 
	t  = (1:n)' ./n;
//
	CP = CPAnalysis(x, D-4, 'Sine');
	stree1 = CalcStatTree(CP,'Entropy');
	stree2 = CalcStatTree(CP,'l^p', .5);
	btree1 = BestBasis(stree1,D-4);
	btree2 = BestBasis(stree2,D-4);
//
	subplot(2,1,1); 
	plot(t,x);
	title('Figure 7(a): Werner Sorrows')
//
	subplot(2,2,3);
	ImagePhasePlane('CP',btree1,CP);
	title('(b): Phase Plane, BOB by C-W Entropy')
	//brighten(-.8);
//
	subplot(2,2,4);
	ImagePhasePlane('CP',btree2,CP);
	title('(c): Phase Plane, BOB by l^1 Entropy')
	//brighten(-.8);
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig08 -- Show MP phase plane for Tweet signal
//
// The phase plane generated by the Matching Pursuits algorithm
// on the tweet signal is markedly less clear than that found by
// BOB..  In this case, MP is too adaptive.
//
mode(-1);  
scf(1);clf(1);
	tweet = ReadSignal('Tweet');
	n = length(tweet);
//
	[atomic,resid] = CPPursuit(tweet,6,'Sine',100,.001,0);
//
	ImageAtomicPhase('CP',atomic,n,[]);
	//a=gca();a.data_bounds=([ 0 1 .4 .6]);
	title('Figure 8: MP Phase Plane ; Tweet');
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig09 -- Minimum Entropy Focusing: Evaluate minimum
//
// Here we experiment with using the wavelet transform to focus a blurry
// signal (i.e. one convolved with an autoregressive filter).  By assigning
// a cost-functional to the fine-scale wavelet coefficients, we may evaluate
// this entropy over choices of the deblurring parameter and deblur by choosing
// the parameter corresponding to the minimum entropy.
//
mode(-1);  
scf(1);clf(1);
global ent_min;

	rho = .9;
	qmf = MakeONFilter('Haar');
//
	x = MakeSignal('Blocks',512);
	y = filter(1,[1 ((-2 * rho)) (rho^2)],x);
//
	ngrid = 21;
	tau_grid = linspace(-1,1,ngrid);
	for i=1:ngrid,
		tau = tau_grid(i);
		by = filter([1 ((-2 * tau)) (tau^2)],1,y);
	//
		nrm_by = norm(by);
	//
		wby = FWT_PO(by,3,qmf); wby = wby(9:512);
		ent(i) = norm(wby,1)  ;
	end
//
	plot(tau_grid,ent)
	title('Figure 9: Entropy Profile')
	xlabel('tau, Filter Parameter')
	ylabel('Normalized Entropy')
//
    [ent_min,imin] = min(ent);
    [ent_max,imax] = max(ent);
	tau_min = tau_grid(imin);
	plot([tau_min tau_min], [ent_min ent_max], '-.'); 
	a=gca();a.data_bounds=([0 1 0 10^4])
   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig10 -- Minimum Entropy Focusing: Reconstruct blurry signal
//
// By using the deblurring scheme proposed, we get a perfect reconstruction
// of the blocks!  Admittedly the Haar wavelets are tuned for this example,
// or perhaps vice-versa.
//
mode(-1);  
scf(1);clf(1);
global ent_min tau_min y x
if isempty(ent_min)
        warndlg ('Please run figure 9 first and then run this figure');
    return;
end
    

	by = filter([1 ((-2 * tau_min)) (tau_min^2)],1,y);
// 	clf;
	subplot(3,1,1); plot(x); title('Figure 10(a): Blocks')
	subplot(3,1,2); plot(y); title('Figure 10(b); Blurred Blocks')
	subplot(3,1,3);	plot(by);
	titlestr = sprintf('Figure 10(c); Minimum Entropy Deconvolution, Entropy = %g',ent_min);
    title(titlestr)

   halt("press a key to proceed!");
clc;mode(1);lines(0);
// vdlfig11 -- Use tree-constrained thresholding to denoise Blocks
//
// Denoising by wavelet thresholding acts essentially to keep or kill
// certain wavelet coefficients.  The coefficients which survive often
// exhibit a certain pattern: a coefficient at a finer scale never survives
// thresholding unless its parent also survives.
//
// Based on this, a complexity parameter may be built into the best basis
// search to require this hereditary pattern.  Here we illustrate denoising
// of the blocks based on several such complexities (AIC, BIC and RIC), as
// well as by the VisuThresh technique.
//
mode(-1);  
scf(1);clf(1);
	N = 2048;
	t = (0:(N-1))/N;
	L = 2;
	qmf = MakeONFilter('Haar');
	Blocks = MakeSignal('Blocks',N);
//
	[xblocks,yblocks] = NoiseMaker(Blocks,4);
//
	wtblocks = FWT_PO(yblocks,L,qmf);
	waicblocks = TreeDeNoise(wtblocks,L,'AIC');
	wbicblocks = TreeDeNoise(wtblocks,L,'BIC');
	wricblocks = TreeDeNoise(wtblocks,L,'RIC');
//
	aicblocks = IWT_PO(waicblocks,L,qmf);
	bicblocks = IWT_PO(wbicblocks,L,qmf);
	ricblocks = IWT_PO(wricblocks,L,qmf);
//
	ax = [0 1 -4 12];
        subplot(511);
	plot(t,xblocks);title('Figure 11');
        a=gca();a.data_bounds=ax;
	ylabel('Blocks');
        subplot(512);
	plot(t,yblocks);
        a=gca();a.data_bounds=ax;
	ylabel('Noisy');
        subplot(513);
	plot(t,aicblocks);
        a=gca();a.data_bounds=ax;
	ylabel('AIC');
        subplot(514);
	plot(t,bicblocks);
        a=gca();a.data_bounds=ax;
	ylabel('BIC');
        subplot(515);
	plot(t,ricblocks);
        a=gca();a.data_bounds=ax;
	ylabel('RIC');
	



// 
// Copyright (c) 1995, Jonathan Buckheit.
// Prepared for ``WaveLab and Reproducible Research''
// for XV Recontres Franco-Belges symposium proceedings.
//



//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:42 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 

