mode(-1);clc;stacksize(1e8);
// CAPTION
printf('\n');
disp('Figure 4.3')
disp('Window 1: The top signal includes a linear chirp whose frequency')
disp('increases, a quadratic chirp whose frequency decreases, and two')
disp('modulated Gaussian functions located at t=512 and t=896.')
disp('The bottom image is the spectrogram. The horizontal axis is time')
disp('where as the vertical axis corresponds to frequencies.')
disp('Dark points indicate large amplitude coefficients.') 
disp('Window 2: Complex phase of the window Fourier transform in regions')
disp('where the modulus the spectrogoram is non-zero.')


function phi = ourphase(g,epsilon);
// phi = ourphase(g);
// calculates the complex phase of vector g ;
// coordinates whose moduli are smaller than a defined 
// threshold epsilon are associated to phi = -pi/2;



phase = modulo(imag(log(g)),2*%pi.*ones(g));
phi = phase.*bool2s(abs(g) > epsilon) - %pi * bool2s(abs(g) <= epsilon);

// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr

 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:38 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
endfunction
function g = Analytic(f);
//
// Takes the Analytic part of signal f
//
	f0 = f;
	f    = f(:);	
	N    = max(size(f));
	hatf = mtlb_fft(f);
	hatg = zeros(N,1);
	hatg(1) = hatf(1);
	hatg(2:N/2) = 2*hatf(2:N/2);
	hatg(N/2+1) = hatf(N/2+1);
	g = mtlb_ifft(hatg);
        
//	g = ShapeLike(g,f0);

endfunction

	N = 1024;
	f = MakeSignal('Chirps',N);

// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [delta delta 1-2*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];
	
scf(1);clf(2);
        title('Window 1')
        subplot(212)
	Window = 50;  	
	specgm = WindowFT(f,Window,1,'Gaussian');	
        subplot(211)
	//axes('position',h2);
		plot(f);
		a=gca();a.data_bounds=([1 N min(f) max(f)]);
	//axes('position',h3);


scf(2);clf(2);
        title('Window 2');
	//axes('position',h3);
	phase = ourphase(specgm(1:(N/2+1),:),1);
	pmax = max(max(phase));
	pmin = min(min(phase));
	F=gcf();F.color_map=(1-graycolormap(256));
  mtlb_image(linspace(0,N,N),linspace(0,N/2,N/2+1),255*(phase-pmin)/(pmax-pmin) + 1);
        ylabel('Frequency')
	F=gcf();F.color_map=(1-graycolormap(256));
	//axis('xy')

halt("press a key to proceed!");
close(scf(2))
scf(1);clf(1);
//fprintf('\n');
disp('Figure 4.5')
disp('Graphs of four windows g(t) whose supports are [-.5,.5].');

N = 64;
t = -.5 + (0:N)/N;

subplot(221)
	hamming = .54 + .46*cos(2*%pi*t);
	plot(t,hamming);
 	plot(t,zeros(1,N+1));
	a=gca();a.data_bounds=([-.5 .5 -.1 1.1]);
	title('Hamming')
subplot(222)
	gaussian = exp(-18*t.^2);
	plot(t,gaussian);
 	plot(t,zeros(1,N+1));
	a=gca();a.data_bounds=([-.5 .5 -.1 1.1]);
	title('Gaussian')
subplot(223)
	hanning = (cos(%pi*t)).^2;
	plot(t,hanning);
 	plot(t,zeros(1,N+1));
	a=gca();a.data_bounds=([-.5 .5 -.1 1.1]);
	title('Hanning')
subplot(224)
	blackman = .42+.5*cos(2*%pi*t)+.08*cos(4*%pi*t);
	plot(t,blackman);
 	plot(t,zeros(1,N+1));
	a=gca();a.data_bounds=([-.5 .5 -.1 1.1]);
	title('Blackman');


halt("press a key to proceed!");
scf(1);clf(1);
disp('Figure 4.6')
disp('Left: graph of the Mexican hat wavelet, equal to minus the second')
disp('derivative of a Gaussian.')
disp('Right: graph of the Fourier transform of the Mexican hat wavelet.')

N = 1024;
t = -5 + 10*(1:N)/N;
om = -2*%pi + 4*%pi*(1:N)/N;
pi4 = %pi^.25;
sqrt3 = sqrt(3);

psi = -2./(pi4.*sqrt3).*exp((-t.^2)./2).*(t.^2-1);
hatpsi = sqrt(8).*pi4./sqrt3.*(om.^2).*exp(-(om.^2)./2);

subplot(121)
	plot(t,psi);

subplot(122)
	plot(om,hatpsi);
	a=gca();a.data_bounds=([-5 5 -.2 1.7]);
	

halt("press a key to proceed!");
scf(1);clf(1);

disp('Figure 4.7')
disp('The wavelet transform Wf(u,s) of the top signal f(t) is shown below.')
disp('It is calculated with the Mexican hat wavelet of Figure 4.6.')
disp('The vertical and horizontal axes of the wavelet image are respectively')
disp('the translation parameter u and the log base 2 of the scale s.')
disp('Black, grey and white points correspond respectively ')
disp('to positive, zero and negative wavelet coefficients.')

global WLVERBOSE;
WLVERBOSE='No';
x = ReadSignal('msignal');
nvoice = 8;
wavelet = 'Sombrero';
rwt = RWT(x,nvoice,wavelet,1,4);
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [delta delta 1-2*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];


subplot(212);
	  rwt = fliplr(rwt);
	  ImageRWT(rwt,'Individual','gray','log');
subplot(211);
	  plot(x)
	  a=gca();a.data_bounds=([1 length(x) min(x) max(x)]);
WLVERBOSE='Yes';

halt("press a key to proceed!");
scf(1);clf(1);


disp('Figure 4.8')
disp('Left: scaling function associated to a Mexican hat wavelet.')
disp('Right: Fourier transform of this scaling function.')

N = 1024;
t = -5 + 10*(1:N)/N;
om = -2*%pi + 4*%pi*(1:N)/N;
pi4 = %pi^.25;
sqrt3 = sqrt(3);

psi = -2 ./(pi4.*sqrt3).*exp((-t.^2)./2).*(t.^2-1);
hatpsi = sqrt(8).*pi4./sqrt3.*(om.^2).*exp(-(om.^2)./2);

// finding the correspondence between psi2 = ifft(hatpsi) and psi
	p = 16;
	hatpsi2 = zeros(1,p*N);
	om2 = -2*%pi + 4*%pi*(1:p*N)/(p*N);
	hatpsi2((p-1)*N/2+1:(p+1)*N/2) = hatpsi;
	hatpsi2 = rshift(fftshift(hatpsi2));
	psi2 = mtlb_ifft(hatpsi2)*2*(N/64);
	psi2 = fftshift(psi2);
	a =find(real(psi2)==min(real(psi2)));
	b =find(real(psi)==min(real(psi)));
	ratio = (a(2)-a(1))/(b(2)-b(1));
	
	l = floor(p*N/2+ratio*N/2) - floor(p*N/2-ratio*(N/2-1)) +1;
	t2 = 5 + 10*(1:l)/l;
// now we plot hatphi and we compute phi, using the above ratio
hatphi = 2 .*pi4./sqrt3.*exp(-(om.^2)/2).*sqrt(om.^2+1);
p = 16;
hatphi2 = zeros(1,p*N);
hatphi2((p-1)*N/2+1:(p+1)*N/2) = hatphi;
// rshift in order for the Fourier transform to be real
hatphi2 = rshift(fftshift(hatphi2));
phi2 = mtlb_ifft(hatphi2)*2*(N/64);
phi2 = mtlb_fftshift(phi2);

subplot(211)
	plot(t2-10,real(phi2(floor(p*N/2-ratio*(N/2-1)):floor(p*N/2+ratio*N/2))))
	a=gca();a.data_bounds=([-5 5 -.1 .9]);

subplot(212)
	plot(om,hatphi);
        a=gca();a.data_bounds=([-5 5 -.2 1.6]);


halt("press a key to proceed!");
scf(1);clf(1);
disp('Figure 4.11')
disp('Window 1: Normalized scalogram of the signal shown in Figure 4.3,')
disp('calculated from the modulus of an analytic wavelet transform.')
disp('Dark points indicate large amplitude coefficients. ')
disp('Window 2: Complex phase of the analytic wavelet transform,')
disp('where the scalogram is non-zero.')

Name = 'Chirps';
N = 1024;
	f = MakeSignal(Name,N);
 	awt = AWT(f);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [1.5*delta delta 1-2.5*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta 2*unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];
		sz     = size(awt);
	logawt = awt';
	linawt = log2lin(flipud(logawt),12);
	

        title('Window 1')
	//axes('position',h3);
	ImageAWT(linawt','Overall','gray','lin');
scf(2);clf(2);

        title('Window 2')
	phase = ourphase(linawt',1.e-1);
	pmax = max(max(phase));
	pmin = min(min(phase));
	phase = (phase-pmin)/(pmax-pmin);
	ImageAWT(phase,'Overall','gray','lin');

halt("press a key to proceed!");
close(scf(2))
scf(1);clf(1);
disp('Figure 4.12')
disp('Larger amplitude ridges calculated from the spectrogram shown')
disp('in Figure 4.3. These ridges give the instantaneous frequencies')
disp('of the linear and quadratic chirps, and of the low and high frequency')
disp('transients at t=512 and t=896.')
disp('Enlarge the window to improve the visualization of ridges.')


N = 1024;	
f = MakeSignal('Chirps',N);

// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [delta delta 1-2*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];
	
subplot(211)
Window = 50;
specgm = WindowFT(f,Window,1,'Gaussian');

 subplot(212)
		ridges = Ridge_WindowFT(specgm);
		xtix   = linspace(0,N,N);
		sz = size(ridges);
		ytix = linspace(0,N/2,sz(2)/2);
		grayplot(xtix,ytix,256 .*ridges(N/2:-1:1,:)');
		//axis('xy')
		xlabel('')
		ylabel('Frequency')
		f=gcf();f.color_map=(1-graycolormap(256));

halt("press a key to proceed!");
scf(1);clf(1);
disp('Figure 4.15')
disp('Ridges calculated from the scalogram shown in Figure 4.11.')
disp('Compare with the windowed Fourier ridges in Figure 4.12')
disp('Enlarge the window to improve the visualization of ridges.')

Name = 'Chirps';
N = 1024;
	f = MakeSignal(Name,N);
 	awt = AWT(f);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [1.5*delta delta 1-2.5*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta 2*unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];
		sz     = size(awt);
	logawt = awt';
	linawt = log2lin(flipud(logawt),12);
	

	linridges = Ridge_AWT(flipud(linawt),3);
	sz = size(linridges);
	xtix = linspace(0,N,N);
	ytix   = linspace(450,0,sz(1));
	mtlb_image(xtix,ytix,255 .*linridges(1:sz(1),:) + 1);
          ylabel('Frequency')
	F=gcf();F.color_map=(1-graycolormap(256));

halt("press a key to proceed!");

disp('Figure 4.16')
disp('Window 1: Normalized scalogram of the linear chirp signal shown')
disp('in Figure 4.13.')
disp('Window 2: Ridges calculated from the scalogram.')
disp('Enlarge the window to improve the visualization of ridges.')

Name = 'LinChirps';
N = 1024;
	f = MakeSignal(Name,N);
 	awt = AWT(f);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [1.5*delta delta 1-2.5*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta 2*unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];

	sz     = size(awt);
	logawt = awt';
	linawt = log2lin(flipud(logawt),12);

scf(1);clf(1);
        title('Window 1')
	ImageAWT(linawt','Overall','gray','lin');

scf(2);clf(2);
        title('Window 2')
	linridges = Ridge_AWT(flipud(linawt),3);
	sz = size(linridges);
	xtix = linspace(0,N,N);
	ytix   = linspace(450,0,sz(1));
	mtlb_image(xtix,ytix,255 .*linridges(1:sz(1),:) + 1);
	
          ylabel('Frequency')
	F=gcf();F.color_map=(1-graycolormap(256));

halt("press a key to proceed!");
close(scf(2))
disp('Figure 4.17')
disp('Window 1: Normalized scalogram of a hyperbolic chirp signal shown')
disp('in Figure 4.14.')
disp('Window 2: Ridges calculated from the scalogram.')
disp('Enlarge the window to improve the visualization of ridges.')

Name = 'HypChirps';
N = 1024;
	f = MakeSignal(Name,N);
 	awt = AWT(f);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h3 = [1.5*delta delta 1-2.5*delta 2*unit];
	h2 = [delta 2*(unit+delta) 1-2*delta 2*unit];
	h1 = [delta 4*unit+3*delta 1-2*delta unit];
	h0 = [delta delta 1-2*delta 1-2*delta];

	sz     = size(awt);
	logawt = awt';
	linawt = log2lin(flipud(logawt),12);

scf(1);clf(1);
       title('Window 1')
	ImageAWT(linawt','Overall','gray','lin');

scf(2);clf(2);
       title('Window 2')
	linridges = Ridge_AWT(flipud(linawt),3);
	sz = size(linridges);
	xtix = linspace(0,N,N);
	ytix   = linspace(450,0,sz(1));
	mtlb_image(xtix,ytix,255 .*linridges(1:sz(1),:) + 1);
          ylabel('Frequency')
	F=gcf();F.color_map=(1-graycolormap(256));

halt("press a key to proceed!");
close(scf(2))
disp('Figure 4.18')
disp('Wigner-Ville distribution of the two Gabor atoms shown at the top.')
disp('Large amplitude coefficients are shown in black.')
disp('The oscillating interferences are centered at the middle')
disp('time-frequency location.')

	delta = 1/15;
	unit = (1-3*delta)/3;
	h2 = [delta delta 1-2*delta 2*unit];
	h1 = [delta 2*(unit+delta) 1-2*delta unit];

	N = 512;	
	f = MakeSignal('Gabor',N);

scf(1);clf(1);
        subplot(211)
	plot(real(f))
	a=gca();a.data_bounds=([200 460 min(real(f)) max(real(f))]);
        subplot(212)
	WignerDist(f);
	a=gca();a.data_bounds=([200 460 0 128]);

halt("press a key to proceed!");
disp('Figure 4.19')
disp('The bottom image is the Wigner-Ville distribution of the analytic part')
disp('of the top signal.')

	f = MakeSignal('Chirps',1024);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h2 = [delta delta 1-2*delta 2*unit];
	h1 = [delta 2*(unit+delta) 1-2*delta unit];

	N = 1024;
scf(1);clf(1);
        subplot(211)
	plot(real(f));
	a=gca();a.data_bounds=([1 N min(real(f)) max(real(f))]);
	g = Analytic(f);
	subplot(212)
	wv = WignerDist(g);
// 
// halt("press a key to proceed!");
// disp('Figure 4.20')
// disp('Choi-William distribution of the two Gabor atoms shown at the top. ')
// disp('The interference terms that appear in the Wigner-Ville distribution')
// disp('of Figure 4.18 have nearly disappeared.')
// 
// // axes handles	
// 	delta = 1/15;
// 	unit = (1-3*delta)/3;
// 	h2 = [delta delta 1-2*delta 2*unit];
// 	h1 = [delta 2*(unit+delta) 1-2*delta unit];
// 
// 	N = 512;	
//    	ix = (-N:N)*5/N;
//         j = (1:N)./N;
// 	g = exp(-ix.^2*20);
// 	i1 = (2*N/4+1:2*N/4+N);
// 	i2 = (N/4+1:N/4+N);
// 	f1 = 3*g(i1).*exp(%i*N/16 .*%pi.*j);
// 	f2 = 3*g(i2).*exp(%i*N/4 .*%pi.*j);
//    	f = f1+f2;
// 
// scf(1);clf(1);
//         subplot(211)
// 	plot(real(f))
// 	a=gca();a.data_bounds=([200 460 min(real(f)) max(real(f))]);
// 
// 	subplot(212)
// 	CohenDist(f,1000);
// 	a=gca();a.data_bounds=([200 460 0 128]);
// 
// halt("press a key to proceed!");
//       disp('Figure 4.21')
// disp('Choi-William distribution of the analytic part of the signal shown')
// disp('at the top. The interferences remain visible.')
// 
//         
// 	N = 1024;
// 	f = MakeSignal('Chirps',N);
// 	g = Analytic(f);
// // axes handles	
// 	delta = 1/15;
// 	unit = (1-3*delta)/3;
// 	h2 = [delta delta 1-2*delta 2*unit];
// 	h1 = [delta 2*(unit+delta) 1-2*delta unit];
// 
// scf(1);clf(1);
//         subplot(211)
// 	plot(real(f));
// 	a=gca();a.data_bounds=([1 N min(real(f)) max(real(f))]);
// 	subplot(212)
// 	CohenDist(g,1000*N/512); 


halt("press a key to proceed!");
close(scf(2))
disp('Figure 4.22')
disp('Window 1: Realization of a locally stationary process.')
disp('Window 2: Estimation of the Wigner-Ville spectrum calculated by')
disp('averaging the spectrograms of 100 realizations.')
disp('WARNING : this computation takes a long time.')

// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h2 = [delta delta 1-2*delta 2*unit];
	h1 = [delta 2*(unit+delta) 1-2*delta unit];
specgm = 0;
Window = 25;
n = 512;
imax = 100;
for i = 1:imax,
//  disp(i);
  x = MakeProcess(1,n);
  sp = WindowFT(x,Window,1,'Gaussian');	
  specgm = specgm + abs(sp).^2;
end;
specgm = specgm ./ imax;
// display :
scf(1);clf(1);
       title('Window 1')
	plot(x);
	a=gca();a.data_bounds=([0 n min(x).*1.1 max(x).*1.1]);
scf(2);clf(2);
        title('Window 2')
 	specgmShow = abs(specgm(1:(n/2+1),:));
	spmax = max(max(specgmShow));
	spmin = min(min(specgmShow));
	mtlb_image(linspace(0,n,n),linspace(0,n/2,n/2+1),255*(specgmShow-spmin)/(spmax-spmin)+1);
	F=gcf();F.color_map=(1-graycolormap(256));
	//axis('xy')
	xlabel('')
	ylabel('Frequency')

// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr

    
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:38 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
