mode(-1);clc;

function [def,y] = NormedIFFT(x,l);
// l : longueur du domaine de definition en frequence
n = max(size(x));
y = Wavelab_ifft(rshift(fftshift(x)))*l/2/%pi;
y = fftshift(y);
def = 2*%pi/l * (-n/2 : n/2-1);
endfunction

function s = Sigma8(omega);

omega = omega./2;
cos2 = cos(omega).^2;
sin2 = 1-cos2;
cos4 = cos2.^2;
sin4 = sin2.^2;
sin6 = sin2.^3;
sin8 = sin4.^2;
s = (5+30.*cos2+30.*sin2.*cos2+70.*cos4+2.*sin4.*cos2+2.*sin6./3);
s = s ./105 ./sin8 ./2^8;
endfunction

function DisplayProjV(wc,L,qmf);

wcoef = ShapeAsRow(wc);
[n,J] = dyadlength(wcoef); 
t = (.5:(n-.5));
LockAxes([0 n 0 (J-L+1)]);
scale = .9;
w = wcoef(1:2^L);
for j = L:J-1,
  tj = n.*(.5:(2^(j+1)-.5))./2^(j+1);
  w = UpDyadLo(w,qmf) + UpDyadHi(wcoef(dyad(j)),qmf);
  maxw = max(w);
  PlotSpikes(J-j,tj, scale .* (w./maxw),n);
  xstring(0,-j+J-1/5,sprintf('2^%d',-j+J));
end

endfunction

function Display2dProjV(wc,L,qmf);

[n,J] = quadlength(wc);
// axes handles	
//	delta = (1-2^(L-J-1))./(J-L+2);
	delta = 1/40;
	unit = .45 * 2^(L-J);
	limitx = delta;
	limity = delta;
x = wc; 
	h = [limitx limity unit unit];
	//axes('position',h)
        a1=newaxes();a1.axes_bounds=h;
	grayplot(1:2^L,1:2^L,x(1:2^L,1:2^L));
	f=gcf();f.color_map=(graycolormap(256));
	//axis image
	//axis('off')
	limitx = delta + unit;
	unit = 2*unit;
	nc = 2^(L+1);
	for jscal=L:J-1,
		top = (nc/2+1):nc; bot = 1:(nc/2); all = 1:nc;
		for iy=1:nc,
			x(all,iy) =  UpDyadLo(x(bot,iy)',qmf)'  ...
					   + UpDyadHi(x(top,iy)',qmf)'; 
		end
		for ix=1:nc,
			x(ix,all) = UpDyadLo(x(ix,bot),qmf)  ... 
					  + UpDyadHi(x(ix,top),qmf);
		end
		nc = 2*nc;
		h = [limitx limity unit unit];
		//axes('position',h)
                a1=newaxes();a1.axes_bounds=h;
		grayplot((1:nc/2),(1:nc/2),x(all,all));
		f=gcf();f.color_map=(graycolormap(256));
		//axis image
		//axis('off')
		limitx = limitx + unit;
		unit = 2*unit;
	end
endfunction

function [hath] = Meyerhath(omega);

omega = modulo(omega+%pi,2*%pi)-%pi;
n = max(size(omega));
hath = zeros(1,n);
supp = find((abs(omega) >= %pi/3) & (abs(omega) <= 2*%pi/3));
hath(supp) = sqrt(2) .* cos(%pi/2.*beta01(3*abs(omega(supp))/%pi-1));
supp2 = find(abs(omega) < %pi/3);
hath(supp2) = sqrt(2)* ones(supp2);
endfunction
function b = beta01(x);

b  = x.^4 .* (35 - 84 .*x + 70 .* x.^2 - 20 .* x.^3);
endfunction


disp('Figure 7.1')
disp('The left graph is a cubic box spline. Its Fourier transform is shown')
disp('on the right.')


N = 16384*2;
M = 80;
omega = ((1:N)/N -.5) * 2 * M;
omega(N/2) = omega(N/2+1)/100;
hattheta = (sin(omega ./2) ./ (omega ./2)).^4;
hattheta(N/2) = 1;

scf(1);clf
subplot(222)
plot(omega,hattheta);
a=gca();a.data_bounds=([-15 15 0 1.1]);

[def,theta] = NormedIFFT(hattheta, 2*M);
supp = find(abs(theta) > max(abs(theta))/10000);
subplot(221)
plot(def(supp),abs(theta(supp)));



halt("Press a key");
disp('Figure 7.2')
disp('The graph on the left is a cubic spline scaling function and')
disp('its Fourier transform is shown on the right.')


N = 1024;
M = 20;
omega = ((1:N)/N -.5) * 2 * M;
omega(N/2) = omega(N/2+1)/100;

hatphi = 1 ./((omega).^4 .* sqrt(Sigma8(omega)));
supp = find(hatphi > max(hatphi/900));

scf(1);clf
subplot(222)
plot(omega(supp),hatphi(supp));
a=gca();a.data_bounds=([-15 15 0 1.1]);

j=5;
n = 1024;
J = log2(n);
p = 3;
k = 2^(j);
phi = MakeWavelet(J-j,k,'Battle',p,'Father',n).*2^(j/2);
x = (abs(phi)>1.e-6);
x=double(x);
l = x*x';
m = find(phi == max(phi));
def = (-l/2 : l /2) ./2^j;

subplot(221)
plot(def,phi(round(m-l/2):round(m+l/2)));
a=gca();a.data_bounds=([-12 12 -.3 1.3]);



halt("Press a key");
disp('Figure 7.3')
disp('The original signal is at the bottom.')
disp('The discrete signals above are multiresolution approximations')
disp('a_j[n] at scales 2^j, computed with cubic splines.')


global WLVERBOSE;
WLVERBOSE='No';
// axes handles	
	delta = 1/20;
	unit = (1-6*delta)/6;
	h1 = [delta delta 1-2*delta 1.5*unit];
	h2 = [delta unit+2*delta 1-2*delta 6*unit];
f     = ReadSignal('lady');
scf(1);clf
	subplot(211);
	plot(f)
	a=gca();a.data_bounds=([0 256 0 260]);
L = 3;
qmf = MakeONFilter('Daubechies',6);
wc    = FWT_PO(f,L,qmf);
       
	subplot(212)
	DisplayProjV(wc,L,qmf);
	
WLVERBOSE='Yes';


halt("Press a key");
disp('Figure 7.4')
disp('The solid line gives the transfer function (modulus squared)')
disp('of the low-pass conjugate mirror filter h, which generates a')
disp('cubic spline multiresolution. The dotted line gives the transfer')
disp('function (modulus squared) of the high pass filter g on [-pi,pi].')


// axes handles	
	delta = 1/8;
	unit = (1-2*delta)/2;
	h= [delta delta 1-2*delta unit];
N = 1024;
M = %pi;
omega = ((1:N)/N -.5) * 2 * M;
omega(N/2) = omega(N/2+1)/100;
hsquared(1:1023) = Sigma8(omega(1:1023)) ./(2^7 .* ...
    Sigma8(2.*omega(1:1023)));
hsquared(1024)=0;
gsquared = fftshift(hsquared);
scf(1);clf

plot(omega,hsquared);

plot(omega,gsquared,'b--');
a=gca();a.data_bounds=([-%pi %pi 0 2.1]);



halt("Press a key");
disp('Figure 7.5')
disp('The left graph gives the Battle-Lemarie cubic spline wavelet.')
disp('The modulus of its Fourier transform is shown on the right.')


j=5;
n = 1024;
J = log2(n);
p = 3;
k = 2^(j-1);
psi = MakeWavelet(J-j,k,'Battle',p,'Mother',n).*2^(j/2);
x = (abs(psi)>1.e-6);
x=double(x);
l = x*x';
m = find(psi == max(psi));
def = (2^(j-1)-l/2 :2^(j-1)+ l /2) ./2^j;

scf(1);clf
subplot(221)
plot(def,psi(round(m-l/2):round(m+l/2)));
a=gca();a.data_bounds=([-9 9 -1 1.4]);


clear hatpsi;
N = 4096;
M = 80;
omega = ((1:N)/N -.5) * 2 * M;
omega(N/2) = omega(N/2+1)/100;
hatpsi =sqrt(Sigma8(omega./2+%pi)./(Sigma8(omega./2).*Sigma8(omega)));
hatpsi = hatpsi .* exp(-%i.*omega./2) ./ (omega).^4;
supp1 = find(abs(hatpsi) > max(abs(hatpsi)) ./1000);

subplot(222)
plot(omega(supp1),abs(hatpsi(supp1)));
a=gca();a.data_bounds=([-25 25 0 1.1]);



halt("Press a key");
disp('Figure 7.6')
disp('The modulus squared of the Fourier transform of a cubic') 
disp('spline wavelet is dilated by 2^j, for 0 < j < 6.')


N = 4096;
M = 80;
omega = ((1:N)/N -.5) * 2 * M;
omega(N/2) = omega(N/2+1)/100;
hatpsi =sqrt(Sigma8(omega./2+%pi)./(Sigma8(omega./2).*Sigma8(omega)));
hatpsi = hatpsi .* exp(-%i.*omega./2) ./ (omega).^4;

[def,psi] = NormedIFFT(hatpsi,2*M);
supp = find(abs(hatpsi) > max(abs(hatpsi)) ./1000);
defmax = max(def(find(abs(hatpsi) == max(abs(hatpsi)))));
def = def .*%pi./defmax;

scf(1);clf;
plot(def(supp),abs(hatpsi(supp)).^2);

plot(def(supp)./2,abs(hatpsi(supp)).^2);

plot(def(supp)./4,abs(hatpsi(supp)).^2);

plot(def(supp)./8,abs(hatpsi(supp)).^2);

plot(def(supp)./16,abs(hatpsi(supp)).^2);

a=gca();a.data_bounds=([-%pi %pi 0 1.1]);




halt("Press a key");
disp('Figure 7.7')
disp('The original signal is at the bottom.')
disp('The detail wavelet coefficients d_j[n] at scales 2^j for 0<j<6')
disp('are shown above. They are calculated with a cubic spline wavelet. ')
disp('At the top is the remaining coarse signal approximation a_J[n] for J = 5.')


global WLVERBOSE;
WLVERBOSE='No';
// axes handles	
	delta = 1/20;
	unit = (1-6*delta)/6;
	h1 = [delta delta 1-2*delta 1.5*unit];
	h2 = [delta unit+2*delta 1-2*delta 6*unit];
f     = ReadSignal('lady');
scf(1);clf
        subplot(212)
	plot(f)
	a=gca();a.data_bounds=([0 256 0 260]);
L = 3;
qmf = MakeONFilter('Daubechies',6);
wc    = FWT_PO(f,L,qmf);

scf(1);clf
	scale = 0;
	PlotWaveCoeff(wc,L,scale,f);
WLVERBOSE='Yes';

halt("Press a key");
disp('Figure 7.8')
disp('The left graph shows a Meyer wavelet.')
disp('The modulus of its Fourier transform is on the right.')


n = 8192;
M = 2*%pi;
omega = ((1:n) - n/2)* M / n;
hath = Meyerhath(omega);
hatg = exp(-%i*%pi) .* Meyerhath(omega + %pi);
M = 8*%pi*20;
omega = ((1:n) - n/2)* M / n;
hatpsi = zeros(1,n);
supp1 = find((abs(omega) > 2*%pi/3) & (abs(omega) <= 4*%pi/3));
hatpsi(supp1) = exp(-%i.*(omega(supp1)./2)).*Meyerhath(omega(supp1)./2 + %pi)./sqrt(2);
supp2 = find((abs(omega) > 4*%pi/3) & (abs(omega) <= 8*%pi/3));
hatpsi(supp2) = exp(-%i.*omega(supp2)./2).*Meyerhath(omega(supp2)./4)./sqrt(2);

scf(1);clf
subplot(222)
plot(omega,abs(hatpsi))
a=gca();a.data_bounds=([-4*%pi 4*%pi 0 1.1]);

psi = zeros(1,n);
[def,psi] = NormedIFFT(hatpsi,M);
supp = find(abs(psi) > max(abs(psi))./10000);

subplot(221)
plot(def(supp),real(psi(supp)));
a=gca();a.data_bounds=([-8 8 -1 1.3]);



halt("Press a key");
disp('Figure 7.9')
disp('The left graph is a linear spline Battle-Lemarie scaling')
disp('function. The corresponding linear spline wavelet is on the right.')


N = 1024;
M = 20*16;
omega = ((1:N)/N -.5) * 2 * M;
omega(N/2) = omega(N/2+1)/100;
cos2 = cos(omega./2).^2;
sin2 = 1-cos2;

hatphi = 4.*sqrt(3).*sin2./((omega).^2 .* sqrt(1+2*cos2));
supp = find(hatphi > max(hatphi/900));

j=5;
n = 1024*16;	
J = log2(n);
p = 1;
k = 2^(j-1);
phi = MakeWavelet(J-j,k,'Battle',p,'Mother',n).*2^(j/2);
x = (abs(phi)>1.e-6);
x=double(x);
l = x*x';
m = min(find(phi == mtlb_max(phi)));
def = (-2^(j-1)-l/2 :-2^(j-1)+l /2) ./2^j;

scf(1);clf
subplot(222)
plot(def,-phi(round(m-l/2):round(m+l/2)));
a=gca();a.data_bounds=([-4 4 -1.2 2]);

[def,phi] = NormedIFFT(hatphi,2*M);
supp = find(abs(phi) > max(abs(phi)) ./1000);

subplot(221)
plot(def(supp),real(phi(supp)));
a=gca();a.data_bounds=([-4 4 -0.3 1.5]);




halt("Press a key");
disp('Figure 7.10')
disp('The bottom graphs display the Daubechies wavelets with p=2,3,4')
disp('vanishing moments, from left to right. The corresponding')
disp('scaling functions are above.')


scf(1);clf
n = 1024;
J = log2(n);
j = 7;
p = 4;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Father',1024).*2^(j/2);
supp = find(abs(m) >0.0000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j)+1;
subplot(231)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([0 3 -.5 1.5]);

j = 7;
p = 6;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Father',1024).*2^(j/2);
supp = find(abs(m) >0.0000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j)+1;
subplot(232)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([0 5 -.5 1.5]);

j = 6;
p = 8;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Father',1024).*2^(j/2);
supp = find(abs(m) >0.0000000000000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j)+1;
subplot(233)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([0 7 -.5 1.5]);

j = 7;
p = 4;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Mother',1024).*2^(j/2);
supp = find(abs(m) >0.0000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(234)
plot(i(mins:maxs),-m(mins:maxs))
a=gca();a.data_bounds=([-1 2 -2 2]);

j = 7;
p = 6;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Mother',1024).*2^(j/2);
supp = find(abs(m) >0.0000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(235)
plot(i(mins:maxs),-m(mins:maxs))
a=gca();a.data_bounds=([-2 3 -1.5 2]);

j = 6;
p = 8;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Mother',1024).*2^(j/2);
supp = find(abs(m) >0.0000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(236)
plot(i(mins:maxs),-m(mins:maxs))
a=gca();a.data_bounds=([-3 4 -1 1.5]);




halt("Press a key");
disp('Figure 7.11')
disp('The left and right graphs at the top are respectively the')
disp('Daubechies scaling function and wavelet with p=8 vanishing moments.')
disp('The left and right graphs at the bottom are respectively the')
disp('Symmlet scaling function and wavelet with p=8 vanishing moments.')


n = 2048;
J = log2(n);
j = 5;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Symmlet',8,'Father',n).*2^(j/2);
supp = find(abs(m) >0.0000000000000001);
mins = min(supp)-2^j;
maxs = max(supp)+2^j;
i = (((1:n)-n/2)./2^j);
scf(1);clf
subplot(223)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([0 15 -.5 1.5]); 

j = 7;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Symmlet',8,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.0000000000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(224)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([-7 8 -1 1.5]);

j = 5;
p = 16;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Father',n).*2^(j/2);
supp = find(abs(m) >0.00000000001);
mins = min(supp)-2^j;
maxs = max(supp)+2^j;
i = (((1:n)-n/2)./2^j)+1;

subplot(221)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([0 15 -.6 1.2]);

j =7;
p = 16;
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'Daubechies',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.0000000000001);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);

subplot(222)
plot(i(mins:maxs),-m(mins:maxs))
a=gca();a.data_bounds=([-7 8 -1.2 1.2]);



halt("Press a key");

disp('Figure 7.14')
disp('Window 1: The top left and right graphs are biorthogonal')
disp('spline scaling functions calculated with conjugate mirror')
disp('filters having respectively p=2 zeros and p`=4 zeros at pi.')
disp('The left and right graphs below are the resulting biorthogonal')
disp('wavelets with respectively 4 and 2 vanishing moments.')
printf('\n');
disp('Window 2: The top left and right graphs are biorthogonal')
disp('spline scaling functions calculated with conjugate mirror')
disp('filters having respectively p=3 zeros and p`=7 zeros at pi.')
disp('The left and right graphs below are the resulting biorthogonal')
disp('wavelets with respectively 7 and 3 vanishing moments.')


n = 2048;
J = log2(n);

	j = 7;
// p(1) and p(2) are the parameters of the wavelet
// if p(3)=0, m is the original biorthogonal wavelet
// if p(3)=1, m is the dual biorthogonal wavelet

scf(1);clf
        title('Window 1')
subplot(221)
	j = 6;
	p = [2 4 0];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Father',n).*2^(j/2);
	supp = find(abs(m) >0.0000000001);
	mins = min(supp);
	maxs = max(supp);
	i = ((2^(j)+(1:n)-n/2)./2^j);
	plot(i(mins:maxs),m(mins:maxs))
	a=gca();a.data_bounds=([-1,1,min(m).*1.2,max(m).*1.2]);

subplot(222)
	j = 6;
	p = [2 4 1];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Father',n).*2^(j/2);
	supp = find(abs(m) >0.00000000001);
	mins = min(supp);
	maxs = max(supp);
	i = ((2^(j)+(1:n)-n/2)./2^j);
	plot(i(mins:maxs),m(mins:maxs))
	a=gca();a.data_bounds=([-4,4,min(m).*1.2,max(m).*1.2]);

subplot(223)
	j = 7;
	p = [2 4 0];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.000000000001);
mins = min(supp)-2^j;
maxs = max(supp)+2^j;
i = (((1:n)-n/2)./2^j);
plot(i(mins:maxs),m(mins:maxs))
	a=gca();a.data_bounds=([-(p(1)+p(2))./2+1,(p(1)+p(2))/2,1.2*min(m),1.2*max(m)]);

subplot(224)
	j = 7;
	p = [2 4 1];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.000000000001);
mins = min(supp)-2^j;
maxs = max(supp)+2^j;
i = (((1:n)-n/2)./2^j);
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([-(p(1)+p(2))./2+1,(p(1)+p(2))/2,1.2*min(m),1.2*max(m)]);


scf(2);clf
        title('Window 2')


 
subplot(221)
	j = 6;
	p = [3 7 0];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Father',n).*2^(j/2);
	supp = find(abs(m) >0.0000001);
	mins = min(supp);
	maxs = max(supp);
	i = ((2^(j)+(1:n)-n/2)./2^j);
	plot(i(mins:maxs),m(mins:maxs))
	a=gca();a.data_bounds=([-1,2,min(m).*1.2,max(m).*1.2]);

subplot(222)
	j = 6;
	p = [3 7 1];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Father',n).*2^(j/2);
	supp = find(abs(m) >0.000000000001);
	mins = min(supp);
	maxs = max(supp);
	i = ((2^(j)+(1:n)-n/2)./2^j);
	plot(i(mins:maxs),m(mins:maxs))
	a=gca();a.data_bounds=([-7,8,min(m).*1.2,max(m).*1.2]);

subplot(223)
	j = 7;
	p = [3 7 0];	
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.000000000001);
mins = min(supp)-2^j;
maxs = max(supp)+2^j;
i = (((1:n)-n/2)./2^j);
plot(i(mins:maxs),-m(mins:maxs))
		a=gca();a.data_bounds=([-(p(1)+p(2))./2+1,(p(1)+p(2))/2,1.2*min(m),1.2*max(m)]);

subplot(224)
	j = 7;
	p = [3 7 1];
	k = 2^(J-j-1);
	m = MakeWavelet(J-j,k,'CDF',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.000000000001);
mins = min(supp)-2^j;
maxs = max(supp)+2^j;
i = (((1:n)-n/2)./2^j);
plot(i(mins:maxs),-m(mins:maxs))
		a=gca();a.data_bounds=([-(p(1)+p(2))./2+1,(p(1)+p(2))/2,1.2*min(m),1.2*max(m)]);




halt("Press a key");
disp('Figure 7.15')
disp('The top left and right graphs are biorthogonal')
disp('scaling functions calculated with conjugate mirror')
disp('filters having 4 zeros at pi. The left and right graphs below')
disp('are the resulting biorthogonal wavelets with 4 vanishing moments.')


n = 4096;
J = log2(n);
j = 7;
p = [4,4,0];
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'CDF',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.000000000001);
mins = min(supp)-2^(j-1);
maxs = max(supp)+2^(j-1);
i = (((1:n)-n/2)./2^j);
scf(1);clf
subplot(223)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([-3 4 -1.5 2]);

j = 7;
p = [4,4,1];
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'CDF',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >0.00000000001);
mins = min(supp)-2^(j-1);
maxs = max(supp)+2^(j-1);
i = (((1:n)-n/2)./2^j);
subplot(224)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([-3 4 -1 2]);

j = 6;
p = [4 4 0];
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'CDF',p,'Father',n).*2^(j/2);
supp = find(abs(m) >0.000000000001);
mins = min(supp)-2^(j-1);
maxs = max(supp)+2^(j-1);
i = ((2^(j)+(1:n)-n/2)./2^j);
subplot(221)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([-3 3 -.5 1.5]);

j = 6;
p = [4 4 1];
k = 2^(J-j-1);
m = MakeWavelet(J-j,k,'CDF',p,'Father',n).*2^(j/2);
supp = find(abs(m) >0.00000000001);
mins = min(supp)-2^(j);
maxs = max(supp)+2^(j);
i = ((2^(j)+(1:n)-n/2)./2^j);
subplot(222)
plot(i(mins:maxs),m(mins:maxs))
a=gca();a.data_bounds=([-4 4 -.5 1.5]);




halt("Press a key");
disp('Figure 7.20')
disp('Window 1: The top graphs are the two left border scaling functions.') 
disp('The bottom graphs are the two left border wavelets with p=2 vanishing moments.') 
disp('Window 2: The top graphs are the two right border scaling functions.') 
disp('The bottom graphs are the two right border wavelets with p=2 vanishing moments.') 


n = 2048;
J = log2(n);
j = 6;
p = 2;
k = 0;
m = MakeWavelet(J-j,k,'CDJV',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2-1)./2^j);
scf(1);clf
title('Window 1')
subplot(223)
plot(i(mins:maxs)-i(mins),m(mins:maxs))
a=gca();a.data_bounds=([0 2 min(m) max(m)]);

j = 6;
p = 2;
k = 1;
m = MakeWavelet(J-j,k,'CDJV',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(224)
plot(i(mins:maxs)-i(mins),m(mins:maxs))
a=gca();a.data_bounds=([0 3 min(m)-.2 max(m)+.2]);

j = 6;
p = 2;
k = 1;
m = MakeWavelet(J-j,k,'CDJV',p,'Father',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(221)
plot(i(mins:maxs)-i(mins),m(mins:maxs))

j = 6;
p = 2;
k = 2;
m = MakeWavelet(J-j,k,'CDJV',p,'Father',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(222)
plot(i(mins:maxs)-i(mins),m(mins:maxs))
a=gca();a.data_bounds=([0 3 min(m)-.2 max(m)+.2]);

scf(2);clf
       title('Window 2')
j = 6;
p = 2;
k = 2^(J-j)-1;
m = MakeWavelet(J-j,k,'CDJV',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(224)
plot(i(mins:maxs)-i(maxs),m(mins:maxs))

j = 6;
p = 2;
k = 2^(J-j)-2;
m = MakeWavelet(J-j,k,'CDJV',p,'Mother',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(223)
plot(i(mins:maxs)-i(maxs),m(mins:maxs))
a=gca();a.data_bounds=([-3 0 min(m)-.2 max(m)+.2]);



j = 6;
p = 2;
k = 2^(J-j);
m = MakeWavelet(J-j,k,'CDJV',p,'Father',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(222)
plot(i(mins:maxs)-i(maxs),m(mins:maxs))

j = 6;
p = 2;
k = 2^(J-j)-1;
m = MakeWavelet(J-j,k,'CDJV',p,'Father',n).*2^(j/2);
supp = find(abs(m) >1.e-10);
mins = min(supp);
maxs = max(supp);
i = (((1:n)-n/2)./2^j);
subplot(221)
plot(i(mins:maxs)-i(maxs),m(mins:maxs))
a=gca();a.data_bounds=([-3 0 min(m)-.2 max(m)+.2]);



halt("Press a key");
disp('Figure 7.21')
disp('The left graph is a cubic spline interpolation function.')
disp('The right graph is the Deslaurier-Dubuc interpolation function') 
disp('of degree 3.')


// figure (a)
N = 32768;
M = 2*%pi*100;
omega = ((1:N)/N -.5) * 2 * M;
cos2 = cos(omega./2).^2;
sin4 = (1-cos2).^2;
omega(N/2) = .01;
hattheta = 48*sin4 ./ (omega.^4 .* (1 + 2.*cos2));
hattheta(N/2) = 1;
[def,theta] = NormedIFFT(hattheta,2*M);
supp = find(abs(theta) > max(abs(theta))./10000);

scf(1);clf;
subplot(221)
plot(def(supp),real(theta(supp)));
a=gca();a.data_bounds=([-6 6 -.2 1.1]);

plot(def(supp),zeros(supp))
plot2d([0 -0],[-.2 1.1]);

// figure (b)
n = 1024;
J = log2(n);
j = 7;
p = 4;
k = 2^(J-j-1);
phi = MakeWavelet(J-j,k,'Daubechies',p,'Father',1024).*2^(j/2);
i = (((1:2*n)-n)./2^j);
phitilde = reverse(phi);
theta = conv(phi,phitilde);
supp = find(abs(theta) > .000000000001);
mins = min(supp);
maxs = max(supp);

subplot(222)
plot(i(mins:maxs),theta(mins:maxs)./max(theta));
a=gca();a.data_bounds=([-3 3 -.2 1.1]);

plot2d([-3 3],[0 0]);
plot2d([0 -0],[-.2 1.1]);


halt("Press a key");
disp('Figure 7.22')
disp('Dual cubic spline associated to the spline interpolation')
disp('function shown in Figure 7.21.')


N = 4096;
M = 2*%pi*40;
omega = ((1:N)/N -.5) * 2 * M;
cos2 = cos(omega./2).^2;
sin4 = (1-cos2).^2;
omega(N/2) = .01;
hattheta = 48*sin4 ./ (omega.^4 .* (1 + 2.*cos2));
hattheta(N/2) = 1;
sumtheta = zeros(1,N);
for k = -100:100,
	omega = ((1:N)/N -.5) * 2 * M + 2.*k.*%pi;
	cos2 = cos(omega./2).^2;
	sin4 = (1-cos2).^2;
        omega(find(omega==0)) = .001*ones((find(omega==0)));
	t = 48*sin4 ./ (omega.^4 .* (1 + 2.*cos2));
	t(find(omega==0)) = ones((find(omega==0)));
	sumtheta = sumtheta + abs(t).^2;
end // k loop
sumtheta(find(sumtheta==0)) = .5 * ones((find(sumtheta==0)));
hattildetheta = hattheta ./ sumtheta;
hattildetheta = (hattildetheta < 10).*hattildetheta;
[def,tildetheta] = NormedIFFT(hattildetheta,2*M);
supp = find(abs(tildetheta) > max(abs(tildetheta))./1.e4);
scf(1);clf;
plot(def(supp),real(tildetheta(supp)));
a=gca();a.data_bounds=([-12 12 -.4 1.4]);



halt("Press a key");
disp('Figure 7.23')
disp('Multiresolution approximations a_j[n,m] of an image')
disp('at scales 2^j, for 5>j>0.')


global WLVERBOSE;
WLVERBOSE='No';
Image = ReadImage('Lenna');
[n,J] = quadlength(Image);
qmf = MakeONFilter('Daubechies',8);
L = 5;
wc = FWT2_PO(Image,L,qmf);
scf(1);clf
Display2dProjV(wc,L,qmf);
WLVERBOSE='Yes';


halt("Press a key");

disp('Figure 7.24')
disp('The top left surface is the Fourier transform modulus')
disp('of a separable scaling function, calculated with a Daubechies 4')
disp('filter. The top right, bottom left and bottom right surfaces')
disp('are the Fourier transform modulus of the three separable wavelets.')


// filter support
DAUBECHIES = 4;

x=(-512:511)/128*%pi;

p=zeros(1,1024);
p(1)=1;
qmf=MakeONFilter('Daubechies',DAUBECHIES);

phi=fftshift(abs(Wavelab_fft(IWT_PO(p,8,qmf))))/2;

p=zeros(1,1024);
p(257)=1;

psi=fftshift(abs(Wavelab_fft(IWT_PO(p,8,qmf))))/2;

// plot(x,psi);

// sub-sampling

pas = 16;
phi=phi(1:pas:1024);
psi=psi(1:pas:1024);
x=x(1:pas:1024);

ns=1024/pas;

y=ones(ns,1);xy=y*x;

scf(1);clf
subplot(221);mesh(xy,xy',phi'*phi);a=gca();a.data_bounds=([-13 13 -13 13 0 1]);
subplot(223);mesh(xy,xy',phi'*psi);a=gca();a.data_bounds=([-13 13 -13 13 0 1]);
subplot(222);mesh(xy,xy',psi'*phi);a=gca();a.data_bounds=([-13 13 -13 13 0 1]);
subplot(224);mesh(xy,xy',psi'*psi);a=gca();a.data_bounds=([-13 13 -13 13 0 1]);

//F=gcf();F.color_map=(.5*graycolormap(256)+1);





halt("Press a key");
disp('Figure 7.26')
disp('Window 1: Separable wavelet transform on J=4 octaves of the')
disp('image of a white square in a black background.')
disp('Black, grey and white pixels correspond respectively')
disp('to positive zero and negative wavelet coefficients.')
disp('Window 2: Separable wavelet transform of Lena decomposed on J=3 octaves.') 



global WLVERBOSE;
WLVERBOSE='No';

N = 256;
Image = MakeImage('Square',N);

[n,J] = quadlength(Image);
qmf = MakeONFilter('Daubechies',8);
L = 4;
wc = FWT2_PO(Image,L,qmf);
wc2 = wc;
avg = wc(1:2^L,1:2^L);
wc2(1:2^L,1:2^L) = 1-(avg ./max(max(abs(avg))));
wc2(1:2^L,2^L) = zeros(2^L,1);
wc2(2^L,1:2^L) = zeros(1,2^L);
//wc2max = max(-min(min(wc2)),max(max(wc2)));
//wc2 = (wc2+wc2max) ./ (2*wc2max);
for j = L:J-1,
	low = 1:2^j;
	high = 2^j+1:2^(j+1);
	max1 = max(max(max(abs(wc2(low,high)))));
	wc2(low,high) = (wc2(low,high)+max1) ./ (2*max1);
	max2 = max(max(max(abs(wc2(high,low)))));
	wc2(high,low) = (wc2(high,low)+max2) ./(2*max2);
	max3 = max(max(max(abs(wc2(high,high)))));
	wc2(high,high) = (wc2(high,high)+max3) ./(2*max3);
	wc2(2^(j),2^j+1:2^(j+1)) = zeros(1,2^(j));
	wc2(2^(j+1),1:2^j) = zeros(1,2^(j));
	wc2(2^j+1:2^(j+1),2^(j)) = zeros(2^(j),1);
	wc2(1:2^j,2^(j+1)) = zeros(2^(j),1);
	wc2(2^(j+1),2^j+1:2^(j+1)) = zeros(1,2^(j));
	wc2(2^j+1:2^(j+1),2^(j+1)) = zeros(2^(j),1);
//	wc2(2^(j),2^j+1:2^(j))= zeros(1,2^(j));
end
scf(1);clf
title('Window 1')
grayplot(1:size(wc2,1),1:size(wc2,2),wc2)
f=gcf();f.color_map=(1-graycolormap(256));


Image = ReadImage('Lenna');
[n,J] = quadlength(Image);
qmf = MakeONFilter('Daubechies',8);
L = 5;
wc = FWT2_PO(Image,L,qmf);
wc2 = wc;
avg = wc(1:2^L,1:2^L);
wc2(1:2^L,1:2^L) = 1-(avg ./max(max(abs(avg))));
wc2(1:2^L,2^L) = zeros(2^L,1);
wc2(2^L,1:2^L) = zeros(1,2^L);
for j = L:J-1,
	low = 1:2^j;
	high = 2^j+1:2^(j+1);
	max1 = max(max(max(abs(wc2(low,high)))));
	wc2(low,high) = (wc2(low,high)+max1) ./ (2*max1);
	max2 = max(max(max(abs(wc2(high,low)))));
	wc2(high,low) = (wc2(high,low)+max2) ./(2*max2);
	max3 = max(max(max(abs(wc2(high,high)))));
	wc2(high,high) = (wc2(high,high)+max3) ./(2*max3);
	wc2(2^(j),2^j+1:2^(j+1)) = zeros(1,2^(j));
	wc2(2^(j+1),1:2^j) = zeros(1,2^(j));
	wc2(2^j+1:2^(j+1),2^(j)) = zeros(2^(j),1);
	wc2(1:2^j,2^(j+1)) = zeros(2^(j),1);
	wc2(2^(j+1),2^j+1:2^(j+1)) = zeros(1,2^(j));
	wc2(2^j+1:2^(j+1),2^(j+1)) = zeros(2^(j),1);
end
scf(2);clf
title('Window 2')
grayplot(1:size(wc2,1),1:size(wc2,2),wc2);
f=gcf();f.color_map=(1-graycolormap(256));
WLVERBOSE='Yes';

// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
    
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 