mode(-1);clc;

function PlotMBandPlane(pkt)
// function PlotMBandPlane(pkt)
//
// Time-frequency representation of wavelet decomposition
//
// See also : wavelet2packet
//
[n,L] = size(pkt);
L = L-1;
v = 1;
basis = zeros(1,2*n-1);
for d = 0:L-1,
	     for k = 0:min(2^v-1,2^d-1),
		basis(node(d,k)) = 1;
	     end
	  end
ImagePhasePlane('WP',basis,pkt);
endfunction

function PlotSquareCPPlane(pkt)
// function PlotSquareCPPlane(pkt)
//
// Time-frequency representation of wavelet decomposition
//
// See also : wavelet2packet
//
[n,L] = size(pkt);
L = L-1;
v = 1;
basis = zeros(1,2*n-1);
for d = 0:L-3,
	     for k = 0:2^d-1,
		basis(node(d,k)) = 1;
	     end
end
ImagePhasePlane('CP',basis,pkt,'');
endfunction

function PlotSquareWPPlane(pkt)
// function PlotSquareWPPlane(pkt)
//
// Time-frequency representation of wavelet decomposition
//
// See also : wavelet2packet
//
[n,L] = size(pkt);
L = L-1;
v = 1;
basis = zeros(1,2*n-1);
for d = 0:L-5,
	     for k = 0:2^d-1,
		basis(node(d,k)) = 1;
	     end
	  end
ImagePhasePlane('WP',basis,pkt); 

endfunction

disp('Figure 8.2')
disp('Wavelet packets at the depth j=3 of the wavelet packet tree,') 
disp('calculated with a Daubechies 5 filter. They are ordered from')
disp('left to right and up to down, from low to high frequencies.')


n = 2048;
J = log2(n);
j = 7;
p = 10;
k = 2^(J-j-1);
scf(1);clf
for b = 0:7,
	w = MakeWaveletPacket(j,b,k,'Daubechies',p,n)*2^((j-3)/2);
	x = (abs(w)>1.e-6);
    x=double(x);
    l = x*x';
	m = find(abs(w) >0.0000001);
	minm = min(m);
	maxm = max(m);
	i = (((1:n)-n/2)./2^(j-3)); 
	subplot(3,4,b+1)
	plot(i(minm:maxm),w(minm:maxm))
	a=gca();a.data_bounds=([i(minm) i(maxm) min(w)-.05 max(w)+.05]);
end;


halt("Press a key to proceed!");
disp('Figure 8.4')
disp('Walsh wavelet packets at the depth j=3 of the Walsh tree,') 
disp('calculated with a Haar filter. They are ordered from')
disp('left to right and up to down, from low to high frequencies.')


n = 2048;
J = log2(n);
j = 7;
p = 10;
k = 2^(J-j-1);
scf(1);clf
for b = 0:7,
	w = MakeWaveletPacket(j,b,k,'Haar',p,n)*2^((j-3)/2);
	x = (abs(w)>1.e-6);
    x=double(x);
    l = x*x';
	i = (((1:n)-n/2)./2^(j-3)); 
	subplot(3,4,b+1)
	plot(i,w)
	a=gca();a.data_bounds=([-1 9 min(w)-.05 max(w)+.05]);
end;


halt("Press a key to proceed!");
disp('Figure 8.6')
disp('Wavelet packet decomposition of the multi-chirp signal')
disp('whose spectrogram is shown in Figure 4.3.')
disp('The darker the gray level of each Heisenberg box the larger ')
disp('the amplitude of the corresponding wavepacket coefficient. ')
printf('\n');


global WLVERBOSE;
WLVERBOSE='No';
f = MakeSignal('Chirps',1024);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h2 = [delta delta 1-2*delta 2*unit];
	h1 = [delta 2*(unit+delta) 1-2*delta unit];

[n,J] = dyadlength(f);
D = J-3;
qmf = MakeONFilter('Daubechies',6);
//scf(2);clf
[wp, btree] = AutoWPTour(f,D,qmf,'',0,0,0,0,0);
scf(1);clf
//a1=newaxes();a1.axes_bounds=h1;
subplot(211)
	plot(real(f));
	a=gca();a.data_bounds=([1 n min(real(f))*1.1 max(real(f))*1.1]);

//a2=newaxes();a1.axes_bounds=h2;
subplot(212)
ImagePhasePlane('WP',btree,wp,'',256,qmf)
// (no sqrt in the display)
WLVERBOSE='Yes';

halt("Press a key to proceed!");
disp('Figure 8.8')
disp('Window 1: Heisenberg boxes of a 2-band wavelet decomposition')
disp('of the multi-chirp signal shown in Figure 8.6.')
disp('Window 2: Decomposition of the same signal in a pseudo-local')
disp('cosine wavelet packet basis.');
printf('\n');


global WLVERBOSE;
WLVERBOSE='No';
f = MakeSignal('Chirps',1024);
// axes handles	
	delta = 1/15;
	unit = (1-3*delta)/3;
	h2 = [delta delta 1-2*delta 2*unit];
	h1 = [delta 2*(unit+delta) 1-2*delta unit];
[n,J] = dyadlength(f);
D = J-1;
qmf = MakeONFilter('Daubechies',20);
[wp, btree] = AutoWPTour(f,D,qmf,'',0,0,0,0,0);
scf(1);clf;
 title('Window 1')
//a2=newaxes();a1.axes_bounds=h2;
PlotMBandPlane(wp);

scf(2);clf
title('Window 2')
//a2=newaxes();a1.axes_bounds=h2;
PlotSquareWPPlane(wp);
WLVERBOSE='Yes';

halt("Press a key to proceed!");
disp('Figure 8.18')
disp('Window 1: The signal at the top is a recording of the sound')
disp('""grea"" in the word ""greasy"". This signal is decomposed ')
disp('in a local cosine basis with windows of varying sizes. ')
disp('The larger the amplitude of a local cosine coefficient')
disp(' the darker the gray level of the Heisenberg box. ')
disp('Window 2: Decomposition in a local cosine basis with smaller')
disp('windows of constant size.')
printf('\n');


global WLVERBOSE;
WLVERBOSE='No';
// axes handles	
	N = 512;
	delta = 1/15;
	unit = (1-3*delta)/3;
	h2 = [delta delta 1-2*delta 2*unit];
	h1 = [delta 2*(unit+delta) 1-2*delta unit];
x = ReadSignal('Greasy');


xx=zeros(1,4096);
xx(1:3400)=x(1:3400)';
x=xx;
[n,J] = dyadlength(x);

scf(1);clf
title('Window 1')
	//a1=newaxes();a1.axes_bounds=h1;
      subplot(211);
	plot(x);
	a=gca();a.data_bounds=([1 n min(x)*1.1 max(x)*1.1]);
//a2=newaxes();a1.axes_bounds=h2;
subplot(212);
[cp, btree] = AutoCPTour(x,J-4,'',0,0,0,0,0);
PlotSquareCPPlane(cp);
F=gcf();F.color_map=(1-graycolormap(256).^.25);

cp = CPAnalysis(x,7,'Sine');
scf(2);clf
title('Window 2')
//a2=newaxes();a1.axes_bounds=h2;
PlotSquareCPPlane(cp);
F=gcf();F.color_map=(1-graycolormap(256).^.25);
WLVERBOSE='Yes';


halt("Press a key to proceed!");
disp('Figure 8.21')
disp('The grid shows the support of the square windows')
disp('of a ""best"" local cosine basis selected in the local cosine quad-tree.')
printf('\n');


global WLVERBOSE;
WLVERBOSE='No';
img = ReadImage('Lenna');
MaxDepth = 5;
[bb,stats,coef] = CP2Tour(img,MaxDepth,'');

title('');
WLVERBOSE='Yes';
