clf;mode(-1);


function [g,sig] = Filt_GWN(n,Beta,alpha)
// Makes GWN of s.d Beta low-pass filtered
//  Calling Sequence
//    sig = Fig1(n,Beta,k)
//  Parameters
//  Inputs:
//    Beta:	standard deviation
//    n	:desired signal length
//    alpha	:low-pass filter parameter.
//  Outputs:
//    sig  :  1-d signal
//

sig=GWN(n,Beta);
g=zeros(1,n);
lim=alpha*n;
mult=%pi/(2*alpha*n);
g(1:fix(lim))=(cos(mult*(1:fix(lim)))).^2;
g((n/2+1):n)=g((n/2):-1:1);
g = rnshift(g,n/2);
g=g/norm(g);
sig=iconv(g,sig);

endfunction

function MyPlotBasisTree(basis,D,stree,titlestr)
// MyPlotBasisTree -- Display basis tree with decorated branch lengths
//  Usage
//    MyPlotBasisTree(btree,D,stree[,titlestr])
//  Inputs
//    btree      basis tree (e.g. output of BestBasis)
//    D          max depth of tree
//    stree      stat tree of pkt table
//    titlestr   optional signal title
//
//  Side Effects
//    A plot of tree with height of each branch proportional
//    to improvement in cost function obtained by splitting.
//
 [nargout,nargin]=argn();
	if nargin < 4,
	   titlestr = ' ';
	end
	stack = zeros(6,2^D+1);
	k = 1;
	stack(:,k) = [ 0 0 .5 0 .5 1. ]';
	maxheight=2;
	LockAxes([0 1 (-1.1)*maxheight 0]);


	while(k > 0),
		d = stack(1,k); b = stack(2,k); x = stack(3,k);
		y = stack(4,k); w = stack(5,k); h = stack(6,k);
		k=k-1;
		if(basis(node(d,b)) == 0) ,  // terminal node
			   plot([(x-w/10) (x+w/10)],[y y ])
		else
			plot([(x-w/2) (x+w/2)],[y y ])
			h = maxheight/D;
			plot([(x-w/2) (x-w/2)],[y (y-h) ])
			k = k+1;
			stack(:,k) = [(d+1) (2*b) (x-w/2) (y-h) (w/2) h]'; 
			plot([(x+w/2) (x+w/2)],[y (y-h) ])
			k = k+1;
			stack(:,k) = [(d+1) (2*b+1) (x+w/2) (y-h) (w/2) h]'; 
		end
	end
	//axis('off')
	UnlockAxes;
endfunction

disp('Figure 10.1')
disp('Window 1: Realization of a Gaussian process.')
disp('Window 2: Noisy signal obtained by adding a Gaussian white noise, with SNR = -0.48db')
disp('Window 3: Wiener linear estimation, with SNR = 15.2db')


n=1024;
sigma=20;
Beta=20;
[g,sig] = Filt_GWN(n,sigma,0.05);

Noisy = GWNoisy(sig,Beta);
scf(2);
plot(Noisy);

wien = Wien_Filt_GWN(Noisy,g,sigma,Beta);

snr1=SNR(sig,Noisy);
snr2=SNR(sig,wien);

scf(1);clf
title('Window 1')
plot(sig);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 1100 -100 100]);
scf(2);clf
title('Window 2')
plot(Noisy);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 1100 -100 100]);
scf(3);clf
title('Window 3')
plot(wien);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 1100 -100 100]);

disp('Figure 10.2')
disp('Window 1: Piecewise polynomial of degree 3.')
disp('Window 2: Noisy signal obtained by adding a Gaussian')
disp('white noise, with SNR = 21.9db')
disp('Window 3: Ideal Wiener estimation, with SNR = 25.9db')


n=4096;
sigma=4;
Pol = MakeSignal('Piece-Polynomial',4096);
Noisy = GWNoisy(Pol,sigma);

wien = Wiener(Noisy,Pol,sigma);

snr1=SNR(Pol,Noisy);
snr2=SNR(Pol,wien);

scf(1);clf();
title('Window 1')
plot(Pol);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

scf(2);clf();
title('Window 2')
plot(Noisy);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

scf(3);clf();
title('Window 3')
plot(wien);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);


halt("press a key to proceed!");
disp('Figure 10.3')
disp('Window 1: Upper left: Piecewise polynomial signal of degree 3.')
disp('Upper right: Noisy signal obtained by adding a Gaussian white noise (SNR = 21.9db).')
disp('Lower left: Estimation reconstructed from the hard thresholded wavelet')
disp('coefficients shown in Window 5 (SNR = 30.8db).')
disp('Lower right: Estimation with a wavelet soft thresholding (SNR = 23.8db).')
disp('Window 2: Estimation with a translation invariant hard thresholding (SNR = 33.7db).')
disp('Window 3: Orthogonal wavelet transform of the upper left signal in Window 1,')
disp('with a Symmlet 4 wavelet.')
disp('Window 4: Orthogonal wavelet transform of the noisy signal in the')
disp('upper right of Window 1.')
disp('Window 5: Orthogonal wavelet coefficients of the noisy signal above a')
disp('threshold.')




n=4096;

sigma=4;
Pol = MakeSignal('Piece-Polynomial',n);
L=5;
qmf=MakeONFilter('Symmlet',4);

scf(1);clf
title('Window 1')
subplot(221)
plot(Pol);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);


Noisy = GWNoisy(Pol,sigma);

[n,d]=dyadlength(Pol);


[out_ht,wcoef,wcoefrest_HT]=HT(Noisy,L,qmf,sigma);
[out_st,wcoef,wcoefrest_ST]=ST(Noisy,L,qmf,sigma);

subplot(222);
plot(Noisy);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

subplot(223);
plot(out_ht);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

subplot(224);
plot(out_st);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

out_TI=zeros(1,n);
nspin =16;
for i=0:(nspin-1),
	[Noistrans]  = cyclespin(Noisy,  i);
	[dout]=HT(Noistrans,L,qmf,sigma);
	[dout]  = cyclespin(dout,  -i);
	out_TI = out_TI+dout;
end

out_TI  = out_TI/nspin;

scf(2);clf
subplot(221);
title('Window 2')
plot(out_TI);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

scf(3);clf
title('Window 3')
wc    = FWT_PO(Pol,L,qmf);
PlotWaveCoeff(wc,L,0);

scf(4);clf
title('Window 4')
wc_noisy    = FWT_PO(Noisy,L,qmf);
PlotWaveCoeff(wc_noisy,L,0);

scf(5);clf
title('Window 5')
PlotWaveCoeff(wcoefrest_HT,L,0);

snr1=SNR(Pol,Noisy);
snr_ht=SNR(Pol,out_ht);
snrst=SNR(Pol,out_st);
snrTI=SNR(Pol,out_TI);

halt("press a key to proceed!");
disp('Figure 10.4')
disp('Window 1: Upper left: Original signal.')
disp('Upper right: Noisy signal obtained by adding a Gaussian white noise (SNR = 12.9db).')
disp('Lower left: Estimation with a hard thresholding in a Symmlet 4 wavelet')
disp('basis (SNR = 23.5db).')
disp('Lower right: Estimation with a wavelet soft thresholding (SNR = 21.7db).')
disp('Window 2: Left: Estimation with a translation invariant')
disp('hard thresholding  (SNR = 25.6db).') 
disp('Right: Estimation with a translation invariant soft thresholding (SNR = 22.7db).')


sigma=4;
n=4096;
Mydata = MakeSignal('Piece-Regular',n);

scf(1);clf();
title('Window 1')
subplot(221);
plot(Mydata);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -20 50]);

Noisy = GWNoisy(Mydata,sigma);

subplot(222);
plot(Noisy);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -20 50]);
[n,d]=dyadlength(Mydata);

L=5;
qmf=MakeONFilter('Symmlet',4);


[out_ht,wcoef,wcoefrest_HT]=HT(Noisy,L,qmf,sigma);

subplot(223);
plot(out_ht);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -20 50]);

[out_st,wcoef,wcoefrest_ST]=ST(Noisy,L,qmf,sigma);

out_TI_ht=zeros(1,n);
nspin =16;
for i=0:(nspin-1),
	[Noistrans]  = cyclespin(Noisy,  i);
	[dout]=HT(Noistrans,L,qmf,sigma);
	[dout]  = cyclespin(dout,  -i);
	out_TI_ht = out_TI_ht+dout;
end

out_TI_ht  = out_TI_ht/nspin;

out_TI_st=zeros(1,n);
nspin =16;
for i=0:(nspin-1),
	[Noistrans]  = cyclespin(Noisy,  i);
	[dout]=ST(Noistrans,L,qmf,sigma);
	[dout]  = cyclespin(dout,  -i);
	out_TI_st = out_TI_st+dout;
end

out_TI_st  = out_TI_st/nspin;

snr1=SNR(Mydata,Noisy);
snr_ht=SNR(Mydata,out_ht);
snrst=SNR(Mydata,out_st);
snrTI_ht=SNR(Mydata,out_TI_ht);
snrTI_st=SNR(Mydata,out_TI_st);

subplot(224);
plot(out_st);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -20 50]);
scf(2);clf();
title('Window 2')
subplot(221);
plot(out_TI_ht);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -20 50]);
subplot(222);
plot(out_TI_st);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -20 50]);

halt("press a key to proceed!");
disp('Figure 10.6')
disp('This noise removal figure with edge thresholding can be reproduced')
disp('with the Wave2 software, which is available on the Internet at')
disp('http://www.cmap.polytechnique.fr/users/www.mallat  and')
disp('http://cs.nyu.edu/cs/faculty/mallat.')
    

disp('Figure 10.7')
disp('Window 1: Blurred signal plus white noise (SNR = 26.8db)')
disp('Window 2: Deconvolution with a Wiener filter (SNR = 28.4db).')


n=4096;

sig=MakeSignal('Piece-Polynomial',n);

sigma=0.245;
Noise=GWN(n,sigma);
[g,I]=convgauss(Noise,-1);

convsig=iconv(g,sig);
Noisy=convsig+Noise;

[H,out_wien] = Wienerdec(g,Noisy,sig,sigma);

scf(1);clf
title('Window 1')
plot(Noisy);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 n -100 200]);

scf(2);clf
title('Window 2')
plot(out_wien);
//handle_axis = gca; // recupere le handle de l'axe actif
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 n -100 200]);

disp('Figure 10.9')
disp('Window 1: Wavepacket tree of a best basis for a low-pass filter deconvolution')
disp('Window 2: Deconvolution by thresholding the best wavepacket coefficients. (SNR=32.1db)')


n=4096;
sig=MakeSignal('Piece-Polynomial',n);

[n,D]=dyadlength(sig);
L=D-5;
qmf=MakeONFilter('Symmlet',4);

sigma=0.245;
Noise=GWN(n,sigma);
[g,I]=convgauss(Noise,-1);

convsig=iconv(g,sig);
Noisy=convsig+Noise;
[h,Exploded]=convgauss(Noisy,-1);

scf(1);clf
 title('Window 1')

wp1 = WPAnalysis(sig,L,qmf);
wp2 = WPAnalysis(I,L,qmf);

sqsin=zeros(1,255);

for d=0:L,
  for b=0:(2^d-1),
    p = wp2(packet(d,b,n),d+1);
    sqsin(node(d,b)) = (1/length(p))*sum(p.*p);
  end
end
T_max=sqrt(2*log(n))*sqrt(sqsin);
T=2.*sqrt(sqsin);

btree=zeros(1,256);
btree(1:4)=ones(1,4);
btree(7:8)=ones(1,2);
btree(15:16)=ones(1,2);
btree(28)=1;
btree(31:32)=ones(1,2);
btree(61)=1;
btree(63:64)=ones(1,2);
btree(99)=1;
btree(106)=1;
btree(108)=1;
btree(115)=1;
btree(118)=1;
btree(120)=1;
btree(123)=1;
btree(125)=1;
btree(127)=1;
MyPlotBasisTree(btree,L);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);

out_best=zeros(1,n);
nspin =1;
for i=0:(nspin-1),
	[Explodtrans]  = cyclespin(Exploded,  i);
	dout=DiscrDenoise(btree,wp1,Explodtrans,T,T_max,qmf,L);
	[dout]  = cyclespin(dout,  -i);
	out_best = out_best+dout;
end

out_best=out_best/nspin;
scf(2);clf
 title('Window 2')
plot(out_best);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 n -100 200]);

snr1=SNR(sig,Noisy);
snr_best=SNR(sig,out_best);

halt("press a key to proceed!");
disp('Figure 10.11')
disp('Window 1: Speech recording of the sound ""grea"".')
disp('Window 2: Noisy signal obtained by adding a Gaussian white noise (SNR=8.7db).')
disp('Window 3: Heisenberg boxes of the local coefficients above the threshold in the best basis.')
disp('Window 4: Estimated signal recovered from the thresholded cosine coefficients (SNR=10.9db)')
printf('\n');

        
	x = ReadSignal('Greasy');
	x = x(1:3400);
	x =[ x; zeros(696,1)];
	[n,J] = dyadlength(x);
	D=J-1;

	sigma=150;
	Noisy = GWNoisy(x',sigma);
	snr1=SNR(Noisy,x');

	cp = CPAnalysis(Noisy,D,'Sine');
        T=sigma*3.8;
	stree = DisStatTree(cp,'HTE_Compr',T,0,sigma);
	[btree,vtree] = BestBasis(stree,D);

	for d=0:D,
	  for b=0:(2^d-1),
	    cpout(packet(d,b,n),d+1)=HardThresh(cp(packet(d,b,n),d+1),T);
	  end
	end

	out     = CPSynthesis(btree,cpout,'Sine');
	snr_out=SNR(out,x');

	scf(1);clf();
	title('Window 1')
	plot(x);
	//handle_axis = gca;
	//set(handle_axis,'FontSize', 21);
	scf(2);clf();
	title('Window 2')
	plot(Noisy);
	//handle_axis = gca;
	//set(handle_axis,'FontSize', 21);
	scf(3);clf();
	title('Window 3')
	ImagePhasePlane('CP',btree,cpout)
	colormap(1-gray(256).^.25)
	//handle_axis = gca;
	//set(handle_axis,'FontSize', 21);
	scf(4);clf();
	title('Window 4')
	plot(out);
	//handle_axis = gca;
	//set(handle_axis,'FontSize', 21);

halt("press a key to proceed!");
disp('Figure 10.12')
disp('Window 1: Piece-wise polynomial signal to which is added a')
disp('musical signal (SNR=19.3db).')
disp('Window 2: Estimation by extracting coherent structures (SNR=23.0db).')


y = ReadSignal('Caruso');
y=y(45001:49096);
y=y'/200;
x=MakeSignal('Piece-Polynomial',4096);
Noisy=x+y;

out=CohWave(Noisy,5);

scf(1);clf();
title('Window 1')
plot(Noisy);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);
scf(2);clf();
title('Window 2')
plot(out);
//handle_axis = gca;
//set(handle_axis,'FontSize', 21);
a=gca();a.data_bounds=([0 4100 -100 200]);

halt("press a key to proceed!");
disp('Figure 10.13')
disp('The matching pursuit algorithm in a Gabor dictionary is not yet')
disp('implemented in Wavelab. This figure can be reproduced with the')
disp('LastWave software, which is available on the Internet at')
disp('http://www.cmap.polytechnique.fr/users/www.bacry')

halt("press a key to proceed!");
disp('Figure 10.14')
disp('The matching pursuit algorithm in a Gabor dictionary is not yet')
disp('implemented in Wavelab. This figure can be reproduced with the')
disp('LastWave software, which is available on the Internet at')
disp('http://www.cmap.polytechnique.fr/users/www.bacry')    
    
 halt("press a key to proceed!");
disp('Figure 10.15')
disp('Left: Log power spectrum of a stationary process.')
disp('Middle: Log periodogram computed from P= 1 realization.')
disp('Right: Regularized estimator calculated by smoothing the periodogram.')

  
//  	x   : filtered white noise 
  N = 2048;
  NR = 1;
  x = zeros(2*N,NR);
 px = zeros(2*N,NR);
  y = zeros(2*N,NR);
 py = zeros(2*N,NR);

// -- filter f
  ix = (1:N/2)*2/N;
  f1 = 1.5*sin(2.5*%pi*ix-.5*%pi)+3+8*ix;
 ix = (1:N/8)*8/N;
  f2 = f1(N/2) + 12*((ix-.5).^2-.25-.25*ix);
 ix = (1:N/4)*4/N;
  f3 = f2(N/8) + 10*((ix-.5).^2-.25-.125*ix);
   ix = (1:N/8)*4/N;
  f4 = f3(N/4) + 10*((ix-.5).^2-.25);
  logf = zeros(N,1);
  logf(1:N/2) 	  = f1';
  logf(N/2+1:5*N/8)  = f2';
  logf(5*N/8+1:7*N/8)= f3';
  logf(7*N/8+1:N)    = f4';
  logf(N+1:2*N,1) = reverse(logf(1:N,1));
  f = exp(logf);
 
  tukey = ones(2*N,1);
  alphaN = 40;
  tukey(1:alphaN) = ((1-cos(%pi.*(1:alphaN+0.5)/alphaN))./2)';
  tukey(2*N - alphaN +1 : 2*N) = reverse(tukey(1:alphaN));

   noiselevel = 200;
  for i = 1:NR,
    z = exp(noiselevel)*rand(2*N,1,'normal');
    hatz = Wavelab_fft(z);
 //   scf(4)
 //   plot(real(hatz))
    hatx = hatz .* f;
    x(:,i) =  Wavelab_ifft(hatx);
    y(:,i) =x(:,i) .* tukey; 
    px(:,i) = .5*(log(abs(fft(x(:,i))).^2./2./N)-2*noiselevel);
    py(:,i) = .5*(log(abs(fft(y(:,i))).^2./2./N)-2*noiselevel);
  end
   
  average = ones(NR,1) ./NR;
  pxmean = px * average;
  pymean = py * average;

  scf(1);clf
  subplot(331)
  plot(logf)
  a=gca();a.data_bounds=([0 2*N 0 12]);

  subplot(332)
  plot(pymean)
  a=gca();a.data_bounds=([0 2*N 0 12]);

  t = (1:2*N)/2/N;
 sigma = 0.005;
 g = exp(-.5.*(abs(t-.5)./sigma).^2)./sigma./sqrt(2*%pi);
 g = fftshift(g);

 subplot(333)
 pymean2 = iconv(g',pymean')'/2/N; 
  
  
 plot(pymean2)
  a=gca();a.data_bounds=([0 2*N 0 12]);
  
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr


  
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 

