clc;mode(1);lines(0);
// toon0111 -- Wavelet Families
//
//   Wavelet analysis begins by choosing a specific family of wavelets
//   to work with.
//
//   The family is specified by a father and a mother wavelet, and
//   these generate a basis by translation and dilation.
// 
//   Here we illustrate four specific Mother wavelets
//
//       Haar          -- the first wavelet; a square-wave wavelet
//
//       Daubechies D4 -- the first continuous, compactly supported
//                        orthonormal wavelet family
//
//       Coiflet C3    -- orthonormal wavelets system where both father and
//                        mother have special vanishing moments properties
//
//       Symmlet S8    -- nearly-symmetric orthogonal wavelet of
//                        compact support with 8 vanishing moments.
// 
	mode(-1);scf(1);clf();
//
	wave = MakeWavelet(4,8,'Haar',[],'Mother',1024);
	subplot(221);
	t = (1:1024)./1024;
	plot(t(300:800),wave(300:800)); title(' Haar Wavelet ');
//
	wave = MakeWavelet(4,8,'Daubechies',4,'Mother',1024);
	subplot(222);
	plot(t(300:800),wave(300:800)); title(' D4 Wavelet ');
//
	wave = MakeWavelet(4,8,'Coiflet',3,'Mother',1024);
	subplot(223);
	plot(t(300:800),wave(300:800)); title(' C3 Coiflet ');
//
	wave = MakeWavelet(4,8,'Symmlet',8,'Mother',1024);
	subplot(224);
	plot(t(300:800),wave(300:800)); title(' S8 Symmlet ');
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// toon0112 -- Interpolating Wavelets
//
//   Wavelet analysis begins by choosing a specific family of wavelets
//   to work with.
//
//   The family is specified by a father and a mother wavelet, and
//   these generate a basis by translation and dilation.
// 
//   Here we illustrate four specific Mother wavelets
//
//       Interp	3	
//       Interp	5	
//       Interp	7   
//       Interp	9   
//
mode(-1);scf(1);clf();
	wave = MakeWavelet(4,8,'Interpolating',3,'Mother',1024);
	subplot(221);
	t = (1:1024)./1024;
	plot(t(300:800),wave(300:800)); title('Interpolating Wavelet (Deg 3)');
//
	wave = MakeWavelet(4,8,'Interpolating',5,'Mother',1024);
	subplot(222);
	plot(t(300:800),wave(300:800)); title('Interpolating Wavelet (Deg 5)');
//
	wave = MakeWavelet(4,8,'Interpolating',7,'Mother',1024);
	subplot(223);
	plot(t(300:800),wave(300:800)); title('Interpolating Wavelet (Deg 7)');
//
	wave = MakeWavelet(4,8,'Interpolating',9,'Mother',1024);
	subplot(224);
	plot(t(300:800),wave(300:800)); title('Interpolating Wavelet (Deg 9)');
    
halt("press a key to proceed!");
clc;mode(1);lines(0);
// toon0113 -- Average Interpolating Wavelets
//
//   Wavelet analysis begins by choosing a specific family of wavelets
//   to work with.
//
//   The family is specified by a father and a mother wavelet, and
//   these generate a basis by translation and dilation.
// 
//   Here we illustrate four specific Mother wavelets
//
//       AverageInterp	3	
//       AverageInterp	5	
//       AverageInterp	7   
//       AverageInterp	9   
//
mode(-1);scf(1);clf();
	wave = MakeWavelet(4,8,'AverageInterpolating',2,'Mother',1024);
	subplot(221);
	t = (1:1024)./1024;
	plot(t(300:800),wave(300:800)); title('Average Interpolating Wavelet (Deg 2)');
//
	wave = MakeWavelet(4,8,'AverageInterpolating',4,'Mother',1024);
	subplot(222);
	plot(t(300:800),wave(300:800)); title('Average Interpolating Wavelet (Deg 4)');
//
	wave = MakeWavelet(4,8,'AverageInterpolating',6,'Mother',1024);
	subplot(223);
	plot(t(300:800),wave(300:800)); title('Average Interpolating Wavelet (Deg 6)');
//
	wave = MakeWavelet(4,8,'AverageInterpolating',8,'Mother',1024);
	subplot(224);
	plot(t(300:800),wave(300:800)); title('Average Interpolating Wavelet (Deg 8)');
 
    
    halt("press a key to proceed!");
clc;mode(1);lines(0);
// toon0114 -- Meyer Wavelets
//
//   Wavelet analysis begins by choosing a specific family of wavelets
//   to work with.
//
//   The family is specified by a father and a mother wavelet, and
//   these generate a basis by translation and dilation.
// 
//   Here we illustrate four specific Mother wavelets
//
//       Meyer	3	
//       Meyer	5	
//       Meyer	7   
//       Meyer	9   	
//
mode(-1);scf(1);clf();
	wave = MakeWavelet(4,8,'Meyer',2,'Mother',1024);
	subplot(211);
	t = (1:1024)./1024;
	plot(t(300:800),wave(300:800)); title('Meyer Wavelet (Deg 2)');
//
	wave = MakeWavelet(4,8,'Meyer',3,'Mother',1024);
	subplot(212);
	plot(t(300:800),wave(300:800)); title('Meyer Wavelet (Deg 3)');
//
//	wave = MakeWavelet(4,8,'Meyer',6,'Mother',1024);
//	subplot(223);
//	plot(t(300:800),wave(300:800)); title('Meyer Wavelet (Deg 6)');
//
//	wave = MakeWavelet(4,8,'Meyer',8,'Mother',1024);
//	subplot(224);
//	plot(t(300:800),wave(300:800)); title('Meyer Wavelet (Deg 8)');
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
 
 
