clc;mode(1);lines(0); 
// toon0331 -- Behavior of Wavelet Transform of Singularities
//
//     Here we analyze 4 functions:
//
//             Ramp = t - (t >= .37);
//           Crease = exp(-4*abs(t - .37));
//             Cusp = sqrt(abs(t - .37));
//             Sing = 1 ./abs(t - (k+.5)/2048);
//
//     These have singularities of degree 0, 1, 1/2, and -1,
//        respectively.
//
mode(-1);  
scf(1);clf(1);
	n = 4096;
	t  = (1:n) ./n;
	Ramp = t - (t >= .37);
	Crease = exp(-4*abs(t - .37));
	Cusp = sqrt(abs(t - .37));
	k = floor(n * .37);
	Sing = 1 ./abs(t - (k+.5)/n); Sing = Sing ./ norm(Sing) .* 20;
//
	subplot(221); plot(t, Sing);  title(' Sing')
	subplot(222); plot(t, Ramp);   title(' Ramp')
	subplot(223); plot(t, Cusp);  title(' Cusp')
	subplot(224); plot(t, Crease); title(' Crease')
     halt("press a key to proceed!");
clc;mode(1);lines(0);  
// toon0332 -- Behavior of Wavelet Transform of Singularities
//
//	Show the wavelet transforms of the signals in toon0331.
// 
//             Away from the singularities, 
//               the wavelet coefficients decay rapidly
//
mode(-1);  

scf(1);clf(1);
	qmf = MakeONFilter('Coiflet',3);
	wcRamp   = FWT_PO(Ramp,3,qmf);
	wcCrease = FWT_PO(Crease,3,qmf);
	wcCusp   = FWT_PO(Cusp,3,qmf);
	wcSing   = FWT_PO(Sing,3,qmf);
//
	subplot(221); PlotWaveCoeff(wcSing,3,0.);  title('WT Sing')
	subplot(222); PlotWaveCoeff(wcRamp,3,2.);   title('WT Ramp')
	subplot(223); PlotWaveCoeff(wcCusp,3,2.);  title('WT Cusp')
	subplot(224); PlotWaveCoeff(wcCrease,3,2.); title('WT Crease')
     halt("press a key to proceed!");
clc;mode(1);lines(0); 
// toon0333 -- Behavior of Wavelet Transform of Singularities
// 
//	Show the MRA's of the signals in toon0331.
//
mode(-1);  
scf(1);clf(1);
	qmf = MakeONFilter('Coiflet',3);
	wcRamp   = FWT_PO(Ramp,3,qmf);
	wcCrease = FWT_PO(Crease,3,qmf);
	wcCusp   = FWT_PO(Cusp,3,qmf);
	wcSing   = FWT_PO(Sing,3,qmf);
//
	subplot(221); PlotMultiRes(wcRamp  ,3,2.,qmf);  title('MR Ramp')
	subplot(222); PlotMultiRes(wcCrease,3,2.,qmf);  title('MR Crease')
	subplot(223); PlotMultiRes(wcCusp  ,3,2.,qmf);  title('MR Cusp')
	subplot(224); PlotMultiRes(wcSing  ,3,0.,qmf);  title('MR Sing')
    
    
     halt("press a key to proceed!");
clc;mode(1);lines(0); 
// toon0334 -- Behavior of Wavelet Transform of Singularities
//
//		Show the level norms for the signals in toon0331.
//
mode(-1);  
scf(1);clf(1);
	qmf = MakeONFilter('Symmlet',8);
	wcRamp   = FWT_PO(Ramp,3,qmf);
	wcCrease = FWT_PO(Crease,3,qmf);
	wcCusp   = FWT_PO(Cusp,3,qmf);
	wcSing   = FWT_PO(Sing,3,qmf);
//
	ax = [0 12 10^(-2) 10^4];
//
	subplot(221); PlotLevelNorms(wcSing  ,3);  title('Decay Sing')  ; a=gca();a.data_bounds=(ax);
	subplot(222); PlotLevelNorms(wcRamp  ,3);  title('Decay Ramp')  ; a=gca();a.data_bounds=(ax);
	subplot(223); PlotLevelNorms(wcCusp  ,3);  title('Decay Cusp')  ; a=gca();a.data_bounds=(ax);
	subplot(224); PlotLevelNorms(wcCrease,3);  title('Decay Crease'); a=gca();a.data_bounds=(ax);
    
         halt("press a key to proceed!");
clc;mode(1);lines(0); 
// toon0335 -- Behavior of Wavelet Transform of Singularities
//
//		Show the ordered wavelet coefficients for the signals in toon0331.
//
mode(-1);  
scf(1);clf(1);
	qmf = MakeONFilter('Symmlet',8);
	wcRamp   = FWT_PO(Ramp,3,qmf);
	wcCrease = FWT_PO(Crease,3,qmf);
	wcCusp   = FWT_PO(Cusp,3,qmf);
	wcSing   = FWT_PO(Sing,3,qmf);
//
	ax = [0 100 10^(-2) 10];
//
	subplot(221); PlotOrderedCoef(wcSing  );  title('OrderedCoef Sing')  ; a=gca();a.data_bounds=(ax);
	subplot(222); PlotOrderedCoef(wcRamp  );  title('OrderedCoef Ramp')  ; a=gca();a.data_bounds=(ax);
	subplot(223); PlotOrderedCoef(wcCusp  );  title('OrderedCoef Cusp')  ; a=gca();a.data_bounds=(ax);
	subplot(224); PlotOrderedCoef(wcCrease);  title('OrderedCoef Crease'); a=gca();a.data_bounds=(ax);
    
    
 
 


 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
