clc;mode(1);lines(0); 
// toon0341 -- Compare Symmlet & Haar Coefficient Decay
//
//  Illustrates how the S8 wavelet can represent the doppler signal
//  more compactly than the haar wavelet.
//
//  toon0341 plots the levelwise norms of the transforms.
//  toon0342 plots the ordered coefficients.
//
mode(-1);  
scf(1);clf(1);
	Doppler = MakeSignal('Doppler',4096);
	HaarQMF = MakeONFilter('Haar');
	S8QMF   = MakeONFilter('Symmlet',8);
	wcHaar  = FWT_PO(Doppler,1,HaarQMF);
	wcS8    = FWT_PO(Doppler,4,S8QMF);
//
	subplot(221); PlotWaveCoeff(wcHaar,1,1);
	title('Haar Transform of Doppler Object')
//
	subplot(222); PlotWaveCoeff(wcS8  ,4,1);
	title('S8 Transform of Doppler Object')
//
	subplot(223); 
	for j=4:11,
		nrmHaar(j) = norm(wcHaar(dyad(j)));
	end
	plot2d(4:11,nrmHaar(4:11),logflag="nl")
	title('Levelwise norm of Haar Coefficients')
	a=gca();a.data_bounds=([0 11 10^(-1) 10^1 ])
//
	subplot(224); 
	for j=4:11,
		nrmS8(j)  = norm(wcS8(dyad(j)));
	end
	plot2d(4:11,nrmS8(4:11),logflag="nl")
	a=gca();a.data_bounds=([0 11 10^(-1) 10^1 ])
	title('Levelwise norm of S8 Wavelet Coefficients')
    
      halt("press a key to proceed!");
clc;mode(1);lines(0);    

 // toon0342 -- Compare Wavelet & Haar Coefficient Decay
//
//  Illustrates how the S8 wavelet can represent the doppler signal
//  more compactly than the haar wavelet.
//
//  toon0341 plots the levelwise norms of the transforms.
//  toon0342 plots the ordered coefficients.
//
mode(-1);  
scf(1);clf(1);
	Doppler = MakeSignal('Doppler',4096);
	HaarQMF = MakeONFilter('Haar');
	S8QMF   = MakeONFilter('Symmlet',8);
	wcHaar  = FWT_PO(Doppler,1,HaarQMF);
	wcS8    = FWT_PO(Doppler,4,S8QMF);
//
	subplot(221); PlotWaveCoeff(wcHaar,1,1);
	title('Haar Transform of Doppler Object')
//
	subplot(222); PlotWaveCoeff(wcS8  ,4,1);
	title('S8 Transform of Doppler Object')
//
	subplot(223); 
	ordcoef = reverse(mtlb_sort(abs(wcHaar)));
	plot2d(ordcoef,logflag="nl")
	title('Ordered Haar Coefficients')
	a=gca();a.data_bounds=([0 300 10^(-2) 10^1 ])
//
	subplot(224); 
	ordcoef = reverse(mtlb_sort(abs(wcS8)));
	plot2d(ordcoef,logflag="nl")
	a=gca();a.data_bounds=([0 300 10^(-2) 10^1 ])
	title('Ordered S8 Wavelet Coefficients')
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 

 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
