clc;mode(1);lines(0);  
// toon0441 -- Best-m Wavelet & DCT Partial Reconstructions
//
//  Compare the accuracy of best-m reconstructions of the Doppler
//  signal for the Wavelet and DCT transforms.
//
mode(-1);  
scf(1);clf(1);
	n       = 2048;
	t       = (1:n)./n;
	S8QMF   = MakeONFilter('Symmlet',8);
//
	Doppler = MakeSignal('Doppler',n);
	dctDopp = dct_iv(Doppler);
	wcDopp  = FWT_PO(Doppler,4,S8QMF);
//
	BigDCT = KeepBiggest(dctDopp,64);
	Bigwc  = KeepBiggest(wcDopp,64);
//
	subplot(221); PartialDCT = dct_iv(BigDCT);
	plot(t,PartialDCT)
	title('Doppler: DCT Recon. 64 largest')
	a=gca();a.data_bounds=([ 0 1 -.5 .5]);
//
	subplot(222); PartialS8 = IWT_PO(Bigwc,4,S8QMF);
	plot(t,PartialS8)
	title('Doppler: S8 Wavelet Recon. 64 largest')
	a=gca();a.data_bounds=([ 0 1 -.5 .5])
//
	Bumps = MakeSignal('Bumps',n);
	dct = dct_iv(Bumps);
	wc  = FWT_PO(Bumps,4,S8QMF);
//
	BigDCT = KeepBiggest(dct,64);
	Bigwc  = KeepBiggest(wc,64);
//
	subplot(223); PartialDCT = dct_iv(BigDCT);
	plot(t,PartialDCT)
	title('Bumps: DCT Recon. 64 largest')
	a=gca();a.data_bounds=([ 0 1 0 6]);
//
	subplot(224); PartialS8 = IWT_PO(Bigwc,4,S8QMF);
	plot(t,PartialS8)
	title('Bumps: S8 Wavelet Recon. 64 largest')
	a=gca();a.data_bounds=([ 0 1 0 6]);
    
         halt("press a key to proceed!");
clc;mode(1);lines(0);     
 // toon0442 -- First-m Wavelet & DCT Partial Reconstructions
//
//  Compare the accuracy of first-m reconstructions of the Doppler
//  signal for the Wavelet and DCT transforms.
//
mode(-1);  
scf(1);clf(1);
	n       = 2048;
	t       = (1:n)./n;
	S8QMF   = MakeONFilter('Symmlet',8);
//
	Doppler = MakeSignal('Doppler',n);
	dct     = dct_iv(Doppler);
	wc      = FWT_PO(Doppler,4,S8QMF);
//
	BigDCT = KeepFirst(dct,64);
	Bigwc  = KeepFirst(wc,64);
//
	subplot(221); PartialDCT = dct_iv(BigDCT);
	plot(t,PartialDCT)
	title('Doppler: DCT Recon. First 64')
	a=gca();a.data_bounds=([ 0 1 -.5 .5]);
//
	subplot(222); PartialS8 = IWT_PO(Bigwc,4,S8QMF);
	plot(t,PartialS8)
	title('Doppler: S8 Wavelet Recon. First 64')
	a=gca();a.data_bounds=([ 0 1 -.5 .5]);
//
	Bumps = MakeSignal('Bumps',n);
	dct = dct_iv(Bumps);
	wc  = FWT_PO(Bumps,4,S8QMF);
//
	BigDCT = KeepFirst(dct,64);
	Bigwc  = KeepFirst(wc,64);
//
	subplot(223); PartialDCT = dct_iv(BigDCT);
	plot(t,PartialDCT)
	title('Bumps: DCT Recon. FIrst 64')
	a=gca();a.data_bounds=([ 0 1 0 6]);
//
	subplot(224); PartialS8 = IWT_PO(Bigwc,4,S8QMF);
	plot(t,PartialS8)
	title('Bumps: S8 Wavelet Recon. First 64')
	a=gca();a.data_bounds=([ 0 1 0 6]);
          halt("press a key to proceed!");
clc;mode(1);lines(0);  
 // toon0443 -- Best-m Compression Numbers in DCT & DWT of Four Objects
//
//  Compare the accuracy of best-m reconstructions of four
//  signals with the Wavelet and DCT transforms.
//
mode(-1);  
scf(1);clf(1);
	n = 2048;
	Bumps     = MakeSignal('Bumps',n);
	Doppler   = MakeSignal('Doppler',n);
	HeaviSine = MakeSignal('HeaviSine',n);
	Blocks    = MakeSignal('Blocks',n);
	t         = (1:n)./n;
//
	S8QMF       = MakeONFilter('Symmlet',8);
	wcBumps     = FWT_PO(Bumps,4,S8QMF);
	wcBlocks    = FWT_PO(Blocks,4,S8QMF);
	wcDoppler   = FWT_PO(Doppler,4,S8QMF);
	wcHeaviSine = FWT_PO(HeaviSine,4,S8QMF);
//
	dctBumps     = dct_iv(Bumps);
	dctBlocks    = dct_iv(Blocks);
	dctDoppler   = dct_iv(Doppler);
	dctHeaviSine = dct_iv(HeaviSine);
//
	subplot(221); 
        plot2d(reverse(cumsum(mtlb_sort(wcBlocks.^2))),logflag="nl");//'y--'); 
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
        
	plot2d(reverse(cumsum(mtlb_sort(dctBlocks.^2))),logflag="nl");//'r-');
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('Blocks; Best-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
        legend(['DCT -';'DWT --'],3);
	//xstring(350,10^4,'DCT -'); set(h,'Color','Red');
	//xstring(350,10^(3.3),'DWT --'); set(h,'Color','Yellow');
//
	subplot(222); 
        plot2d(reverse(cumsum(mtlb_sort(wcBumps.^2))),logflag="nl");
                e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(mtlb_sort(dctBumps.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('Bumps; Best-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^(3.3),'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
//
	subplot(223); 
        plot2d(reverse(cumsum(mtlb_sort(wcHeaviSine.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(mtlb_sort(dctHeaviSine.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('HeaviSine; Best-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^(3.3),'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
//
	subplot(224); 
        plot2d(reverse(cumsum(mtlb_sort(wcDoppler.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(mtlb_sort(dctDoppler.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('Doppler; Best-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^(3.3),'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
         halt("press a key to proceed!");
clc;mode(1);lines(0);    
// toon0444 -- First-m Compression Numbers in DCT & DWT of Four Objects
//
//  Compare the accuracy of first-m reconstructions of four
//  signals with the Wavelet and DCT transforms.
//
mode(-1);  
scf(1);clf(1);
	n = 2048;
	Bumps     = MakeSignal('Bumps',n);
	Doppler   = MakeSignal('Doppler',n);
	HeaviSine = MakeSignal('HeaviSine',n);
	Blocks    = MakeSignal('Blocks',n);
	t         = (1:n)./n;
//
	S8QMF       = MakeONFilter('Symmlet',8);
	wcBumps     = FWT_PO(Bumps,4,S8QMF);
	wcBlocks    = FWT_PO(Blocks,4,S8QMF);
	wcDoppler   = FWT_PO(Doppler,4,S8QMF);
	wcHeaviSine = FWT_PO(HeaviSine,4,S8QMF);
//
	dctBumps     = dct_iv(Bumps);
	dctBlocks    = dct_iv(Blocks);
	dctDoppler   = dct_iv(Doppler);
	dctHeaviSine = dct_iv(HeaviSine);
//
	subplot(221); 
        plot2d(reverse(cumsum(reverse(wcBlocks.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(reverse(dctBlocks.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('Blocks; First-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^3,'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
//
	subplot(222); 
        plot2d(reverse(cumsum(reverse(wcBumps.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(reverse(dctBumps.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('Bumps; First-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^3,'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
//
	subplot(223); 
        plot2d(reverse(cumsum(reverse(wcHeaviSine.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(reverse(dctHeaviSine.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('HeaviSine; First-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^3,'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
//
	subplot(224); 
        plot2d(reverse(cumsum(reverse(wcDoppler.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(reverse(cumsum(reverse(dctDoppler.^2))),logflag="nl");
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=3;
	title('Doppler; First-m')
	xlabel('m')
	ylabel('d_m')
	a=gca();a.data_bounds=([0 512 1 10^5]);
// 	xstring(350,10^4,'DCT -'); set(h,'Color','Red');
// 	xstring(350,10^3,'DWT --'); set(h,'Color','Yellow');
        legend(['DCT -';'DWT --'],3);
    
 
 

 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
