clc;mode(1);lines(0);    
// toon0531 -- Compress/Decompress Seismic Trace
//
//  Try and compress the seismic Trace using the top 100 wavelet
//  coefficients.  Plot the reconstruction and the error.
//
mode(-1);  
scf(1);clf(1);
	Trace = ReadSignal('Seismic')';  // note transpose
//
	qmf = MakeONFilter('Coiflet',3);
	wc  = FWT_PO(Trace,4,qmf);
//
	wprev  = reverse((mtlb_sort(wc.^2)));
	thresh = sqrt(wprev(100));
	wct    = wc .* bool2s(abs(wc) >= thresh);
	recon  = IWT_PO(wct,4,qmf);
//
	subplot(3,1,1)
	plot(Trace)
	title('Seismic Trace')
	//ax = axis;
	
	subplot(3,1,2)
	plot(recon)
	title('Reconstruction from 100 Wavelet Coefficients');
	//axis(ax);
	
	subplot(3,1,3)
	plot(Trace-recon)
	title('Error')
	//axis(ax);

    halt("press a key to proceed!");
clc;mode(1);lines(0);       
// toon0532 -- Compress/Decompress Seismic Trace
//
//  Try and compress the seismic Trace using the top 100 DCT
//  coefficients.  Plot the reconstruction and the error.
//
mode(-1);  
scf(1);clf(1);
	Trace = ReadSignal('Seismic')';  // note transpose
//
	dctcoef  = dct_iv(Trace);
//
	dcrev  = reverse((mtlb_sort(dctcoef.^2)));
	thresh = sqrt(dcrev(100));
	dctt    = dctcoef .* bool2s(abs(dctcoef) >= thresh);
	recon  = dct_iv(dctt);
//
	subplot(3,1,1)
	plot(Trace)
	title('Seismic Trace')
	//ax = axis;
	
	subplot(3,1,2)
	plot(recon)
	title('Reconstruction from 100 Cosine Coefficients');
	//axis(ax);
	
	subplot(3,1,3)
	plot(Trace-recon)
	title('Error')
	//axis(ax);

halt("press a key to proceed!");
clc;mode(1);lines(0);       
// toon0533 -- Compare all four methods of analysis on seismic signal
//
//  Show the compression curves for wavelet, DCT, wavelet packet,
//  and cosine packet analysis on the seismic signal.
//
mode(-1);  
scf(1);clf(1);
	Trace = ReadSignal('Seismic')';  // note transpose
//
	qmf = MakeONFilter('Coiflet',3);
	wc = FWT_PO(Trace,4,qmf);
//
	[wpcoef,bb] = BB_WP(Trace,10,qmf);
//
	[cpcoef,cpbb] = BB_CP(Trace,6);
//
	dccoef = dct_iv(Trace);
//
	wprev = reverse(cumsum(mtlb_sort(wpcoef.^2)));
	wcrev = reverse(cumsum(mtlb_sort(wc    .^2)));
	dcrev = reverse(cumsum(mtlb_sort(dccoef.^2)));
	cprev = reverse(cumsum(mtlb_sort(cpcoef.^2)));
	ymax = log10(wcrev(1));
	ymin = log10(wcrev(100));
//
	subplot(1,1,1);
	plot2d(dcrev,logflag="nl") ; 
        e=gce();
        e.children(1).foreground=color("yellow");
        e.children(1).line_style=2;
	plot2d(wcrev,logflag="nl") ; 
        e=gce();
        e.children(1).foreground=color("blue");
        e.children(1).line_style=3;
	plot2d(wprev,logflag="nl"); 
        e=gce();
        e.children(1).foreground=color("red");
        e.children(1).line_style=4;
	plot2d(cprev,logflag="nl"); 
        e=gce();
        e.children(1).foreground=color("green");
        e.children(1).line_style=5;
        legend(['BBCP -.';'BBWP ..';'DWT - ';'DCT --'],3);
// 	h = text(225,10^(ymax-.3) ,'BBCP -.'); set(h,'Color','Green');
// 	h = text(225,10^(ymax-.6) ,'BBWP ..'); set(h,'Color','Red');
// 	h = text(225,10^(ymax-.9),'DWT - '); set(h,'Color','Blue');
// 	h = text(225,10^(ymax-1.2),'DCT --'); set(h,'Color','Yellow');
	a=gca();a.data_bounds=([0 300 10^(ymin) 10^(ymax)]);
	title('Compression Numbers: Seismic')
	xlabel('m, number of coefficients retained'); 
	ylabel('c_m, (reconstruction error)^2')

    
//  Revision History
//             10/1/05     AM     Changing the name of the variable QMF

    
    
   
    
 
 
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
