clc;mode(1);lines(0);       
// toon0551 -- Four Spatially Inhomogenoeus Signals
//
//  These four signals are caricatures of signals arising
//  in scientific signal processing.
//
//  Blocks is a piecewise constant signal, a caricature of a scan line
//  through a 2-d image depicting an object with several edges.
//
//  Bumps is a very peaky signal, a caricature of an NMR Spectrum.
// 
//  HeaviSine is a sinusoid with two clicks.
//
//  Doppler is an attenuating sinusoid with time-varying frequency.
//
//  These objects are interesting to us because they portray significant
//  spatial inhomogeneity.
//
mode(-1);  
scf(1);clf(1);
global xblocks xbumps xheavi xDoppler
global yblocks ybumps yheavi yDoppler
global t N rho
//
	N = 2048;
	rho = 7;
	t = (0:(N-1))/N;
//
	HeaviSine = MakeSignal('HeaviSine',N);
	Bumps     = MakeSignal('Bumps',N);
	Blocks    = MakeSignal('Blocks',N);
	Doppler   = MakeSignal('Doppler',N);
//
	[xblocks,yblocks] = NoiseMaker(Blocks,rho);
	[xbumps,ybumps]   = NoiseMaker(Bumps,rho);
	[xheavi,yheavi]   = NoiseMaker(HeaviSine,rho);
	[xDoppler,yDoppler] = NoiseMaker(Doppler,rho);

//
clf;
subplot(221);
plot(t,xblocks);
title(' 1 (a) Blocks ' )
subplot(222);
plot(t,xbumps);
title(' 1 (b) Bumps ')
subplot(223);
plot(t,xheavi);
title(' 1 (c) HeaviSine ')
subplot(224);
plot(t,xDoppler);
title(' 1 (d) Doppler '  )

    halt("press a key to proceed!");
clc;mode(1);lines(0);        
    // toon0552 -- Noisy Versions of Four Signals
//
//  The four objects of Figure 1 with white noise superposed.
//  The noise is normally distributed with variance 1.
//
mode(-1);  
scf(1);clf(1);
global yblocks ybumps yheavi yDoppler t
//
subplot(221);
plot(t,yblocks);
title(' 2 (a) Noisy Blocks ' )
subplot(222);
plot(t,ybumps);
title(' 2 (b) Noisy Bumps ')
subplot(223);
plot(t,yheavi);
title(' 2 (c) Noisy HeaviSine ')
subplot(224);
plot(t,yDoppler);
title(' 2 (d) Noisy Doppler '  )

    
    halt("press a key to proceed!");
clc;mode(1);lines(0);     
// toon0553 -- Wavelet Shrinkage of the Four Noisy Signals
//
//  Here we apply a specific thresholding rule to the
//  four noisy signals depicted in toon0552.
//
//  The procedure for DeNoising:
//        1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//            with 8 vanishing moments.
//        2.  Apply a soft thresholding nonlinearity, with threshold set to
//            sqrt{2 log(n)}
//        3.  Transform back to the signal domain.
// 
//  The reconstructions suppress the noise, while preserving the sharp structure
//  in the neighborhood of the highly-variable spatial components.
//
mode(-1);  
scf(1);clf(1);
global yblocks ybumps yheavi yDoppler
global t
//
	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks] = WaveShrink(yblocks,  'Visu',L,QMF_Filter);
	[xhbumps]  = WaveShrink(ybumps,   'Visu',L,QMF_Filter);
	[xhheavi]  = WaveShrink(yheavi,   'Visu',L,QMF_Filter);
	[xhDoppler] = WaveShrink(yDoppler,'Visu',L,QMF_Filter);
//
subplot(221);
plot(t,xhblocks);
title(' 3 (a) VisuShrink[yBlocks] ' )
subplot(222);
plot(t,xhbumps);
title(' 3 (b) VisuShrink[yBumps] ')
subplot(223);
plot(t,xhheavi);
title(' 3 (c) VisuShrink[yHeaviSine] ')
subplot(224);
plot(t,xhDoppler);
title(' 3 (d) VisuShrink[yDoppler] '  )

	
     halt("press a key to proceed!");
clc;mode(1);lines(0);          
// toon0554 -- AutoSpline Reconstructions from Noisy Data
//
//  Here we depict a reconstruction using penalized thin-plate splines,
//  in which periodic thin-plate splines are used to smooth the data,
//  with roughness penalty proportional to the energy stored in the
//  second derivative.  The constant of proportionality (or Lagrangian
//  tuning parameter) is the empirical minimizer of the Stein Unbiased
//  Estimate of Risk.
//
mode(-1);  
scf(1);clf(1);
global yblocks ybumps yheavi yDoppler
global t
// 

//SplineInit();
//
	[xhat, c] = SplineUChoose(yblocks,2.);
subplot(221);
plot(t,xhat);
title(' 4 (a) AutoSpline[Blocks] ' )
//
	[xhat,c] = SplineUChoose(ybumps,2.);
subplot(222);
plot(t,xhat);
title(' 4 (a) AutoSpline[Bumps]] ' )
//
	[xhat,c] = SplineUChoose(yheavi,2.);
subplot(223);
plot(t,xhat);
title(' 4 (a) AutoSpline[HeaviSine] ' )
//
	[xhat,c] = SplineUChoose(yDoppler,2.);
subplot(224);
plot(t,xhat);
title(' 4 (a) AutoSpline[Doppler] ' )

    
 
 
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
