clc;mode(1);lines(0);         
// toon0561 -- Fast Algorithm for Matrix Multiplication
//
//  Illustrate Compression of Matrix Multiplication
//  using matrix with logarithmic singularity on diagonal.
//
//  The Matrix has the form
//        sin(2*pi .*X) .* sin(2*pi .*Y) .* log(abs(X-Y));
//
//  This is not circulant or Toeplitz, so Fourier Methods
//  cannot be applied.
//
//  First depict the matrix.
//
mode(-1);  
scf(1);clf(1);
	xm = linspace(0,1,128);
	ym = xm + xm(2)/2;
//	[X,Y] = meshdom(xm,ym);  // DLD 09/29/99
	[X,Y] = meshgrid(xm,ym);
	Y = flipud(Y);
	mat = sin(2*%pi .*X) .* sin(2*%pi .*Y) .* log(abs(X-Y));
//
	zmat = (mat + 6) .* 40;
	GrayImage(zmat);
// 	brighten(-.5)
// 	brighten(-.5)
	title('Sin(2*%pi*x) Sin(2*%pi*y) Log(Abs(X-y))')
    
       halt("press a key to proceed!");
clc;mode(1);lines(0);          
// toon0562 -- Fast Algorithm for Matrix Multiplication
//
//  The Beylkin-Coifman-Rokhlin method is to 
//   -> 1.  Take the 2-d Wavelet Transform of the matrix
//      2.  ``compress'' the 2-d wavelet transform
//      3.  ``stretch'' it into a nonstandard form
//      4.  apply the nonstandard form by matrix multiplication.
//
//  Here we look at the Wavelet Transform of the matrix.  It is SPARSE.
//
mode(-1);  
scf(1);clf(1);
	g = MakeONFilter('Coiflet',2);
	wmat = FWT2_PO(mat,3,g);
//
	zmat = (wmat + 51) .* 4;
	GrayImage(zmat);
	title('Wavelet Transform of Matrix');
    
      halt("press a key to proceed!");
clc;mode(1);lines(0);           
 // toon0563 -- Fast Algorithm for Matrix Multiplication
//
//  The Beylkin-Coifman-Rokhlin method is to 
//      1.  Take the 2-d Wavelet Transform of the matrix
//   -> 2.  ``compress'' the 2-d wavelet transform
//      3.  ``stretch'' it into a nonstandard form
//      4.  apply the nonstandard form by matrix multiplication.
//
//  How many non-negligible vales in WT ?
//
mode(-1);  
scf(1);clf(1);
	worder = mtlb_sort(abs(wmat(:)));
	plot(log(reverse(worder)+%eps))
	title('log(mtlb_sort(abs(NS[Matrix])))')
	xlabel('Ordered Coefficient'); ylabel('log(size(coefficient))');

     halt("press a key to proceed!");
clc;mode(1);lines(0);          
 // toon0564 -- Fast Algorithm for Matrix Multiplication
//
//  The Beylkin-Coifman-Rokhlin method is to 
//      1.  Take the 2-d Wavelet Transform of the matrix
//   -> 2.  ``compress'' the 2-d wavelet transform
//      3.  ``stretch'' it into a nonstandard form
//      4.  apply the nonstandard form by matrix multiplication.
//
//  Here compress the Wavelet Transform of the matrix.  We set small
//  elements ( < .01) to ZERO.
//
mode(-1);  
scf(1);clf(1);
	thresh = .01;
	sum(sum(abs(wmat)> thresh))
	spwmat = wmat .* bool2s( abs(wmat) > thresh );
// 	[i,j,s] = find(spwmat);
// 	spmat = sparse(i,j,s,128,128);
// 	spy(spmat)
	[i,j] = find(spwmat);
        spmat=ones(spwmat);
        spmat(i,j)=150;
        Matplot(spmat)
	title('spy(sparse(threshold(wmat))))')

     halt("press a key to proceed!");
clc;mode(1);lines(0);            
 // toon0565 -- Fast Algorithm for Matrix Multiplication
//
//  The Beylkin-Coifman-Rokhlin method is to 
//      1.  Take the 2-d Wavelet Transform of the matrix
//      2.  ``compress'' the 2-d wavelet transform
//  ->  3.  ``stretch'' it into a nonstandard form
//      4.  apply the nonstandard form by matrix multiplication.
//
//  Here we look at the nonstandard form of the compressed matrix.
//  It is ``stretched out''. 
//
mode(-1);  
scf(1);clf(1);
	[inew,jnew] = StretchMatrix(i,j,128,3);
// 	snsmat = sparse(inew,jnew,s,256,256);
// 	spy(snsmat)

        spmat=ones(spwmat);
        spmat(inew,jnew)=150;
        Matplot(spmat)
	title('Sparse Nonstandard form of Matrix')
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
