function [Beta,alfa] = AIDyadDown(afine,D,F,EF)
//  Average-Interpolating DownSampling Operator
//  Calling Sequence
//    [Beta,alfa] = AIDyadDown(afine,D,F,EF)
//   Parameters
//  Inputs:
//    afine:   fine-scale block averages
//    D    :   degree of polynomial fit in average-interpolation
//    F     :  filter implementing average-interpolation
//    EF    :  edge filter of average-interpolation
//  Outputs:
//    Beta :   coarse-scale block averages
//    alfa :   detail corrections
//
//  Description
//    Splits information afine on fine scale block averages into
//    coarse scale block averages Beta and detail corrections alfa.
//
//  See also
//    IWT_AI
//    AIRefine
//    MakeAIFilter
// 
// Authors
// H. Nahrstaedt - 2011
// Copyright (c) 1993. David L. Donoho

	n = max(size(afine));
	acoarse = (afine(1:2:(n-1)) + afine(2:2:n)) ./ 2;
	ahat = AIRefine(acoarse,D,F,EF);
	adif = afine - ahat;
	alfa = sqrt(2) .* adif(2:2:n);
	Beta = sqrt(2) .* acoarse;
endfunction
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
