function [coef,btree] = BB_CP(x,D,Entropy)
// Decomposition in Best Cosine Packet Basis
//  Calling Sequence
//    [coef, btree] = BB_CP(x,D,Entropy)
//   Parameters
//  Inputs:
//   x     :    1-d signal to analyze by Cosine Packets
//   D     :    maximum depth of dyadic subdivision of time domain [optional]
//   Entropy:   type of entropy for best-basis [optional; default 'Entropy']
//  Outputs: 
//   coef  :    coefficients in best Cosine Packets basis
//   btree :    basis tree of best time-frequency basis
//
//  Description
//	To reconstruct x, use IPT_CP(btree,x,D,'Sine').
//
//  See also
//    IPT_CP
//     CPTour
//     BestBasis
//     CalcStatTree
//
// Authors
// Copyright (c) 1994. David L. Donoho
//  H. Nahrstaedt - 2011
 [nargout,nargin]=argn();
	if nargin < 3,
		Entropy = 'Entropy';
	end
//
	if nargin < 2,
		[n,J] = dyadlength(x);
		D = max(J-4,1);
	end
//
	cp    = CPAnalysis(x,D,'Sine');
	stree = CalcStatTree(cp,Entropy);
	[btree,vtree] = BestBasis(stree,D);
	coef  = UnpackBasisCoeff(btree,cp);


    
endfunction    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
