function [coef,btree] = BB_WP(x,D,qmf,Entropy)
// Decomposition in Best Wavelet Packet Basis
//  Calling Sequence
//   [coef, btree] = BB_WP(x,D,qmf [,Entropy])
//  Parameters
//  Inputs : 
//   x     :   1-d signal to analyze by Wavelet Packets
//   D     :   fineness of frequency splitting
//   qmf   :   quadrature mirror filter (e.g. Coiflet c3)
//   Entropy:  criterion to optimize in best-basis algorithm      optiona; default 'Entropy' gives CW
//  Outputs: 
//   coef  :   Coefficients in best basis
//   btree :   basis tree of best time-frequency basis
//
//  Description
//	To reconstruct x, use IPT_WP(btree,x,D,qmf).
//
//  See also
//    IPT_WP
//    BestBasis
//    WPTour
// Authors
//  Copyright (c) 1994. David L. Donoho
// H. Nahrstaedt - 2011

 [nargout,nargin]=argn();
	if nargin < 4,
		Entropy = 'Entropy';
	end
//
	if nargin < 3,
		qmf = MakeONFilter('Coiflet',3);
	end
//
	if nargin < 2,
		[n,J] = dyadlength(x);
		D = J;
	end
//

	wp     = WPAnalysis(x,D,qmf);
	stree  = CalcStatTree(wp,Entropy);
	[btree,vtree] = BestBasis(stree,D);
	coef = UnpackBasisCoeff(btree,wp);

//
// Copyright (c) 1994. David L. Donoho
// 
endfunction
    

 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
