function wcoefs = CombineCoeff(rtrigcoefs,itrigcoefs,Window,n)
// Combine local trig. coeff's into wavelet coeff's
//  Calling Sequence
//    wcoefs = CombineCoeff(rtrigcoefs,itrigcoefs,Window,n)
//   Parameters
//  Inputs:
//    rtrigcoefs:   trigonometric coefficients corresponding to     projection of real part of \hat f
//    itrigcoefs :  trigonometric coefficients corresponding to     projection of imag part of \hat f
//    Window     :  string selecting window for projection.     'm' -> mother, 'f' -> father, 't' -> truncated mother
//    n         :   length of original signal f
//  Outputs:
//    wcoefs:       wavelet coefficients for a given level
//
//  See also
//    CoarseMeyerCoeff
//    DetailMeyerCoeff
//    FineMeyerCoeff
// Authors
//  Prepared for the thesis of Eric Kolaczyk, Stanford University, 1994
//  Copyright (c) Eric Kolaczyk, 1994.
//H. Nahrstaedt - 2011

	ln = max(size(rtrigcoefs));
	
	if Window == 'm',
	  wcoefs = zeros(1,2*ln);
	  wcoefs = [ [itrigcoefs + rtrigcoefs] ...
				 [fliplr(itrigcoefs-rtrigcoefs)] ] ./ (n) ;
	  wcoefs = (-1).^(1:2*ln).*wcoefs;
	elseif Window == 'f',
	  wcoefs = zeros(1,2*(ln-1));
	  wcoefs(1) = rtrigcoefs(1)/n;
	  wcoefs(2:2*(ln-1)) = [ [rtrigcoefs(2:ln) - itrigcoefs] ...
					   [rtrigcoefs(ln-1:-1:2) + itrigcoefs(ln-2:-1:1)] ]...
						 /  (sqrt(2)*n);
	  wcoefs = (-1).^(0:2*(ln-1)-1) .* wcoefs;
	elseif Window == 't',
	  wcoefs = zeros(1,2*ln);
	  wcoefs = [ [itrigcoefs + rtrigcoefs] ...
				 [fliplr(itrigcoefs-rtrigcoefs)] ] ./ (n) ;
	  wcoefs = (-1).^(1:2*ln).*wcoefs;
	
	else
	disp('Window given was not m,f, or t !');
	end


//

endfunction    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
