function [Beta,alfa] = DDDyadDown(afine,D,F,LEF,REF)
//  Deslauriers-Dubuc Interpolating DownSampling Operator
//  Calling Sequence
//    [Beta,alfa] = DDDyadDown(afine,D,F,LEF,REF)
//    Parameters
//  Inputs:
//    afine:   fine-scale samples
//    D    :   degree of polynomial fit in  DD interpolation
//    F    :   filter implementing DD-interpolation
//    LEF  :   Left edge filter for DD-interpolation
//    REF  :   Right edge filter for DD-interpolation
//  Outputs:
//    Beta :   coarse-scale samples
//    alfa :   detail corrections
//
//  Description
//    Splits information afine on fine scale samples into coarse
//    scale samples Beta and gen. midpoint deflections alfa.
//
//  See also
//    IWT_DD
//    DDRefine
//    MakeDDFilter
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011
	
	n = max(size(afine));
	acoarse = afine(1:2:(n-1));
	ahat = DDRefine(acoarse,D,F,LEF,REF);
	adif = afine - ahat;
	alfa = sqrt(2) .* adif(2:2:n);
	Beta = sqrt(2) .* acoarse;
    
    
//
// For Article "Interpolating Wavelet Transforms"

//
    
    
endfunction   
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
