function [beta, alpha] = DownDyad_SBS(x,qmf,dqmf)
//  Symmetric Downsampling operator
//  Calling Sequence
//    [beta,alpha] = DownDyad_SBS(x,qmf,dqmf)
//   Parameters
//  Inputs:
//    x   :  1-d signal at fine scale
//    qmf :  quadrature mirror filter
//    dqmf:  dual quadrature mirror filter
//  Outputs:
//    beta : coarse coefficients
//    alpha: fine coefficients
//  See also
//    FWT_SBS
//  Authors				
// Copyright (c) 1996. Thomas P.Y. Yu
//	H. Nahrstaedt - 2011


 // oddf = (rem(length(qmf),2)==1);
    oddf = ~(qmf(1)==0 & qmf(max(size(qmf)))~=0);
    oddx = (modulo(max(size(x)),2)==1);
	
// symmetric extension of x
 	  if oddf then
 	      ex = extend(x,1,1);
 	  else
 	      ex = extend(x,2,2);
 	  end
 	
 	  // convolution
 	  ebeta = DownDyadLo_PBS(ex,qmf);
 	  ealpha = DownDyadHi_PBS(ex,dqmf);
 	       
 	  // project
 	  if oddx then
 	     beta = ebeta(1:(max(size(x))+1)/2);
 	     alpha = ealpha(1:(max(size(x))-1)/2);
 	  else
 	     beta = ebeta(1:max(size(x))/2);
 	     alpha = ealpha(1:max(size(x))/2);
 	  end      
endfunction

    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:38 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
