function wcoef = FWT_PB(x,L,qmf,dqmf)
//  Forward Wavelet Transform (periodized, biorthogonal)
//  Calling Sequence
//    wc = FWT_PB(x,L,qmf,dqmf)
//   Parameters
//  Inputs:
//    x   :   1-d signal; length(x) = 2^J
//    L   :   Coarsest Level of V_0;  L << J
//    qmf :   quadrature mirror filter (symmetric)
//    dqmf :  quadrature mirror filter (symmetric, dual of qmf)
//  Outputs:
//    wc   :  1-d wavelet transform of x.
//
//  Description
//    1. qmf filter may be obtained from MakeBSFilter   
//    2. usually, length(qmf) < 2^(L+1)
//    3. To reconstruct use IWT_PB
//
//  See also
//    IWT_PB
//    MakeBSFilter
//
// Authors
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011


  [n,J] = dyadlength(x) ;
  wcoef = zeros(1,n) ;
  Beta = ShapeAsRow(x);  //take samples at finest scale as Beta-coeffts
  for j=J-1:-1:L
       alfa = DownDyadHi_PBS(Beta,dqmf);
       wcoef(dyad(j)) = alfa;
       Beta = DownDyadLo_PBS(Beta,qmf) ;  
  end
  wcoef(1:(2^L)) = Beta;
  wcoef = ShapeLike(wcoef,x);

endfunction

 

    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:38 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
