function wcoef = FWT_SBS(x,L,qmf,dqmf)
// Forward Wavelet Transform (symmetric extension, biorthogonal, symmetric)
//  Calling Sequence
//    wc = FWT_SBS(x,L,qmf,dqmf)
//   Parameters
//  Inputs:
//    x   : 1-d signal; arbitrary length
//    L   : Coarsest Level of V_0;  L << J
//    qmf :   quadrature mirror filter (symmetric)
//    dqmf:   quadrature mirror filter (symmetric, dual of qmf)
//  Outputs:
//    wc   : 1-d wavelet transform of x.
// 
//  Description
//    1. qmf filter may be obtained from MakePBSFilter
//    2. usually, length(qmf) < 2^(L+1)
//    3. To reconstruct use IWT_SBS
// 
//  See also
//    IWT_SBS
//    MakePBSFilter
// 
//  Bibliography
//   Based on the algorithm developed by Christopher Brislawn.
//   See "Classification of Symmetric Wavelet Transforms"
//   Authors
// Copyright (c) 1996. Thomas P.Y. Yu
//  H. Nahrstaedt - 2011

  [n,J] = dyadlength(x);
	
	wcoef = zeros(1,n);
	Beta = ShapeAsRow(x);  // take samples at finest scale as Beta-coeffts

	dp = dyadpartition(n);
	
	for j=J-1:-1:L
	  [Beta, alfa] = DownDyad_SBS(Beta,qmf,dqmf);
	  dyadj = (dp(j+1)+1):dp(j+2);
	  wcoef(dyadj) = alfa;
	end
	wcoef(1:max(size(Beta))) = Beta;
	wcoef = ShapeLike(wcoef,x);
	endfunction


    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:38 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
