function tau = FracScalExp(z,scale,loscale,hiscale)
// Calculate Moment Generating Function
//  Calling Sequence
//    tau = FracScalExp(z,a,loscale,hiscale)
//   Parameters
//  Inputs:
//    z    :     matrix nexp by nscale of z(q,a) ``Thermo Partition Func''
//    scale :        list of scales 
//    loscale:   optional min scale to fit line by
//    hiscale :  optional max scale to fit line by 
//  Outputs:
//    tau   :    vector 1 by nscale of moments
//
//  Description
//    tau(q) = Slope [ log(z(q,a))  versus log(a) ]
//	section 6.5.2 of Mallat's book
//
//  See also
//    FracPartition
// Authors
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011


 [nargout,nargin]=argn();
	if nargin < 3,
		loscale = 0.;
		hiscale = 10^32;
	end
	
	
	[nq,nscale]     = size(z);
	tau = zeros(nq,1);
	if nscale ~= size(scale),
		disp('FracScalExp: no match between z and a')
	end
	
	Window = (loscale <= scale) & (scale <= hiscale);
	ix     = find(Window);
	l = max(size(ix));
	if max(size(ix))>1,
		for kq =1:nq,
		 	y       =  log(z(kq,ix));   
			y = y-mean(y);
			x       =  log(scale(ix));  
			x = x-mean(x);			
			tau(kq) = sum(y.*x) / sum(x.*x);
//			tau(kq) = (y(l)-y(1)) ./ (x(l)-x(1));
//			tau(kq) = sum(y./x)./l;
		end
	else
		disp('FracScalExp: not enough data to determine slope')
	end 	 
    
endfunction
    
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
