function f = FracSingSpect(tau,q,alpha)
// Calculate Spectrum of Local Scaling Exponents
//  Calling Sequence
//    f = FracSingSpect(z,q,alpha)
//  Parameters
//  Inputs:
//    tau  :     matrix 1 by nq of tau(q) ``Moment Gen Func''
//    q    :     optional list of exponents.  Default linspace(-2,5,61)'
//    alpha :    optional list of dimensions. Default linspace(.1,.9,11)
//  Outputs:
//    f     :    vector 1 by length(alpha) of fractal dimensions
//
//  Description
//    section 6.5.2 of Mallat's book
//
//  See also
//    RWT
//    MM_RWT
//    FracPartition
// Authors
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011


 [nargout,nargin]=argn();
	if nargin < 3,
		alpha = linspace(.1,.9,11);
	end
	
	if nargin < 2,
		q  = linspace(-2,5,61)';
	end
	
	nalpha = max(size(alpha));
	f = zeros(nalpha,1);
	
	nq = max(size(q));
	minq = q(1);
	maxq = q(nq);
	

	for kalpha =1:nalpha,
		f(kalpha) = min((alpha(kalpha)+.5)*q - tau);
		bogus = f(kalpha);
		if  alpha(kalpha)*maxq - tau(nq) == f(kalpha),
			bogus = -10;
		elseif alpha(kalpha)*minq - tau(1) == f(kalpha),
 			bogus = -10;
		end
//		find(alpha(kalpha)*q - tau == f(kalpha))
		f(kalpha) = bogus;
	end
    
endfunction
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
