function x = INWT_PO(nwc,L,qmf)
//  Inverse Nonstandard Wavelet Transform (Periodized, Orthogonal)
//  Calling Sequence
//    x = INWT_PO(nwc,L,qmf)
//   Parameters
//  Inputs:
//    nwc :    nonstandard wavelet transform. Produced by FNWT_PO.
//    L   :    coarsest resolution level
//    qmf :    quadrature mirror filter
//  Outputs:
//    x    :   1-d signal. length(x) = 2^J.
//
//  Description
//    if x is a vector and M is a matrix, then one can calculate
//    Mx in two ways:
//          (a) Use standard basis: M*x
//          (b) Use wavelet Basis:  INWT[NSF * FNWT[x]]
//    where NWT and INWT are nonstandard wavelet transforms and NSF 
//    is the nonstandard form of the matrix.
//
//  See also
//    FNWT_PO
//     FSFT_PO
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

        nwc = ShapeAsRow(nwc);
        x = zeros(1,max(size(nwc))/2);
	[n,J] = dyadlength(x);
	Beta = nwc(1:2^L);
	for j=L:(J-1),
	  alfa = UpDyadHi(nwc(ndyad(j,1)),qmf);
	  Beta = UpDyadLo(Beta + nwc(ndyad(j,0)),qmf) + alfa ;
	end
	x = Beta';
    
endfunction 
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
