function Beta = IWT_AI(wc,L,D,F,EF)
//  Inverse transform, average-interpolating wavelets
//  Calling Sequence
//    x = IWT_AI(wc,L,D)
//  Parameters
//  Inputs:
//    wc  :  1-d wavelet transform; length(x) = 2^J
//    L   :  coarsest resolution. L << J
//    D   :  degree of polynomials for average interpolation
//  Outputs:
//    x    : 1-d signal reconstructed from wc
//
//  Description
//    IWT_AI implements a 1-d inverse wavelet transform of data which
//    arise as the outputs of boxcar integrators.  The ideas are
//    described in ``Smooth Wavelet Decompositions with Blocky
//    Coefficient Kernels.''  See BlockyDemo and the directory
//    Scripts/Blocky.
// Examples
//   wc=1:1024;
//   L=8;
//   D=10;
//   Beta=IWT_AI(wc,L,D);
//  See also
//    FWT_AI
//    FWT_DD
//    FWT_PO 
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

    [lhs,rhs]=argn()
        
        if rhs == 3,
	  F = MakeAIFilter(D);
	  EF = MakeAIBdryFilter(D);
	end
	
	[n,J] = dyadlength(wc);
	w     = ShapeAsRow(wc);
	Beta  = w(1:(2^L));
//
	for j=L:(J-1) ,
	   Beta = AIDyadUp(Beta,w(dyad(j)),D,F,EF);
	end
//
	x = ShapeLike(Beta,wc);
endfunction


//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
