function x= IWT_CDJV(wc,L,N)
// Inverse Wavelet Transform  (boundary corrected)
//  Calling Sequence
//    x = IWT_CDJV(wc,L,N)
//   Parameters
//  Inputs:
//    wc  : 1-d wavelet transform
//    L   : Level of V_0;  L << J
//    N   : Degree of Daubechies Filters
//  Outputs:
//    x    : 1-d signal: length(y) = 2^J
//
//  See also
//    FWT_CDJV
//    MakeCDJVFilter
//
//  Bibliography
//   This is an implementation of the Cohen-Daubechies-Jawerth-Vial Algorithm
//   for orthonormal wavelet bases of compact support, with boundary corrected
//   wavelets at 0 and 1.
//
// Authors
// Copyright (c) 1993. David L. Donoho
//     H. Nahrstaedt - 2011

	[HPF,LHPEF,RHPEF] = MakeCDJVFilter('HighPass',N);
	[LPF,LLPEF,RLPEF] = MakeCDJVFilter('LowPass',N);
	[LPOSTMAT,RPOSTMAT] = MakeCDJVFilter('PostCondition',N);
//
    wcoef = ShapeAsRow(wc);
	[n,J] = dyadlength(wcoef) ;
	Beta = wcoef(1:(2^(L))); 
	for j=L:(J-1),
	   alfa = CDJVDyadUp(wcoef(dyad(j)),HPF,LHPEF,RHPEF); 
	   Beta = CDJVDyadUp(Beta,LPF,LLPEF,RLPEF) + alfa;
	end
	x = Beta;
	x(1:N) = (Beta(1:N)) *  LPOSTMAT';
	x(n:-1:(n-N+1)) = Beta(n:-1:(n-N+1)) * RPOSTMAT';
//
    x = ShapeLike(x,wc);
endfunction

    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
