function x = IWT_DD(wc,L,D,F,LEF,REF)
// Inverse transform Deslauriers-Dubuc wavelets
//  Calling Sequence
//    x = IWT_DD(wc,L,D)
//   Parameters
//  Inputs:
//    wc  :     1-d wavelet transform; length(w) = 2^J
//    L   :     coarsest resolution. L << J
//    D   :     degree of interpolating polynomials
//  Outputs:
//    x    :    1-d signal reconstructed from w
//
//  Description
//    IWT_DD implements a 1-d inverse wavelet transform of data which
//    arise as the outputs of point sampling devices.  The ideas are
//    described in ``Interpolating Wavelet Transforms.''
//
// Examples
//   wc=1:1024;
//   L=8;
//   D=9;
//   x=IWT_AI(wc,L,D);
//
//  See also
//    FWT_DD
//    FWT_AI
//    FWT_PO 
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011


    [lhs,rhs]=argn()
    if rhs == 3,
	  F = MakeDDFilter(D);
	  [LEF,REF] = MakeDDBdryFilter(D);
	end
	  
        [n,J] = dyadlength(wc);
	w     = ShapeAsRow(wc);
	Beta  = w(1:(2^L));
//
	for j=L:(J-1) ,
	   Beta = DDDyadUp(Beta,w(dyad(j)),D,F,LEF,REF);
	end
//
	x = ShapeLike(Beta,wc);
endfunction
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
