function sig = IWindowFT(specgm,w,Name)
// Inverse Window Fourier Transform
//  Calling Sequence
//    sig = IWindowFT(specgm,w,Name)
//  Parameters
//  Inputs:
//    specgm  :  Window Fourier Transform of sig, complex matrix
//    w      :  window half-length used to construct specgm
//    Name   :  string: 'Rectangle', 'Hanning', 'Hamming',  'Gaussian', 'Blackman'   name of window used to construct specgm
//  Outputs:
//    sig   :   1-d signal
//  Description
//     supposes signal is non-periodic, i.e. zero-padded
//     reconstruction is not exact in the border region, but it is
//     exact in the center
//  See also
//    WindowFT
//  Bibliography
//    Mallat, "A Wavelet Tour in Signal Processing"; 
//            4.2.3 Discrete Windowed Fourier Transform.
// Authors
// Copyright (c) 1997. Maureen Clerc and Jerome Kalifa
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011

[n,nw] = size(specgm);
f = zeros(3*n,1);
totseg = zeros(3*n,1);
win    = MakeWindow(Name,w);
win    = win(:);
wind = zeros(3*n,1);
wind(n+1-w:n+1+w,1) = win;

for i = 1:nw,
	totseg(n+1:2*n) = Wavelab_ifft(specgm(:,i)');
	f = f + wind.*totseg;
	wind = rshift(wind')';
end;
f = f(n+1:2*n);
//sig = f/max(svd(wind))^2.;
sig = f/norm(wind)^2.;
endfunction
//

    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
