function ImageCWT(cwt,Scaling,colors,option,oct,scale)
// Image of Continuous Wavelet Transform
//  Calling Sequence
//    ImageCWT(cwt,scaling,colors)
//  Parameters
//  Inputs:
//    cwt  :    matrix produced by CWT
//    scaling:  string, 'Overall', 'Individual'
//    colors :  string  argument for colormap
//    option :  'lin' or 'log' for the type of display
//    oct    :  Default=2
//    scale  :  Default=4
//
//  Description
//    Image Display of Continuous Wavelet Transform
// Authors
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011

  [lhs,rhs]=argn();
	if rhs < 5,
		oct = 2;
		scale = 4;
	end
	if rhs < 4
       	    option = 'log';
	end
	sz     = size(cwt);
	n      = sz(1);
	nscale = sz(2);
	noctave= floor(log2(n)) -2;
	nvoice = nscale ./ noctave;

  if  string(option)=='log'  
	  ytix   = linspace(1+(oct-floor(log2(scale))),log2(n)-oct,nscale);
	  xtix   = linspace(0,n,n);
	else
	  xtix   = linspace(0,n,n);
	  ytix   = linspace(fix(n/2),0,fix(nscale));  
	end
	
	if string(Scaling)=='Individual',  
	    for k=1:nscale,
		    goodstart = min(n/2 .* 2^(-k/nvoice), n/4);
		   	amin = min(cwt(fix(goodstart):fix(n-goodstart),k));
		    amax  = max((cwt(fix(goodstart):fix(n-goodstart),k)));
		    cwt(:,k) = ((cwt(:,k))-amin) ./ (amax-amin) .*255 + 1;
		end
	else 
		amin = min(min(cwt));
	  amax = max(max((cwt)));
		cwt = (cwt+amax) ./ (2*amax) .*255 + 1;
	end
	
  if string(option)=='lin'  
	  mtlb_image(xtix,ytix, flipud(cwt'));     
	  //axis('xy');
	else
	  mtlb_image(xtix,ytix, cwt');
          //axis('ij');
	  xlabel('')
	  ylabel('log2(s)')
	end
	f=gcf();
	execstr(sprintf('f.color_map=(1-%scolormap(256))',colors));
	//xset("colormap",eval(colors));
	
endfunction


//   
// Originally Part of WaveLab Version .701

 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
