function ImageGaborPhase(TFType,pkt,ell,titlestr)
//  Time-Frequency Display with congruent rectangles
//  Calling Sequence
//    ImageGaborPhase(pkt,ell[,titlestr])
//  Parameters
//  Inputs:
//    TFType:    type of time-frequency decomposition: 'WP' or 'CP'
//    pkt   :    wavelet or cosine packet table
//    ell    :   level of packet table to use
//    titlestr:  optional title string for plot
//
//  Description
//    Phase plot with 2^(ell-1) vertical and n/(2^(ell-1))
//    horizontal subdivisions.
//
//  See also
//    ImagePhasePlane
//    CPTour
//    WPTour
//
// Authors
// Copyright (c) 1993. David L. Donoho
//    H. Nahrstaedt - 2011
 [nargout,nargin]=argn();
	if nargin < 3,
	   titlestr = ' ';
	end
	[n,L] = size(pkt);
	if ell < 0 | ell >= L,
	   printf('in ImageGaborPhase, ell=%g, needs to be 0 <= ell < %g\n',ell,L);
	else 
	   ltree = zeros(1,2^L);
	   if ell >= 1 & ell < L,
		  ltree(1:(2^ell-1)) = ones(1,2^ell-1);
	   end
	   ImagePhasePlane(TFType,ltree,pkt,titlestr)
	end
endfunction
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
