function fBr = MakeBrownian(n,H,par)
// Create Fractional Brownian Signal
//  Calling Sequence
//    fBr = MakeBrownian(n,H,par)
//  Parameters
//  Inputs:
//    n   :    signal length
//    H   :    base of digits in expansion
//    par :    optional, degree of extension in algorithm, default =8.
//  Outputs:
//    fBr  :   (pseudo) Fractional Brownian signal
//
//  Description
//    Uses a Frequency Domain algorithm to get a pseudo Brownian Motion
//    The law is NOT normalized to give unit variance to unit increments.
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

  [lhs,rhs]=argn();
	if rhs < 3,
		par = 8;
	end
	N = n .*par;

// generate the FT of a real white noise
	w    = WhiteNoise(zeros(1,N));
	whatt = Wavelab_fft(w);

// formal fractional integral
	eta  = 2 * %pi * [0:(N/2) (-(N/2)+1):(-1)] ./ N;
	eta(1) = 1;
	bhat = (abs(eta) .^ (-2*H)) .* whatt;
	bhat(1) = 0.;
	fBr  = Wavelab_ifft(bhat);

// extract a segment that is well away from the edges

	start = floor(par/2 .* n);
	stop  = start+n-1;
	fBr   = real(fBr(start:stop));
	endfunction
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
