function x = MakeProcess(NR,N);
//  Generates NR locally stationary process realizations
// Calling Sequence
// x = MakeProcess(NR,N);
// Description
//   Generates NR locally stationary process realizations
//    byfiltering a white noise (z) through a slowly varying filter (kernel);
//   The filtering is done by convolution in the time-domain. 
// Parameters
// Inputs ;
//	NR  : number of realizations
//       N   : size of signal
//
// Outputs:
//  	x   : N*NR matrix containing NR realizations of a  locally stationary process
// Authors
// Written October 4, 1996 by Maureen Clerc
//H. Nahrstaedt - 2011

  x = zeros(N,NR);
  gammaa = (N/2) * %pi;       // center frequency
  par = 1000;               // the greater par, the slower the variation 
  M = N/16;
  enveloppe = ones(1,N); // the rising cutoff function 
  start = (1:round(M));       // the rising cutoff interval
  enveloppe(start) = (1+sin(-%pi/2+(start-ones(1,round(M)))./(M-1)*%pi))/2;
    enveloppe(round(N-M+1):N) = reverse(enveloppe(1:round(M)));
// ---------- the lsp (x) -----------------------------------
  Beta = .3;
  for k = 1:NR,
   z= WhiteNoise(ones(1,N));
   for j = 1:N,
    d = (j-1)./N - (1:N)./N;
   end;
  
  Beta = .01;
  for i = 1:N,
    j = (1:N)-i;
    sa = 1+(i>M) * Beta * (i-M);
    Filter = exp(-(j./sa).^2/2)./%pi./sa;
    Filter = enveloppe(i).* (Filter ./sum(Filter));
   Filter = Filter .* cos(%pi.*j./4);
    x(i,k) = sum(z.*Filter);
  end
  end;
endfunction

    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
