function PlotColumns(Matrix,starting,ABS,GlobalScale,par)
//  Plot each Column of input matrix
//  Calling Sequence
//    PlotColumns(matrix,starting,ABS,GlobalScale);
//  Parameters
//  Inputs:
//    matrix:  	input matrix
//    starting:   starting position of figures, 1 or 2
//    ABS     :   take absolute value[1] or not[0]
//    GlobalScale:	if use global scale[1] or not[0], default = 0;
//  Description
//    Utility function;
//    
//        generate a figure with plot for each column
//     
//  Examples
//    test = rand(1024,5) - .5;
//    clf; PlotColumns(test)  
//    starting = 2; 
//    clf; PlotColumns(test,starting)
//    ABS = 1;
//    clf; PlotColumns(test,starting,ABS)
//    GlobalScale = 1;
//    clf; PlotColumns(test,starting,ABS,GlobalScale)
//  See also
//    DisplayDWT
//  
//   Authors
// Copyright (c) 1996. Xiaoming Huo
// H. Nahrstaedt - 2011


  [nargout,nargin]=argn();   
 if nargin < 5,
	par = 0;
 end
 if nargin < 4,
	GlobalScale = 0;
 end;

 if nargin < 3,
 	ABS = 0;
 end;
 
 if nargin < 2,
	starting = 1;
 end;

 if ABS ~= 0,
	Matrix = abs(Matrix);
 end;

 MIN = min(min(Matrix));
 MAX = max(max(Matrix));

 [nrows,ncols]  = size(Matrix);
 nfigures 	= ncols + starting - 1 + par;
 leftshift = nrows ./ 15;
 for i = 0:(ncols - 1),
	subplot(nfigures, 1, i + starting)
	plot(Matrix(:,i+1))

	plot(zeros(nrows,1))

	st = sprintf('2^%d',i+1);
	if GlobalScale, 
	 	a=gca();a.data_bounds=([1 nrows MIN MAX]); 
 	else,
		a=gca();a.data_bounds=([1 nrows min(Matrix(:,i+1)) max(Matrix(:,i+1))]);
	end;

	xstring(-leftshift,0,st)
 end;


endfunction
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
