function PlotGenFracDimen(d,q,scales)
// Plot Generalized Fractal Dimension Function
//  Calling Sequence
//    PlotGenFracDimen(d,q,scale)
//   Parameters
//  Inputs:
//    d    :     matrix output by CalcGenFracDimen
//    q    :     optional list of exponents default linspace(-2,5,61)
//    scales:    optional list of scales
//
//  Description
//    Display D(q,a)   
//
//  See also
//    CWT
//    WTMM
//    CalcThermoPartition
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

  [lhs,rhs]=argn();
	if rhs < 3,
		scales = 1;
	end	
	if rhs < 2,
		q = linspace(-2,5,61);
	end
	if isempty(q),
	    q = linspace(-2,5,61);
	end

	[nrow,ncol] = size(d);
	
	if ncol==1,
		plot(q,d);	
		title('Generalized Fractal Dimension');
		xlabel('Exponent q');
		ylabel('D(q)');
		a=gca();a.data_bounds=([min(q) max(q) -1 2]);
	else   	
		for k=1:nrow,
			plot2d(scales,d(k,:),logflag="ln"); // hold on;
			xstring(scales(1)*.8,d(k,1),sprintf('q=%5.2f',q(k)));
		end
		title('Generalized Fractal Dimension');
		xlabel('Scale a');
		ylabel('D(q,a)');
		a=gca();a.data_bounds=([(min(scales)/2) (max(scales)*2) -1 2]);
		//hold off;
	end
	endfunction
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
