function PlotRidges(ridgelist,wt,skellist,skelptr,skellen)
// Log-Log Plot of Ridges in Continuous Wavelet Transform
//  Calling Sequence
//    PlotRidges(ridgelist,wt,skellist,skelptr,skellen)
//   Parameters
//  Inputs:
//    ridgelist: index of ridges to plot, 1 <= ridgelist(i) <= nchains
//    wt       : continuous wavelet transform output by CWT
//    skellist : storage for list of chains
//    skelptr  : vector of length nchain -- pointers to heads of chains
//    skellen  : vector of length nchain -- length of skellists
//
//  Description
//    Log-Log Plot of the amplitude of the wavelet transform versus
//    scale along various ridges
//
//  See also
//    CWT
//    WTMM
//    BuildSkelMap
//    PlotSkelMap
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011


	nridge = max(size(ridgelist));
	amax = 0; amin = 10^10;
    smax = 0; smin = 10^10;	
	for i=1:nridge,
		printf('Extracting Ridge %i\n',ridgelist(i)),
		ridge = ExtractRidge(ridgelist(i),wt,skellist,skelptr,skellen);
		plot2d(ridge(:,1),ridge(:,2),logflag="ll"); //*?hold on;loglog
		smax = max(smax, max(ridge(:,1)));
		smin = min(smin, min(ridge(:,1)));
		amax = max(amax, max(ridge(:,2)));
		amin = min(amin, min(ridge(:,2)));
		xstring(ridge(1,1),ridge(1,2),sprintf('%i',ridgelist(i)));
	end
        a=gca();a.data_bounds=([smin smax amin amax]);
        title('Amplitude of Wavelet Transform Along Ridges');
	xlabel('scale')
	ylabel('amplitude')
	//hold off;
	endfunction
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
