function scale = RWTscale(sig,cwt)
//  Complement to Continuous Wavelet Transform
// Calling Sequence
//    scale = CWTscale(sig,cwt);
//   Parameters
//  Inputs:
//    sig :     1-d signal
//    cwt  :    continous wavelet transform of sig, Output from CWT(sig)
//  Outputs:
//    scale :   complement of continuous wavelet Transform of sig   
//  Description
//     scale = fft(sig) - sum(columns of cwt)
//     
//  Examples
//     N = 1024;     // signal length; 
//     nvoice = 12;  
//     // create a Brownian
//     CantorMeasure = MakeFractal(N,3,'Deterministic',[.5 0 .5]);
//     Devil  = cumsum(CantorMeasure); t = (.5:(N-.5))./N;
//     figure; plot(t, Devil); title(sprintf(' Devil Staircase Signal'));
//     // make CWT
//     Devil_cwt = CWT(Devil,nvoice,'Sombrero');
//     // complement to CWT
//     scale = CWTscale(Devil,Devil_cwt);
//     plot(real(scale));
//  See also
//    CWT  
//    iCWT
//  Bibiography
//    Mallat, "Wavelet Signal Processing"; 
//    
//  Authors
//  H. Nahrstaedt - 2011

 sz = size(cwt);
 
 fftsig = Wavelab_fft(sig(:));
 for i = 1:sz(2),
	fftsig = fftsig - Wavelab_fft(cwt(:,i));
 end;
 scale = (Wavelab_ifft(fftsig));
    
endfunction
