function Image = ReadImage(Name)
//  Read Image file in 8-bit raw binary format
//  Calling Sequence
//    Image = ReadImage(Name)
//  Parameters
//  Inputs:
//    Name :   'Barton', 'Canaletto', 'Coifman', 'Daubechies', 'Fingerprint', 'Lincoln', 'Lenna', 'MRIScan', 'Phone'
//  Outputs:
//    Image :   2-d signal, n by n, n dyadic
//
//  Description
//    A descriptor file for the data is printed
//  Authors
// Copyright (c) 1993-5. Jonathan Buckheit and David Donoho
// 
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011
//
    global WLVERBOSE;
	global WAVELABPATH ;       // set by WavePath.m
//
	if (Name=='Barton'),
	    filename = 'barton.raw';
	    par = [512,512];
	    source = 'barton.txt';
	elseif (Name=='Canaletto'),
	    filename = 'canaletto.raw';
	    par = [512,512];
	    source = 'canaletto.txt';
	elseif (Name=='Coifman'),
	    filename = 'coifman.raw';
	    par = [256,256];
	    source = 'coifman.txt';
	elseif (Name=='Daubechies'),
	    filename = 'daubechies.raw';
	    par = [256,256];
	    source = 'daubechies.txt';
	elseif (Name=='Fingerprint'),
	    filename = 'fingerprint.raw';
	    par = [512,512];
	    source = 'fingerprint.txt';
	elseif (Name=='Lenna'),
		filename = 'lenna.raw';
		par = [256,256];
		source = 'lenna.txt';
	elseif (Name=='Lincoln'),
	    filename = 'lincoln.raw';
	    par = [64,64];
	    source = 'lincoln.txt';
	elseif (Name=='MRIScan'),
	    filename = 'mriscan.raw';
	    par = [256,256];
	    source = 'mriscan.txt';
	elseif (Name=='Phone'),    
	    filename = 'phone.raw';
	    par = [128,128];
	    source = 'phone.txt';
	elseif (Name=='Barbara'),
	    filename = 'barb.raw';
	    par = [512,512];
	    source = 'barb.txt';
	else
	    disp('I only know how to read the datasets:            ');
	    disp('   Barton, Canaletto, Coifman, Daubechies,       ');
	    disp('   Fingerprint, Lincoln, Lenna, MRIScan, Phone   ');
	    filename = 'BOGUS';
	end
	
	if ~(filename=='BOGUS'),
	   Filename = WAVELABPATH +'/demos/Datasets' +  filesep()+filename;
	    fid = mopen(Filename,'rb');
	    if fid < 0,
	        printf('ReadImage: I was unable to open the dataset %s',filename);
	        disp('Typically way this error could occur       ');
	        disp('is by the failure of your WavePath.m file to reflect   ');
	        disp('the actual name of the root WaveLab directory.        ');
	        disp('Solution: quit Matlab, correctw WavePath, restart Matlab. ');
	        disp('In our experience this always works.                  ');
	      else
// 		if strcmp(WLVERBOSE,'Yes') 
// 		  printf('Reading %s\n', filename)
// 		  frintf('It is an array of size [%4.0f,%4.0f]\n',par(1),par(2))
// 		  docfile = [WAVELABPATH 'Datasets'  ...
// 			PATHNAMESEPARATOR source];
// 		  type(source)
// 		end
	        Image = mtlb_fread(fid,par);
	        mclose(fid);
	    end
	end
endfunction
//

//

// 	Revision History
//		1.2 09/29/99	DLD		changed .doc -> .txt
//								changed fid < 0 message.
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
