function Signal = ReadSignal(Name)
// Read 1-d signal from file in ascii format
//  Calling Sequence
//    signal = ReadSignal(Name)
//  Parameters
//  Inputs:
//    Name :   'Caruso', 'ESCA', 'Greasy', 'HochNMR', 'Seismic', 'Laser', 'RaphaelNMR', 'Sunspots', 'Transients', 'Tweet'
//  Outputs:
//    signal:   1-d signal
//
//  Description
//    A descriptor file for the data is printed
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

        global WLVERBOSE
	global WAVELABPATH        // set by WavePath.m
//
	if (Name=='Tweet'),
	  filename = 'tweet';
	elseif (Name=='Transients'),
	  filename = 'transients';
	elseif (Name=='Sunspots'),
	  filename = 'sunspots';
	elseif (Name=='RaphaelNMR'),
	  filename = 'RaphNMR';
	elseif (Name=='Laser'),
	  filename = 'laser';
	elseif (Name=='Seismic'),
	  filename = 'seismic';
	elseif (Name=='HochNMR'),
	  filename = 'HochNMR';
	elseif (Name=='Greasy'),
	  filename = 'greasy';
	elseif (Name=='ESCA'),
	  filename = 'esca';
	elseif (Name=='Caruso'),
	  filename = 'caruso';
	elseif (Name=='msignal'),
	  filename = 'msignal';
	elseif (Name=='lady'),
	    filename = 'lady';
	else
	    disp('I only know how to read the signals:     ');
	    disp('   Caruso, ESCA, Greasy, HochNMR,        ');
	    disp('   Seismic, Laser, RaphaelNMR,           ');
	    disp('   Sunspots, Transients, Tweet           ');
	    filename = 'BOGUS';
	end
	
	if ~(filename=='BOGUS'),
	    filepath = WAVELABPATH +'/demos/Datasets' +  filesep()+filename +'.asc';
	    fid = mopen(filepath,'r');
	    if fid < 0,
	        disp('ReadSignal: I was unable to open the dataset you requested        ');
	        disp('Practically the only way this error could occur       ');
	        disp('is by the failure of the WavePath.m file to reflect   ');
	        disp('the actual name of the root WaveLab directory.        ');
	        disp('Solution: quit Matlab, edit WavePath, restart Matlab. ');
	        disp('In our experience this always works.                  ');
	    else
	       if (WLVERBOSE=='Yes') 
		 printf('Reading %s\n', filepath)
		 //docpath = [WAVELABPATH+'demos/Datasets'+ filesep()+ filename+ '.txt'];
		 //type(docpath)
	       end	 
                //mclose(fid);  
	       //Signal =fscanf(fid,'%g');
                Signal=mfscanf(-1,fid,'%g');
                //Signal=fscanfMat(filepath);
	        mclose(fid);
	        par = size(Signal);
		if (WLVERBOSE=='Yes') 
		  printf('It is an array of size[%4.0f,%4.0f]\n',par(1),par(2))
		end		
	    end
	end
endfunction
//
// Copyright (c) 1993-5, Jonathan Buckheit and David Donoho
//

//	Revision History
//		09/29/99	DLD Changed .doc to .txt
//     
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
