function specgm = Spectrogram(sig,w,m,titl)
//  Time-Varying Spectrum
//  Calling Sequence
//    specgm = Spectrogram(sig,w,m,titl)
//  Parameters
//  Inputs:
//    sig  :    1-d signal
//    w    :    window half-length, default = n/2
//    m    :    inter-window spacing, default=1
//    titl  :   Optional Title String Modifier
//  Outputs:
//    specgm:   spectrogram
//
//  Description
//    Image Plot of the spectrogram
//
//  See also
//    WVDist
//    WVDist_AF
//    ImagePhasePlane
//
// Authors
// Copyright (c) 1995, David Donoho
//H. Nahrstaedt - 2011

 [nargout,nargin]=argn();
    
	sig = x(:);
	n = max(size(x));
	f = [zeros(n,1); sig; zeros(n,1)];
//
	if nargin < 2,
		w = n/2;
	end
	if nargin < 3,
		m=1;
	end
	if nargin < 4,
		titl = [];
	end
//
	nw     = floor(n ./ m);
	specgm = zeros(w+1,nw);
	ix     = ((-w+1):w);
//
	for l=1:nw,
		t = 1+ (l-1)*m;
		if m==1 & modulo(t,16)==1,
			printf('Spectrogram: t=%i\n',t);
 		end

		tim = n + t + ix;
		seg = f(tim);
		localspec = abs(fft(seg));
		specgm(:,l)  = localspec(1:(w+1));
	end

//
// Make Spectrogram Display

	spmax = max(max(specgm));
	spmin = min(min(specgm));
	
	mtlb_image(linspace(0,1,n),linspace(0,1,w+1),255*(specgm-spmin)/(spmax-spmin) + 1);
        F=gcf();F.color_map(1-graycolormap(256));
	xlabel('Time')
	ylabel('Frequency')
//
	//titl = AppendTitle('Spectrogram',titl);
	title('Spectrogram '+titl);
//
// 	if nargout==0,
// 		specgm = [];
// 	end


endfunction
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
