function [xh,c] = SplineUChoose(y,k)
// Estimate Optimal Bandwidth for Spline Kernel
// Calling Sequence
//   [xhat,risk] = SplineUChoose(y,k)
//  Parameters
// Inputs:
//   y   :    Noisy Data Normalized to Noise Level 1
//   k   :    Degree of Spline Penalty .
// Outputs:
//   xhat:	Estimate based on y with optimal lambda
//   risk:    Estimate of Risk at this x
// See Also
//    SplineURisk
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

	global Spline_Pnty
	global Spline_Data
//
	f = Wavelab_fft(y);
	n = max(size(y));
	Spline_Data = abs(f/sqrt(n)).^2;
	Spline_Pnty = (2 .* sin(%pi .* (0:(n-1)) ./ n)) .^ (2*k);
	Spline_Lmda = fminbnd(SplineURisk,0.,n.^2);
	xhh = f ./ (1 + Spline_Lmda.*Spline_Pnty);
	xh = real(Wavelab_ifft(xhh));
	//clf; subplot(211);
	//plot(1. ./ (1 + Spline_Lmda.*Spline_Pnty));
	//plot(xh);
	c  = SplineURisk(Spline_Lmda);

endfunction    
    
function [Min,val] = fminbnd(_func,lb,ub, option)

  delta = 1e-17;
  gr = (sqrt(5)-1)/2;
  width = (ub-lb);
  out = linspace(lb, ub, 4);
  out(2) = out(4)-gr*width;
  out(3) = out(1)+gr*width;
  upper = _func(out(3));
  lower = _func(out(2));
  while((out(3)-out(2)) > delta) //this will not work for symmetric funcs
    if(upper > lower)
      out(4) = out(3);
      out(3) = out(2);
      width = out(4)-out(1);
      out(2) = out(4)-gr*width;
      upper = lower;
      lower = _func(out(2));
    else
      out(1) = out(2);
      out(2) = out(3);
      width = out(4)-out(1);
      out(3) = out(1)+width*gr;
      lower = upper;
      upper = _func(out(3));
    end
  end
  Min = out(2);
  val = _func(out(2));
endfunction

 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
