function wig = WVDist(sig)
//  Wigner-Ville Distribution
//  Calling Sequence
//    wig = WVDist(sig)
//  Parameters
//  Inputs:
//    sig  :  1-d signal of dyadic length n=2^J
//  Outputs:
//   wig    : complex-valued matrix representing the Wigner-Villedistribution of zero-extended signal with rows corresponding    to frequencies and columns corresponding to times.
//
//  Description
//   Image Plot of the Wigner-Ville distribution
//
//  See also
//   WVDist_AF
//   TFDist_AF
//   ImagePhasePlane
//
// Authors
// Copyright (c) 1994-5, Shaobing Chen
//H. Nahrstaedt - 2011
    
sig = sig(:);
n   = max(size(sig));
f   = [zeros(n,1); sig; zeros(n,1)];
wig = zeros(n, n);
ix  = 0:(n/2-1);
zerosn = zeros(n,1);

for t=1:n,
        tplus    = n + t + ix;
    tminus   = n + t - ix;
    x = zerosn;
    x(1:(n/2)) = f(tplus) .* f(tminus);
    wig(:,t) = 2 * mtlb_fft(x);
end

abstf = abs(wig);
tfmax = max(max(abstf));
tfmin = min(min(abstf));

mtlb_image(linspace(0,1,n),linspace(0,1,n),255*(abstf-tfmin)/(tfmax-tfmin)+1);
F=gcf();F.color_map(1-graycolormap(256));
title('Wigner Distribution');
xlabel('Time')
ylabel('Frequency')


endfunction 
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
