function [H,out] = Wienerdec(g,in,sig,sigma)
// Wiener filter for deconvolution.
// Calling Sequence
//   [H,out] = wienerdec(g,in,sigma)
//  Parameters
// Inputs:
//   g	:	Convolution filter.
//   in	:	Degraded signal.
//   sig:		Original signal.
//   sigma:		S.d. of the additive GWN.
// Outputs:
//   H	:	Wiener filter
//   out:		Restored signal.
// Authors
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011

Y=Wavelab_fft(sig);
FN=Wavelab_fft(in);
n=max(size(in));
PY=abs(Y.*Y);
G=Wavelab_fft(g);
Gsq=G.*conj(G);
H=(PY.*conj(G))./(PY.*Gsq + n*sigma^2);
FN=FN.*H;
out=real(Wavelab_ifft(FN));





endfunction

 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
