function afwig = WignerDist(sig)
// WignerDist -- Alias-Free Wigner-Ville Distribution
//  Calling Sequence
//    afwig = WignerDist(sig)
//  Parameters
//  Inputs:
//    sig  :   1-d signal
//  Outputs:
//    afwig :  complex-valued matrix representing the alias-free   Wigner-Ville distribution of zero-extended signal with   rows corresponding to frequencies and columns corresponding   to times.
//
//  Description
//    Image Plot of the alias-free Wigner-Ville distribution
//
//  See also
//	Interpol2
//
//  Bibliography
//   Mallat's book, sections 4.5.1 and 4.5.4
//   Authors
//
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// H. Nahrstaedt - 2011
    
sig = sig(:);
N   = max(size(sig));
sig = Interpol2(sig);
f = [zeros(2*N,1) sig zeros(2*N,1)];
afwig = zeros(N, N);
q  = (0 : 2*N-1);
p(1:N) = q(1:N);
p(N+1:2*N) = q(N+1:2*N) - 2*N;
for n=1:N,
     nplus    = 2*n + p;
     nminus   = 2*n - p;
    x = f(2*N+nplus) .* conj(f(2*N+nminus));
    aux = mtlb_fft(x);
    afwig(:,n) = aux(1:2:2*N-1);
end
// this should be zero :
//max(max(abs(imag(afwig(1:N/2,:)))));
abstf = real(afwig(1:N/2,:)).*bool2s(real(afwig(1:N/2,:))>=zeros(N/2,N));
tfmax = max(max(abstf));
tfmin = min(min(abstf));

mtlb_image(linspace(0,N,N),linspace(0,N/2,N/2),255*(abstf-tfmin)/(tfmax-tfmin)+1);
F=gcf();F.color_map=(1-graycolormap(256));
title('');
xlabel('Time')
ylabel('Frequency')

endfunction
    
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
