function y = aconv(f,x)
//  Convolution Tool for Two-Scale Transform
//  Calling Sequence
//    y = aconv(f,x)
//   Parameters
//  Inputs:
//    f  :  filter
//    x  :  1-d signal
//  Outputs:
//    y   : filtered result
//
//  Description
//    Filtering by periodic convolution of x with the
//    time-reverse of f.
//
//  See also
//    iconv
//    UpDyadHi
//    UpDyadLo
//    DownDyadHi
//    DownDyadLo
// Authors
// H. Nahrstaedt - 2011
// Copyright (c) 1993. David L. Donoho
//     
  
    


	n = max(size(x));
	p = max(size(f));
	if p < n,
	   xpadded = [x x(1:p)];
	else
	   z = zeros(1,p);
	   for i=1:p,
		   imod = 1 + modulo(i-1,n);
		   z(i) = x(imod);
	   end
	   xpadded = [x z];
	end
	fflip = reverse(f);   
	ypadded = filter(fflip,1,xpadded);
	y = ypadded(p:(n+p-1));
	endfunction

 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
