function extra = edgeunfold(Which,xc,bp,bm)
//   Undo folding projection with (+,-) polarity at EDGES
//  Calling Sequence
//    extra = endfold(Which,xc,bp,bm)
//  Parameters
//  Inputs:
//   Which:  string, 'left'/'right', indicating Which edge we are at
//    xc  :   unfolded data, center window, produced by unfold
//    bp  :   interior of window
//    bm  :   exterior of window
//  Outputs:
//    extra:  extra contribution to central packet
//
//  Description
//    The result should be added to the central packet to
//    ensure exact reconstruction at edges.
//
//  See also
//    unfold
//    CPSynthesis
//    CPImpulse
//    
// Authors
//  Copyright (c) 1994. David L. Donoho
//  H. Nahrstaedt - 2011

	n = max(size(xc));
	m = max(size(bp));
	extra = xc.*0;

	if string(Which)=='left',
		front = 1:m;
		extra(front) = xc(front) .* (1-bp)./bp;
	else
		back  = n:-1:(n+1-m);
		extra(back) = xc(back) .* (1-bp)./bp;
	end	
	endfunction
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
