function y = fold(xc,xl,xr,bp,bm)
// Folding projection with (+,-) polarity
//  Calling Sequence
//    y = fold(xc,xl,xr,bp,bm)
//   Parameters
//  Inputs:
//    xc,xl,xr:    1-d signals: center, left, and right packets
//    bp,bm    :   interior and exterior of taper window
//  Outputs:
//    y     :      the folded series, whose DCT gives the LCT coeffs
//
//  See also
//    CPAnalysis
//
//  Bibliography
//    H. Malvar, IEEE ASSP, 1990.
//
// Authors
// Copyright (c) 1993. David L. Donoho
//     H. Nahrstaedt - 2011

	m = max(size(bp));
	n = max(size(xc));
	front = 1:m;
	back  = n:-1:(n+1-m);
	y = xc;
	y(front)  = bp .* y(front)   + bm .* xl(back );
	y(back )  = bp .* y(back )   - bm .* xr(front);
	endfunction

    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
