function y = iconv(f,x)
// Convolution Tool for Two-Scale Transform
//  Calling Sequence
//    y = iconv(f,x)
//   Parameters
//  Inputs:
//    f  : filter
//    x  : 1-d signal
//  Outputs:
//    y   : filtered result
//
//  Description
//    Filtering by periodic convolution of x with f
//
//  See also
//    aconv
//    UpDyadHi
//    UpDyadLo
//    DownDyadHi
//    DownDyadLo
//
// Authors
// Copyright (c) 1993. David L. Donoho
//     H. Nahrstaedt - 2011


	n = max(size(x));
	p = max(size(f));
	if p <= n,
	   xpadded = [x((n+1-p):n) x];
	else
	   z = zeros(1,p);
	   for i=1:p,
		   imod = 1 + modulo(p*n -p + i-1,n);
		   z(i) = x(imod);
	   end
	   xpadded = [z x];
	end
	ypadded = filter(f,1,xpadded);
	y = ypadded((p+1):(n+p));
endfunction

 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
