function [kx,ky] = quad2ix(j,k1,k2,ep)
// Translate 2-d wavelet indexing into linear indexing
//  Calling Sequence
//    [kx,ky] = quad2ix(j,k1,k2,ep)
//   Parameters
//  Inputs:
//    j   :   resolution level
//    k1,k2:  spatial indices
//    ep   :  spatial orientation
//           ep = 0:  Father(x)Father(y)
//           ep = 1:  Mother(x)Father(y)
//           ep = 2:  Father(x)Mother(y)
//           ep = 3:  Mother(x)Mother(y)
//  Outputs:
//    kx,ky:  index in 2-d wavelet transform array of indicated wavelet
//
//  See also
//    FWT2_PO
//    IWT2_PO
//
// Authors
// Copyright (c) 1993. David L. Donoho
//     H. Nahrstaedt - 2011
    
	kx = dyad2ix(j,k1);
	ky = dyad2ix(j,k2);
	if modulo(ep,2)==0,
	   kx = kx-2^j;
	end
	if ep<2,
	   ky = ky-2^j;
	end

endfunction
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
